using System;
using System.Collections.Generic;
using System.Linq;
using System.Xml;
using System.Text.RegularExpressions;
using Au.Gov.Sbr.Xbrl.Document;
using DataContracts;
using Au.Gov.Sbr.Xbrl.Metadata;
using System.Runtime.CompilerServices;

namespace Ato.EN.IntegrationServices.CodeGenerationFBT
{
    public class FBT2020Consumer
    {

        private static Regex StripWhitespace = new Regex(@"\s*");

        #region Helper/Validation Methods
        private static bool? ToBoolean(string str)
        {
            bool returnValue;
            string value = (str ?? "").Trim();
            if (value == "0" || value == "1")
                return Convert.ToBoolean(Convert.ToInt32(value));
            
            if (Boolean.TryParse(value, out returnValue))
                return returnValue;
            return null;
        }

        private static string GetValueOrEmpty(bool? val)
        {
            return (val.HasValue) ? val.ToString().ToLower() : string.Empty;
        }

        private static string GetValueOrEmpty(DateTime? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        private static string GetValueOrEmpty(string val)
        {
            return !string.IsNullOrWhiteSpace(val) ? val : string.Empty;
        }

        private static string GetValueOrEmpty(decimal? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        private static string GetValueOrEmpty(int? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        /// <summary>
        /// Derives the SBR element location.
        /// </summary>
        /// <param name="sbrElement">The SBR element.</param>
        /// <param name="addOccurrenceIndex">if set to <c>true</c> [add occurrence the occurrence index to the path].</param>
        /// <returns></returns>
        private static string DeriveSbrElementLocation(SBRElement sbrElement, bool addOccurrenceIndex = false)
        {
            if (sbrElement == null) return "/xbrli:xbrl";
            int xpathOccurrence = sbrElement.OccurrenceIndex + 1;
            string location;

            if (addOccurrenceIndex)
            {
                location = "/" + sbrElement.NamespacePrefix + ":" + sbrElement.Name + "[" +
                           xpathOccurrence + "]";
            }
            else
            {
                location = "/" + sbrElement.NamespacePrefix + ":" + sbrElement.Name;
            }

            if (sbrElement.IsInTuple)
            {
                location = DeriveSbrElementLocation(sbrElement.ParentTuple, true) + location;
            }
            else
            {
                location = "/xbrli:xbrl" + location;
            }

            return location;
        }

        private static bool IsMatch(int? field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(Convert.ToString(field.Value), expression, options);
        }

        private static bool IsMatch(string field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(field, expression, options);
        }

        public DateTime AsDate(string dateAsString)
        {
            DateTime response = DateTime.MinValue;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date;
            }

            return response;
        }

         #endregion

        public FBT2018 Consume(SBRDocument sbrDocument)
        {
            List<ProcessMessageDocument> errors;
            return Consume(sbrDocument, false, out errors);
        }

        /// <summary>
        /// Allows for validation of rules that can not be generated and must run at a lower level.
        /// A sub-class will need to be created with an override for this method - which does nothing in its base implementation.
        /// </summary>
        /// <param name="sbrDocument">The SBR document.</param>
        /// <param name="populatedReportElementsMap">The populated report elements map can be used to find data elements and tuples.</param>
        /// <param name="contextArray">The context array can be used to find context values.</param>
        /// <param name="errors">The errors collection is to be populated with validation results.</param>
        protected virtual void ValidateUnsupportedRules(SBRDocument sbrDocument, IDictionary<string, SBRElement> populatedReportElementsMap, SBRContext[] contextArray, List<ProcessMessageDocument> errors)
        {

        }

        public FBT2018 Consume(SBRDocument sbrDocument, bool validationMode, out List<ProcessMessageDocument> errors)
        {
            FBT2018 report;
            report = new FBT2018();
            errors = new List<ProcessMessageDocument>();

            SBRContext[] contextArray;
            IDictionary<string, SBRElement> populatedReportElementsMap;

            contextArray = sbrDocument.ContextsMap.Values.ToArray();
            populatedReportElementsMap = sbrDocument.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();

            if (validationMode) ValidateUnsupportedRules(sbrDocument, populatedReportElementsMap, contextArray, errors);

            /// <summary>
            /// Current element being extracted
            /// </summary>
            SBRElement currentValue = null;
            /// <summary>
            /// Current elements being extracted
            /// </summary>
            IList<SBRElement> currentValues = null;
            /// <summary>
            /// Current occurrences being extracted
            /// </summary>
            IList<SBRElement> currentOccurrences = null;
            /// <summary>
            /// Working Variable for date time variables
            /// </summary>
            DateTime currentDateTimeValue;
            /// <summary>
            /// Working Variable for boolean variables
            /// </summary>
            bool currentBooleanValue;
            /// <summary>
            /// Working Variable for decimal variables
            /// </summary>
            decimal currentDecimalValue;
            /// <summary>
            /// Working Variable for integer variables
            /// </summary>
            int currentIntValue;
            /// <summary>
            /// Working Variable for long variables
            /// </summary>
            long currentLongValue;
            XmlDocumentFragment currentSegment;
            XmlNamespaceManager currentNamespaceManager;
            XmlNode currentNode;
    
            #region sbrINTContext
            IEnumerable<SBRContext> sbrINTContexts = null;
            SBRContext sbrINTContext = null;
    
            sbrINTContexts = contextArray.Where(
                c => c.Period != null && c.Period.PeriodType == SBRPeriod_PeriodType.DURATION &&
                c.Segment != null && c.Segment.ExplicitOrTypedDimensionDomains.Count == 1 && 
                (c.Segment.ExplicitOrTypedDimensionDomains.Any(dd => dd.DimensionType == SBRExplicitOrTypedDimensionDomain_Type.EXPLICIT && dd.Dimension.EndsWith("}ReportPartyTypeDimension") && ((SBRExplicitDimensionDomain)dd).Domain.EndsWith("}Intermediary")) ));
            Dictionary<string, IList<SBRElement>> sbrPopulatedINTElementsMap = new Dictionary<string, IList<SBRElement>>();
            if (sbrINTContexts != null && sbrINTContexts.Count() > 0)
            {
                sbrINTContext = sbrINTContexts.First();
        
                report.INTId = sbrINTContext.Id;
                report.INTIdentifier = sbrINTContext.EntityIdentifier;
                report.INTIdentifierScheme = sbrINTContext.EntityScheme;
        
                report.INTCount = sbrINTContexts.Count();
                report.INTExists = true;
                report.INTOccurrenceIndex = Array.IndexOf(contextArray, sbrINTContext) + 1;
                report.INTLastOccurrenceIndex = Array.IndexOf(contextArray, sbrINTContexts.Last()) + 1;
        

                if (report.INTIdentifierScheme == "http://www.ato.gov.au/abn") report.INTIdentifierABN = report.INTIdentifier;
    
                report.INTStartDate = ((SBRDurationPeriod)sbrINTContext.Period).DurationStartAsDateObject;
                report.INTEndDate = ((SBRDurationPeriod)sbrINTContext.Period).DurationEndAsDateObject;
        
                sbrPopulatedINTElementsMap = new System.Collections.Generic.Dictionary<string, IList<SBRElement>>();
                for (int i = 0; i < sbrINTContexts.Count(); i++)
                {
                    sbrINTContext = sbrINTContexts.ElementAt(i);
            
                    IList<SBRElement> elements = sbrDocument.ElementsByContextId[sbrINTContext.Id];
                    if (elements != null)
                    {
                        for (int e = 0; e < elements.Count(); e++)
                        {
                            SBRElement currentElement = elements[e];
                            if (currentElement == null || currentElement.IsInTuple) continue; // Don't add tuple elements here, they will be found through a different map.
                            if (sbrPopulatedINTElementsMap.ContainsKey("{" + currentElement.Namespace + "}" + currentElement.Name))
                            {
                                sbrPopulatedINTElementsMap["{" + currentElement.Namespace + "}" + currentElement.Name].Add(currentElement);
                            }
                            else
                            {
                                sbrPopulatedINTElementsMap.Add("{" + currentElement.Namespace + "}" + currentElement.Name, new List<SBRElement> { currentElement } );
                            }
                        }
                    }
        
                    IEnumerable<SBRElement> sbrDeclarationCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration", out currentValue))
                        sbrDeclarationCollection = currentValue.Occurrences;
                    else
                        sbrDeclarationCollection = null;
            
                    #region sbrDeclarationCollection
            
                    if (sbrDeclarationCollection != null)
                    {
                        report.DeclarationCollectionExists = true;
                        report.DeclarationCollectionCount = sbrDeclarationCollection.Count();
                
                        IEnumerable<SBRElement> sbrDeclarationCollection_TrueAndCorrect_INTCollection;
                        sbrDeclarationCollection_TrueAndCorrect_INTCollection = sbrDeclarationCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Declaration.StatementType.Code" && te.Value == "TrueAndCorrect" &&
                            sbrINTContexts.Contains(te.Context)));
                        if (sbrDeclarationCollection_TrueAndCorrect_INTCollection != null && sbrDeclarationCollection_TrueAndCorrect_INTCollection.Count() > 0)
                        {
                            SBRElement sbrDeclarationCollection_TrueAndCorrect_INT;
                            sbrDeclarationCollection_TrueAndCorrect_INT = sbrDeclarationCollection_TrueAndCorrect_INTCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrDeclarationCollection_TrueAndCorrect_INTTupleElementMap;
                            sbrDeclarationCollection_TrueAndCorrect_INTTupleElementMap = sbrDeclarationCollection_TrueAndCorrect_INT.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.DeclarationCollection_TrueAndCorrect_INTExists = true;
                            report.DeclarationCollection_TrueAndCorrect_INTCount = sbrDeclarationCollection_TrueAndCorrect_INTCollection.Count();
                            report.DeclarationCollection_TrueAndCorrect_INTOccurrenceIndex = sbrDeclarationCollection_TrueAndCorrect_INT.OccurrenceIndex + 1;
                            report.DeclarationCollection_TrueAndCorrect_INTLastOccurrenceIndex = sbrDeclarationCollection_TrueAndCorrect_INTCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT187 = currentValue.Value;
                            }
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementAccepted.Indicator", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT219 = ToBoolean(currentValue.Value);
                            }
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.Signature.Date", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT218 = DateTime.Parse(currentValue.Value);
                            }
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.SignatoryIdentifier.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT217 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrDeclarationCollection
                    if (validationMode) ValidateINTDeclarationCollection(errors, sbrDeclarationCollection, sbrINTContexts, report);
            
        
                    IEnumerable<SBRElement> sbrPersonUnstructuredNameCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonUnstructuredName", out currentValue))
                        sbrPersonUnstructuredNameCollection = currentValue.Occurrences;
                    else
                        sbrPersonUnstructuredNameCollection = null;
            
                    #region sbrPersonUnstructuredNameCollection
            
                    if (sbrPersonUnstructuredNameCollection != null)
                    {
                        report.PersonUnstructuredNameCollectionExists = true;
                        report.PersonUnstructuredNameCollectionCount = sbrPersonUnstructuredNameCollection.Count();
                
                        IEnumerable<SBRElement> sbrPersonUnstructuredNameCollection_Contact_INTCollection;
                        sbrPersonUnstructuredNameCollection_Contact_INTCollection = sbrPersonUnstructuredNameCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "PersonUnstructuredName.Usage.Code" && te.Value == "Contact" &&
                            sbrINTContexts.Contains(te.Context)));
                        if (sbrPersonUnstructuredNameCollection_Contact_INTCollection != null && sbrPersonUnstructuredNameCollection_Contact_INTCollection.Count() > 0)
                        {
                            SBRElement sbrPersonUnstructuredNameCollection_Contact_INT;
                            sbrPersonUnstructuredNameCollection_Contact_INT = sbrPersonUnstructuredNameCollection_Contact_INTCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrPersonUnstructuredNameCollection_Contact_INTTupleElementMap;
                            sbrPersonUnstructuredNameCollection_Contact_INTTupleElementMap = sbrPersonUnstructuredNameCollection_Contact_INT.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.PersonUnstructuredNameCollection_Contact_INTExists = true;
                            report.PersonUnstructuredNameCollection_Contact_INTCount = sbrPersonUnstructuredNameCollection_Contact_INTCollection.Count();
                            report.PersonUnstructuredNameCollection_Contact_INTOccurrenceIndex = sbrPersonUnstructuredNameCollection_Contact_INT.OccurrenceIndex + 1;
                            report.PersonUnstructuredNameCollection_Contact_INTLastOccurrenceIndex = sbrPersonUnstructuredNameCollection_Contact_INTCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrPersonUnstructuredNameCollection_Contact_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonUnstructuredName.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT172 = currentValue.Value;
                            }
                    
                            if (sbrPersonUnstructuredNameCollection_Contact_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonUnstructuredName.FullName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT129 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrPersonUnstructuredNameCollection
                    if (validationMode) ValidateINTPersonUnstructuredNameCollection(errors, sbrPersonUnstructuredNameCollection, sbrINTContexts, report);
            
            
                    if (sbrPopulatedINTElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Identifiers.TaxAgentNumber.Identifier", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT2 = currentValues[0].Value;
                    }
            
                    if (sbrPopulatedINTElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Identifiers.TaxAgentClientReference.Text", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT130 = currentValues[0].Value;
                    }
        
                    IEnumerable<SBRElement> sbrElectronicContactTelephoneCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContactTelephone", out currentValue))
                        sbrElectronicContactTelephoneCollection = currentValue.Occurrences;
                    else
                        sbrElectronicContactTelephoneCollection = null;
            
                    #region sbrElectronicContactTelephoneCollection
            
                    if (sbrElectronicContactTelephoneCollection != null)
                    {
                        report.ElectronicContactTelephoneCollectionExists = true;
                        report.ElectronicContactTelephoneCollectionCount = sbrElectronicContactTelephoneCollection.Count();
                
                        IEnumerable<SBRElement> sbrElectronicContactTelephoneCollection_03_INTCollection;
                        sbrElectronicContactTelephoneCollection_03_INTCollection = sbrElectronicContactTelephoneCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "ElectronicContact.Telephone.Usage.Code" && te.Value == "03" &&
                            sbrINTContexts.Contains(te.Context)));
                        if (sbrElectronicContactTelephoneCollection_03_INTCollection != null && sbrElectronicContactTelephoneCollection_03_INTCollection.Count() > 0)
                        {
                            SBRElement sbrElectronicContactTelephoneCollection_03_INT;
                            sbrElectronicContactTelephoneCollection_03_INT = sbrElectronicContactTelephoneCollection_03_INTCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrElectronicContactTelephoneCollection_03_INTTupleElementMap;
                            sbrElectronicContactTelephoneCollection_03_INTTupleElementMap = sbrElectronicContactTelephoneCollection_03_INT.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ElectronicContactTelephoneCollection_03_INTExists = true;
                            report.ElectronicContactTelephoneCollection_03_INTCount = sbrElectronicContactTelephoneCollection_03_INTCollection.Count();
                            report.ElectronicContactTelephoneCollection_03_INTOccurrenceIndex = sbrElectronicContactTelephoneCollection_03_INT.OccurrenceIndex + 1;
                            report.ElectronicContactTelephoneCollection_03_INTLastOccurrenceIndex = sbrElectronicContactTelephoneCollection_03_INTCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrElectronicContactTelephoneCollection_03_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT131 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactTelephoneCollection_03_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.ServiceLine.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT132 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactTelephoneCollection_03_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Area.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT127 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactTelephoneCollection_03_INTTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Minimal.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT128 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrElectronicContactTelephoneCollection
                    if (validationMode) ValidateINTElectronicContactTelephoneCollection(errors, sbrElectronicContactTelephoneCollection, sbrINTContexts, report);
            
                } 
            } 
            #endregion End of Context sbrINTContext
    
            #region sbrRPContext
            IEnumerable<SBRContext> sbrRPContexts = null;
            SBRContext sbrRPContext = null;
    
            sbrRPContexts = contextArray.Where(
                c => c.Period != null && c.Period.PeriodType == SBRPeriod_PeriodType.DURATION &&
                c.Segment != null && c.Segment.ExplicitOrTypedDimensionDomains.Count == 1 && 
                (c.Segment.ExplicitOrTypedDimensionDomains.Any(dd => dd.DimensionType == SBRExplicitOrTypedDimensionDomain_Type.EXPLICIT && dd.Dimension.EndsWith("}ReportPartyTypeDimension") && ((SBRExplicitDimensionDomain)dd).Domain.EndsWith("}ReportingParty")) ));
            Dictionary<string, IList<SBRElement>> sbrPopulatedRPElementsMap = new Dictionary<string, IList<SBRElement>>();
            if (sbrRPContexts != null && sbrRPContexts.Count() > 0)
            {
                sbrRPContext = sbrRPContexts.First();
        
                report.RPId = sbrRPContext.Id;
                report.RPIdentifier = sbrRPContext.EntityIdentifier;
                report.RPIdentifierScheme = sbrRPContext.EntityScheme;
        
                report.RPCount = sbrRPContexts.Count();
                report.RPExists = true;
                report.RPOccurrenceIndex = Array.IndexOf(contextArray, sbrRPContext) + 1;
                report.RPLastOccurrenceIndex = Array.IndexOf(contextArray, sbrRPContexts.Last()) + 1;
        

                if (report.RPIdentifierScheme == "http://www.ato.gov.au/tfn") report.RPIdentifierTFN = report.RPIdentifier;

                if (report.RPIdentifierScheme == "http://www.ato.gov.au/abn") report.RPIdentifierABN = report.RPIdentifier;
    
                report.RPStartDate = ((SBRDurationPeriod)sbrRPContext.Period).DurationStartAsDateObject;
                report.RPEndDate = ((SBRDurationPeriod)sbrRPContext.Period).DurationEndAsDateObject;
        
                sbrPopulatedRPElementsMap = new System.Collections.Generic.Dictionary<string, IList<SBRElement>>();
                for (int i = 0; i < sbrRPContexts.Count(); i++)
                {
                    sbrRPContext = sbrRPContexts.ElementAt(i);
            
                    IList<SBRElement> elements = sbrDocument.ElementsByContextId[sbrRPContext.Id];
                    if (elements != null)
                    {
                        for (int e = 0; e < elements.Count(); e++)
                        {
                            SBRElement currentElement = elements[e];
                            if (currentElement == null || currentElement.IsInTuple) continue; // Don't add tuple elements here, they will be found through a different map.
                            if (sbrPopulatedRPElementsMap.ContainsKey("{" + currentElement.Namespace + "}" + currentElement.Name))
                            {
                                sbrPopulatedRPElementsMap["{" + currentElement.Namespace + "}" + currentElement.Name].Add(currentElement);
                            }
                            else
                            {
                                sbrPopulatedRPElementsMap.Add("{" + currentElement.Namespace + "}" + currentElement.Name, new List<SBRElement> { currentElement } );
                            }
                        }
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Identifiers.TaxFileNumber.Identifier", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT3 = currentValues[0].Value;
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Identifiers.AustralianBusinessNumber.Identifier", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT4 = currentValues[0].Value;
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Report.Amendment.Indicator", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT234 = ToBoolean(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Report.AmendmentSequence.Number", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT235 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Report.AmendmentType.Code", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT236 = currentValues[0].Value;
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Report.AmendmentReason.Text", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT237 = currentValues[0].Value;
                    }
        
                    IEnumerable<SBRElement> sbrControllingPartyCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ControllingParty", out currentValue))
                        sbrControllingPartyCollection = currentValue.Occurrences;
                    else
                        sbrControllingPartyCollection = null;
            
                    #region sbrControllingPartyCollection
            
                    if (sbrControllingPartyCollection != null)
                    {
                        report.ControllingPartyCollectionExists = true;
                        report.ControllingPartyCollectionCount = sbrControllingPartyCollection.Count();
                        SBRElement sbrControllingParty;
                        sbrControllingParty = sbrControllingPartyCollection.ElementAt(0);
                
                        IDictionary<string, SBRElement> sbrControllingPartyTupleElementMap;
                        sbrControllingPartyTupleElementMap = sbrControllingParty.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
            
                        IEnumerable<SBRElement> sbrControllingParty_PersonNameDetailsCollection;
                        if (sbrControllingPartyTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails", out currentValue))
                            sbrControllingParty_PersonNameDetailsCollection = currentValue.Occurrences;
                        else
                            sbrControllingParty_PersonNameDetailsCollection = null;
                
                        #region sbrControllingParty_PersonNameDetailsCollection
                
                        if (sbrControllingParty_PersonNameDetailsCollection != null)
                        {
                            report.ControllingParty_PersonNameDetailsCollectionExists = true;
                            report.ControllingParty_PersonNameDetailsCollectionCount = sbrControllingParty_PersonNameDetailsCollection.Count();
                    
                            IEnumerable<SBRElement> sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection;
                            sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection = sbrControllingParty_PersonNameDetailsCollection.Where(
                                ce => ce.ChildElements != null && 
                                ce.ChildElements.Any(te => te.Name == "PersonNameDetails.PersonNameType.Code" && te.Value == "LGL") &&
                                ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Usage.Code" && te.Value == "Identifier") &&
                                ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Currency.Code" && te.Value == "C" &&
                                sbrRPContexts.Contains(te.Context)));
                            if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection != null && sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection.Count() > 0)
                            {
                                SBRElement sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RP;
                                sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RP = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection.ElementAt(0);
                    
                                IDictionary<string, SBRElement> sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap;
                                sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                    
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPExists = true;
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCount = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection.Count();
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RP.OccurrenceIndex + 1;
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPLastOccurrenceIndex = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPCollection.Last().OccurrenceIndex + 1;
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT150 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT225 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT151 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT5 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT7 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT6 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT8 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT9 = currentValue.Value;
                                }
                            }  
                        } 
                        #endregion End of Tuple sbrControllingParty_PersonNameDetailsCollection
                        if (validationMode) ValidateRPControllingParty_PersonNameDetailsCollection(errors, sbrControllingParty_PersonNameDetailsCollection, sbrRPContexts, report);
                
            
                        IEnumerable<SBRElement> sbrControllingParty_OrganisationNameDetailsCollection;
                        if (sbrControllingPartyTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails", out currentValue))
                            sbrControllingParty_OrganisationNameDetailsCollection = currentValue.Occurrences;
                        else
                            sbrControllingParty_OrganisationNameDetailsCollection = null;
                
                        #region sbrControllingParty_OrganisationNameDetailsCollection
                
                        if (sbrControllingParty_OrganisationNameDetailsCollection != null)
                        {
                            report.ControllingParty_OrganisationNameDetailsCollectionExists = true;
                            report.ControllingParty_OrganisationNameDetailsCollectionCount = sbrControllingParty_OrganisationNameDetailsCollection.Count();
                    
                            IEnumerable<SBRElement> sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection;
                            sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection = sbrControllingParty_OrganisationNameDetailsCollection.Where(
                                ce => ce.ChildElements != null && 
                                ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.OrganisationalNameType.Code" && te.Value == "MN") &&
                                ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.Currency.Code" && te.Value == "C" &&
                                sbrRPContexts.Contains(te.Context)));
                            if (sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection != null && sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection.Count() > 0)
                            {
                                SBRElement sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RP;
                                sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RP = sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection.ElementAt(0);
                    
                                IDictionary<string, SBRElement> sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPTupleElementMap;
                                sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPTupleElementMap = sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                    
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPExists = true;
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPCount = sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection.Count();
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex = sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RP.OccurrenceIndex + 1;
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPLastOccurrenceIndex = sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPCollection.Last().OccurrenceIndex + 1;
                        
                                if (sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT152 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT176 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_OrganisationNameDetailsCollection_MN_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT10 = currentValue.Value;
                                }
                            }  
                        } 
                        #endregion End of Tuple sbrControllingParty_OrganisationNameDetailsCollection
                        if (validationMode) ValidateRPControllingParty_OrganisationNameDetailsCollection(errors, sbrControllingParty_OrganisationNameDetailsCollection, sbrRPContexts, report);
                
                
                        #region sbrControllingParty_PersonNameDetailsCollection
                
                        if (sbrControllingParty_PersonNameDetailsCollection != null)
                        {
                    
                            IEnumerable<SBRElement> sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection;
                            sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection = sbrControllingParty_PersonNameDetailsCollection.Where(
                                ce => ce.ChildElements != null && 
                                ce.ChildElements.Any(te => te.Name == "PersonNameDetails.PersonNameType.Code" && te.Value == "LGL") &&
                                ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Usage.Code" && te.Value == "Identifier") &&
                                ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Currency.Code" && te.Value == "P" &&
                                sbrRPContexts.Contains(te.Context)));
                            if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection != null && sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection.Count() > 0)
                            {
                                SBRElement sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RP;
                                sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RP = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection.ElementAt(0);
                    
                                IDictionary<string, SBRElement> sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap;
                                sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                    
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPExists = true;
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCount = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection.Count();
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RP.OccurrenceIndex + 1;
                                report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPLastOccurrenceIndex = sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPCollection.Last().OccurrenceIndex + 1;
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT168 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT228 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT169 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT49 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT51 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT50 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT52 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT53 = currentValue.Value;
                                }
                            }  
                        } 
                        #endregion End of Tuple sbrControllingParty_PersonNameDetailsCollection
                        if (validationMode) ValidateRPControllingParty_PersonNameDetailsCollection1(errors, sbrControllingParty_PersonNameDetailsCollection, sbrRPContexts, report);
                
                
                        #region sbrControllingParty_OrganisationNameDetailsCollection
                
                        if (sbrControllingParty_OrganisationNameDetailsCollection != null)
                        {
                    
                            IEnumerable<SBRElement> sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection;
                            sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection = sbrControllingParty_OrganisationNameDetailsCollection.Where(
                                ce => ce.ChildElements != null && 
                                ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.OrganisationalNameType.Code" && te.Value == "MN") &&
                                ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.Currency.Code" && te.Value == "P" &&
                                sbrRPContexts.Contains(te.Context)));
                            if (sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection != null && sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection.Count() > 0)
                            {
                                SBRElement sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RP;
                                sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RP = sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection.ElementAt(0);
                    
                                IDictionary<string, SBRElement> sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPTupleElementMap;
                                sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPTupleElementMap = sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                    
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPExists = true;
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPCount = sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection.Count();
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex = sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RP.OccurrenceIndex + 1;
                                report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPLastOccurrenceIndex = sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPCollection.Last().OccurrenceIndex + 1;
                        
                                if (sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT184 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT179 = currentValue.Value;
                                }
                        
                                if (sbrControllingParty_OrganisationNameDetailsCollection_MN_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out currentValue))
                                {
                                    if (!currentValue.IsNil) report.FBT54 = currentValue.Value;
                                }
                            }  
                        } 
                        #endregion End of Tuple sbrControllingParty_OrganisationNameDetailsCollection
                        if (validationMode) ValidateRPControllingParty_OrganisationNameDetailsCollection1(errors, sbrControllingParty_OrganisationNameDetailsCollection, sbrRPContexts, report);
                
                    } 
                    #endregion End of Tuple sbrControllingPartyCollection
        
                    IEnumerable<SBRElement> sbrPersonNameDetailsCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails", out currentValue))
                        sbrPersonNameDetailsCollection = currentValue.Occurrences;
                    else
                        sbrPersonNameDetailsCollection = null;
            
                    #region sbrPersonNameDetailsCollection
            
                    if (sbrPersonNameDetailsCollection != null)
                    {
                        report.PersonNameDetailsCollectionExists = true;
                        report.PersonNameDetailsCollectionCount = sbrPersonNameDetailsCollection.Count();
                
                        IEnumerable<SBRElement> sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection;
                        sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection = sbrPersonNameDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.PersonNameType.Code" && te.Value == "LGL") &&
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Usage.Code" && te.Value == "Identifier") &&
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Currency.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection != null && sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrPersonNameDetailsCollection_LGL_Identifier_C_RP;
                            sbrPersonNameDetailsCollection_LGL_Identifier_C_RP = sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap;
                            sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap = sbrPersonNameDetailsCollection_LGL_Identifier_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.PersonNameDetailsCollection_LGL_Identifier_C_RPExists = true;
                            report.PersonNameDetailsCollection_LGL_Identifier_C_RPCount = sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection.Count();
                            report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex = sbrPersonNameDetailsCollection_LGL_Identifier_C_RP.OccurrenceIndex + 1;
                            report.PersonNameDetailsCollection_LGL_Identifier_C_RPLastOccurrenceIndex = sbrPersonNameDetailsCollection_LGL_Identifier_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT181 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT226 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT182 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT11 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT13 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT12 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT14 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT15 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrPersonNameDetailsCollection
                    if (validationMode) ValidateRPPersonNameDetailsCollection(errors, sbrPersonNameDetailsCollection, sbrRPContexts, report);
            
        
                    IEnumerable<SBRElement> sbrOrganisationNameDetailsCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails", out currentValue))
                        sbrOrganisationNameDetailsCollection = currentValue.Occurrences;
                    else
                        sbrOrganisationNameDetailsCollection = null;
            
                    #region sbrOrganisationNameDetailsCollection
            
                    if (sbrOrganisationNameDetailsCollection != null)
                    {
                        report.OrganisationNameDetailsCollectionExists = true;
                        report.OrganisationNameDetailsCollectionCount = sbrOrganisationNameDetailsCollection.Count();
                
                        IEnumerable<SBRElement> sbrOrganisationNameDetailsCollection_MN_C_RPCollection;
                        sbrOrganisationNameDetailsCollection_MN_C_RPCollection = sbrOrganisationNameDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.OrganisationalNameType.Code" && te.Value == "MN") &&
                            ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.Currency.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrOrganisationNameDetailsCollection_MN_C_RPCollection != null && sbrOrganisationNameDetailsCollection_MN_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrOrganisationNameDetailsCollection_MN_C_RP;
                            sbrOrganisationNameDetailsCollection_MN_C_RP = sbrOrganisationNameDetailsCollection_MN_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrOrganisationNameDetailsCollection_MN_C_RPTupleElementMap;
                            sbrOrganisationNameDetailsCollection_MN_C_RPTupleElementMap = sbrOrganisationNameDetailsCollection_MN_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.OrganisationNameDetailsCollection_MN_C_RPExists = true;
                            report.OrganisationNameDetailsCollection_MN_C_RPCount = sbrOrganisationNameDetailsCollection_MN_C_RPCollection.Count();
                            report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex = sbrOrganisationNameDetailsCollection_MN_C_RP.OccurrenceIndex + 1;
                            report.OrganisationNameDetailsCollection_MN_C_RPLastOccurrenceIndex = sbrOrganisationNameDetailsCollection_MN_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrOrganisationNameDetailsCollection_MN_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT183 = currentValue.Value;
                            }
                    
                            if (sbrOrganisationNameDetailsCollection_MN_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT177 = currentValue.Value;
                            }
                    
                            if (sbrOrganisationNameDetailsCollection_MN_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT16 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrOrganisationNameDetailsCollection
                    if (validationMode) ValidateRPOrganisationNameDetailsCollection(errors, sbrOrganisationNameDetailsCollection, sbrRPContexts, report);
            
        
                    IEnumerable<SBRElement> sbrAddressDetailsCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails", out currentValue))
                        sbrAddressDetailsCollection = currentValue.Occurrences;
                    else
                        sbrAddressDetailsCollection = null;
            
                    #region sbrAddressDetailsCollection
            
                    if (sbrAddressDetailsCollection != null)
                    {
                        report.AddressDetailsCollectionExists = true;
                        report.AddressDetailsCollectionCount = sbrAddressDetailsCollection.Count();
                
                        IEnumerable<SBRElement> sbrAddressDetailsCollection_POS_C_RPCollection;
                        sbrAddressDetailsCollection_POS_C_RPCollection = sbrAddressDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "AddressDetails.Usage.Code" && te.Value == "POS") &&
                            ce.ChildElements.Any(te => te.Name == "AddressDetails.Currency.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrAddressDetailsCollection_POS_C_RPCollection != null && sbrAddressDetailsCollection_POS_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrAddressDetailsCollection_POS_C_RP;
                            sbrAddressDetailsCollection_POS_C_RP = sbrAddressDetailsCollection_POS_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrAddressDetailsCollection_POS_C_RPTupleElementMap;
                            sbrAddressDetailsCollection_POS_C_RPTupleElementMap = sbrAddressDetailsCollection_POS_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.AddressDetailsCollection_POS_C_RPExists = true;
                            report.AddressDetailsCollection_POS_C_RPCount = sbrAddressDetailsCollection_POS_C_RPCollection.Count();
                            report.AddressDetailsCollection_POS_C_RPOccurrenceIndex = sbrAddressDetailsCollection_POS_C_RP.OccurrenceIndex + 1;
                            report.AddressDetailsCollection_POS_C_RPLastOccurrenceIndex = sbrAddressDetailsCollection_POS_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.OverseasAddress.Indicator", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT25 = ToBoolean(currentValue.Value);
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT154 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT153 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line1.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT17 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line2.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT18 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line3.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT19 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line4.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT20 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.LocalityName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT21 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Postcode.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT23 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.StateOrTerritory.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT22 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.CountryName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT24 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Country.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT222 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrAddressDetailsCollection
                    if (validationMode) ValidateRPAddressDetailsCollection(errors, sbrAddressDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrPersonNameDetailsCollection
            
                    if (sbrPersonNameDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection;
                        sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection = sbrPersonNameDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.PersonNameType.Code" && te.Value == "LGL") &&
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Usage.Code" && te.Value == "Identifier") &&
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Currency.Code" && te.Value == "P" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection != null && sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection.Count() > 0)
                        {
                            SBRElement sbrPersonNameDetailsCollection_LGL_Identifier_P_RP;
                            sbrPersonNameDetailsCollection_LGL_Identifier_P_RP = sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap;
                            sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap = sbrPersonNameDetailsCollection_LGL_Identifier_P_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.PersonNameDetailsCollection_LGL_Identifier_P_RPExists = true;
                            report.PersonNameDetailsCollection_LGL_Identifier_P_RPCount = sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection.Count();
                            report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex = sbrPersonNameDetailsCollection_LGL_Identifier_P_RP.OccurrenceIndex + 1;
                            report.PersonNameDetailsCollection_LGL_Identifier_P_RPLastOccurrenceIndex = sbrPersonNameDetailsCollection_LGL_Identifier_P_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT156 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT227 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT157 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT26 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT28 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT27 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT29 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Identifier_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT30 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrPersonNameDetailsCollection
                    if (validationMode) ValidateRPPersonNameDetailsCollection1(errors, sbrPersonNameDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrOrganisationNameDetailsCollection
            
                    if (sbrOrganisationNameDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrOrganisationNameDetailsCollection_MN_P_RPCollection;
                        sbrOrganisationNameDetailsCollection_MN_P_RPCollection = sbrOrganisationNameDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.OrganisationalNameType.Code" && te.Value == "MN") &&
                            ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.Currency.Code" && te.Value == "P" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrOrganisationNameDetailsCollection_MN_P_RPCollection != null && sbrOrganisationNameDetailsCollection_MN_P_RPCollection.Count() > 0)
                        {
                            SBRElement sbrOrganisationNameDetailsCollection_MN_P_RP;
                            sbrOrganisationNameDetailsCollection_MN_P_RP = sbrOrganisationNameDetailsCollection_MN_P_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrOrganisationNameDetailsCollection_MN_P_RPTupleElementMap;
                            sbrOrganisationNameDetailsCollection_MN_P_RPTupleElementMap = sbrOrganisationNameDetailsCollection_MN_P_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.OrganisationNameDetailsCollection_MN_P_RPExists = true;
                            report.OrganisationNameDetailsCollection_MN_P_RPCount = sbrOrganisationNameDetailsCollection_MN_P_RPCollection.Count();
                            report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex = sbrOrganisationNameDetailsCollection_MN_P_RP.OccurrenceIndex + 1;
                            report.OrganisationNameDetailsCollection_MN_P_RPLastOccurrenceIndex = sbrOrganisationNameDetailsCollection_MN_P_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrOrganisationNameDetailsCollection_MN_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT158 = currentValue.Value;
                            }
                    
                            if (sbrOrganisationNameDetailsCollection_MN_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT178 = currentValue.Value;
                            }
                    
                            if (sbrOrganisationNameDetailsCollection_MN_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT31 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrOrganisationNameDetailsCollection
                    if (validationMode) ValidateRPOrganisationNameDetailsCollection1(errors, sbrOrganisationNameDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrAddressDetailsCollection
            
                    if (sbrAddressDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrAddressDetailsCollection_POS_P_RPCollection;
                        sbrAddressDetailsCollection_POS_P_RPCollection = sbrAddressDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "AddressDetails.Usage.Code" && te.Value == "POS") &&
                            ce.ChildElements.Any(te => te.Name == "AddressDetails.Currency.Code" && te.Value == "P" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrAddressDetailsCollection_POS_P_RPCollection != null && sbrAddressDetailsCollection_POS_P_RPCollection.Count() > 0)
                        {
                            SBRElement sbrAddressDetailsCollection_POS_P_RP;
                            sbrAddressDetailsCollection_POS_P_RP = sbrAddressDetailsCollection_POS_P_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrAddressDetailsCollection_POS_P_RPTupleElementMap;
                            sbrAddressDetailsCollection_POS_P_RPTupleElementMap = sbrAddressDetailsCollection_POS_P_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.AddressDetailsCollection_POS_P_RPExists = true;
                            report.AddressDetailsCollection_POS_P_RPCount = sbrAddressDetailsCollection_POS_P_RPCollection.Count();
                            report.AddressDetailsCollection_POS_P_RPOccurrenceIndex = sbrAddressDetailsCollection_POS_P_RP.OccurrenceIndex + 1;
                            report.AddressDetailsCollection_POS_P_RPLastOccurrenceIndex = sbrAddressDetailsCollection_POS_P_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.OverseasAddress.Indicator", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT159 = ToBoolean(currentValue.Value);
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT161 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT160 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line1.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT32 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line2.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT33 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line3.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT34 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line4.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT35 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.LocalityName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT36 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Postcode.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT38 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.StateOrTerritory.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT37 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.CountryName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT39 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_POS_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Country.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT223 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrAddressDetailsCollection
                    if (validationMode) ValidateRPAddressDetailsCollection1(errors, sbrAddressDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrOrganisationNameDetailsCollection
            
                    if (sbrOrganisationNameDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrOrganisationNameDetailsCollection_MTR_C_RPCollection;
                        sbrOrganisationNameDetailsCollection_MTR_C_RPCollection = sbrOrganisationNameDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.OrganisationalNameType.Code" && te.Value == "MTR") &&
                            ce.ChildElements.Any(te => te.Name == "OrganisationNameDetails.Currency.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrOrganisationNameDetailsCollection_MTR_C_RPCollection != null && sbrOrganisationNameDetailsCollection_MTR_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrOrganisationNameDetailsCollection_MTR_C_RP;
                            sbrOrganisationNameDetailsCollection_MTR_C_RP = sbrOrganisationNameDetailsCollection_MTR_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrOrganisationNameDetailsCollection_MTR_C_RPTupleElementMap;
                            sbrOrganisationNameDetailsCollection_MTR_C_RPTupleElementMap = sbrOrganisationNameDetailsCollection_MTR_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.OrganisationNameDetailsCollection_MTR_C_RPExists = true;
                            report.OrganisationNameDetailsCollection_MTR_C_RPCount = sbrOrganisationNameDetailsCollection_MTR_C_RPCollection.Count();
                            report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex = sbrOrganisationNameDetailsCollection_MTR_C_RP.OccurrenceIndex + 1;
                            report.OrganisationNameDetailsCollection_MTR_C_RPLastOccurrenceIndex = sbrOrganisationNameDetailsCollection_MTR_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrOrganisationNameDetailsCollection_MTR_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT163 = currentValue.Value;
                            }
                    
                            if (sbrOrganisationNameDetailsCollection_MTR_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT180 = currentValue.Value;
                            }
                    
                            if (sbrOrganisationNameDetailsCollection_MTR_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT40 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrOrganisationNameDetailsCollection
                    if (validationMode) ValidateRPOrganisationNameDetailsCollection2(errors, sbrOrganisationNameDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrAddressDetailsCollection
            
                    if (sbrAddressDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrAddressDetailsCollection_BUS_C_RPCollection;
                        sbrAddressDetailsCollection_BUS_C_RPCollection = sbrAddressDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "AddressDetails.Usage.Code" && te.Value == "BUS") &&
                            ce.ChildElements.Any(te => te.Name == "AddressDetails.Currency.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrAddressDetailsCollection_BUS_C_RPCollection != null && sbrAddressDetailsCollection_BUS_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrAddressDetailsCollection_BUS_C_RP;
                            sbrAddressDetailsCollection_BUS_C_RP = sbrAddressDetailsCollection_BUS_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrAddressDetailsCollection_BUS_C_RPTupleElementMap;
                            sbrAddressDetailsCollection_BUS_C_RPTupleElementMap = sbrAddressDetailsCollection_BUS_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.AddressDetailsCollection_BUS_C_RPExists = true;
                            report.AddressDetailsCollection_BUS_C_RPCount = sbrAddressDetailsCollection_BUS_C_RPCollection.Count();
                            report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex = sbrAddressDetailsCollection_BUS_C_RP.OccurrenceIndex + 1;
                            report.AddressDetailsCollection_BUS_C_RPLastOccurrenceIndex = sbrAddressDetailsCollection_BUS_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.OverseasAddress.Indicator", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT164 = ToBoolean(currentValue.Value);
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT166 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT165 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line1.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT41 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line2.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT42 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line3.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT43 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line4.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT44 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.LocalityName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT45 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Postcode.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT47 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.StateOrTerritory.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT46 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.CountryName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT48 = currentValue.Value;
                            }
                    
                            if (sbrAddressDetailsCollection_BUS_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Country.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT224 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrAddressDetailsCollection
                    if (validationMode) ValidateRPAddressDetailsCollection2(errors, sbrAddressDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrPersonNameDetailsCollection
            
                    if (sbrPersonNameDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection;
                        sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection = sbrPersonNameDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.PersonNameType.Code" && te.Value == "LGL") &&
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Usage.Code" && te.Value == "Contact") &&
                            ce.ChildElements.Any(te => te.Name == "PersonNameDetails.Currency.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection != null && sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrPersonNameDetailsCollection_LGL_Contact_C_RP;
                            sbrPersonNameDetailsCollection_LGL_Contact_C_RP = sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap;
                            sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap = sbrPersonNameDetailsCollection_LGL_Contact_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.PersonNameDetailsCollection_LGL_Contact_C_RPExists = true;
                            report.PersonNameDetailsCollection_LGL_Contact_C_RPCount = sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection.Count();
                            report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex = sbrPersonNameDetailsCollection_LGL_Contact_C_RP.OccurrenceIndex + 1;
                            report.PersonNameDetailsCollection_LGL_Contact_C_RPLastOccurrenceIndex = sbrPersonNameDetailsCollection_LGL_Contact_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT170 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT171 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT191 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT55 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT57 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT56 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT58 = currentValue.Value;
                            }
                    
                            if (sbrPersonNameDetailsCollection_LGL_Contact_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT59 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrPersonNameDetailsCollection
                    if (validationMode) ValidateRPPersonNameDetailsCollection2(errors, sbrPersonNameDetailsCollection, sbrRPContexts, report);
            
        
                    IEnumerable<SBRElement> sbrElectronicContactTelephoneCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContactTelephone", out currentValue))
                        sbrElectronicContactTelephoneCollection = currentValue.Occurrences;
                    else
                        sbrElectronicContactTelephoneCollection = null;
            
                    #region sbrElectronicContactTelephoneCollection
            
                    if (sbrElectronicContactTelephoneCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrElectronicContactTelephoneCollection_03_RPCollection;
                        sbrElectronicContactTelephoneCollection_03_RPCollection = sbrElectronicContactTelephoneCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "ElectronicContact.Telephone.Usage.Code" && te.Value == "03" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrElectronicContactTelephoneCollection_03_RPCollection != null && sbrElectronicContactTelephoneCollection_03_RPCollection.Count() > 0)
                        {
                            SBRElement sbrElectronicContactTelephoneCollection_03_RP;
                            sbrElectronicContactTelephoneCollection_03_RP = sbrElectronicContactTelephoneCollection_03_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrElectronicContactTelephoneCollection_03_RPTupleElementMap;
                            sbrElectronicContactTelephoneCollection_03_RPTupleElementMap = sbrElectronicContactTelephoneCollection_03_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ElectronicContactTelephoneCollection_03_RPExists = true;
                            report.ElectronicContactTelephoneCollection_03_RPCount = sbrElectronicContactTelephoneCollection_03_RPCollection.Count();
                            report.ElectronicContactTelephoneCollection_03_RPOccurrenceIndex = sbrElectronicContactTelephoneCollection_03_RP.OccurrenceIndex + 1;
                            report.ElectronicContactTelephoneCollection_03_RPLastOccurrenceIndex = sbrElectronicContactTelephoneCollection_03_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrElectronicContactTelephoneCollection_03_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT134 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactTelephoneCollection_03_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.ServiceLine.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT135 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactTelephoneCollection_03_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Area.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT60 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactTelephoneCollection_03_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Minimal.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT61 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrElectronicContactTelephoneCollection
                    if (validationMode) ValidateRPElectronicContactTelephoneCollection(errors, sbrElectronicContactTelephoneCollection, sbrRPContexts, report);
            
        
                    IEnumerable<SBRElement> sbrElectronicContactElectronicMailCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContactElectronicMail", out currentValue))
                        sbrElectronicContactElectronicMailCollection = currentValue.Occurrences;
                    else
                        sbrElectronicContactElectronicMailCollection = null;
            
                    #region sbrElectronicContactElectronicMailCollection
            
                    if (sbrElectronicContactElectronicMailCollection != null)
                    {
                        report.ElectronicContactElectronicMailCollectionExists = true;
                        report.ElectronicContactElectronicMailCollectionCount = sbrElectronicContactElectronicMailCollection.Count();
                
                        IEnumerable<SBRElement> sbrElectronicContactElectronicMailCollection_03_RPCollection;
                        sbrElectronicContactElectronicMailCollection_03_RPCollection = sbrElectronicContactElectronicMailCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "ElectronicContact.ElectronicMail.Usage.Code" && te.Value == "03" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrElectronicContactElectronicMailCollection_03_RPCollection != null && sbrElectronicContactElectronicMailCollection_03_RPCollection.Count() > 0)
                        {
                            SBRElement sbrElectronicContactElectronicMailCollection_03_RP;
                            sbrElectronicContactElectronicMailCollection_03_RP = sbrElectronicContactElectronicMailCollection_03_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrElectronicContactElectronicMailCollection_03_RPTupleElementMap;
                            sbrElectronicContactElectronicMailCollection_03_RPTupleElementMap = sbrElectronicContactElectronicMailCollection_03_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ElectronicContactElectronicMailCollection_03_RPExists = true;
                            report.ElectronicContactElectronicMailCollection_03_RPCount = sbrElectronicContactElectronicMailCollection_03_RPCollection.Count();
                            report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex = sbrElectronicContactElectronicMailCollection_03_RP.OccurrenceIndex + 1;
                            report.ElectronicContactElectronicMailCollection_03_RPLastOccurrenceIndex = sbrElectronicContactElectronicMailCollection_03_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrElectronicContactElectronicMailCollection_03_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.ElectronicMail.Usage.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT133 = currentValue.Value;
                            }
                    
                            if (sbrElectronicContactElectronicMailCollection_03_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.ElectronicMail.Address.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT62 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrElectronicContactElectronicMailCollection
                    if (validationMode) ValidateRPElectronicContactElectronicMailCollection(errors, sbrElectronicContactElectronicMailCollection, sbrRPContexts, report);
            
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Recipients.Count", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT63 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Report.CompletionHours.Number", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT64 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Lodgment.FutureReturn.Indicator", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT238 = ToBoolean(currentValues[0].Value);
                    }
        
                    IEnumerable<SBRElement> sbrFinancialInstitutionAccountCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FinancialInstitutionAccount", out currentValue))
                        sbrFinancialInstitutionAccountCollection = currentValue.Occurrences;
                    else
                        sbrFinancialInstitutionAccountCollection = null;
            
                    #region sbrFinancialInstitutionAccountCollection
            
                    if (sbrFinancialInstitutionAccountCollection != null)
                    {
                        report.FinancialInstitutionAccountCollectionExists = true;
                        report.FinancialInstitutionAccountCollectionCount = sbrFinancialInstitutionAccountCollection.Count();
                        SBRElement sbrFinancialInstitutionAccount;
                        sbrFinancialInstitutionAccount = sbrFinancialInstitutionAccountCollection.ElementAt(0);
                
                        IDictionary<string, SBRElement> sbrFinancialInstitutionAccountTupleElementMap;
                        sbrFinancialInstitutionAccountTupleElementMap = sbrFinancialInstitutionAccount.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                        if (sbrFinancialInstitutionAccountTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FinancialInstitutionAccount.BankStateBranch.Number", out currentValue))
                        {
                            if (!currentValue.IsNil) report.FBT229 = currentValue.Value;
                        }
                
                        if (sbrFinancialInstitutionAccountTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FinancialInstitutionAccount.FinancialInstitutionAccount.Number", out currentValue))
                        {
                            if (!currentValue.IsNil) report.FBT230 = currentValue.Value;
                        }
                
                        if (sbrFinancialInstitutionAccountTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FinancialInstitutionAccount.FinancialInstitutionAccountName.Text", out currentValue))
                        {
                            if (!currentValue.IsNil) report.FBT231 = currentValue.Value;
                        }
                
                        if (sbrFinancialInstitutionAccountTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FinancialInstitutionAccount.FinancialInstitutionBranchName.Text", out currentValue))
                        {
                            if (!currentValue.IsNil) report.FBT232 = currentValue.Value;
                        }
                
                        if (sbrFinancialInstitutionAccountTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FinancialInstitutionAccount.FinancialInstitutionName.Text", out currentValue))
                        {
                            if (!currentValue.IsNil) report.FBT233 = currentValue.Value;
                        }
                    } 
                    #endregion End of Tuple sbrFinancialInstitutionAccountCollection
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type1Aggregate.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT66 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.Type1Aggregate.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT67 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type2Aggregate.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT68 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.Type2Aggregate.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT69 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.AggregateNonExempt.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT70 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.TaxableTotal.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT71 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.Payable.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT72 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.NonRebatableAggregate.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT73 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.Rebate.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT74 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.Liability.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT75 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.LiabilityInstalmentsTotal.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT76 = decimal.Parse(currentValues[0].Value);
                    }
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}FringeBenefitsTax.AdjustmentDue.Amount", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT77 = decimal.Parse(currentValues[0].Value);
                    }
        
                    IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ProvidedFringeBenefitsDetails", out currentValue))
                        sbrProvidedFringeBenefitsDetailsCollection = currentValue.Occurrences;
                    else
                        sbrProvidedFringeBenefitsDetailsCollection = null;
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                        report.ProvidedFringeBenefitsDetailsCollectionExists = true;
                        report.ProvidedFringeBenefitsDetailsCollectionCount = sbrProvidedFringeBenefitsDetailsCollection.Count();
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "A" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_A_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_A_RP = sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_A_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_A_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_A_RPCount = sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_A_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_A_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_A_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT136 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT78 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT79 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT80 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT192 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_A_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT81 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "B" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_B_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_B_RP = sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_B_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_B_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_B_RPCount = sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_B_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_B_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_B_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT137 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT82 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT83 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT84 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT193 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_B_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT85 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection1(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "C" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_C_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_C_RP = sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_C_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_C_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_C_RPCount = sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_C_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_C_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_C_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT138 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT86 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT87 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT194 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT88 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_C_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT89 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection2(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "D" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_D_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_D_RP = sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_D_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_D_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_D_RPCount = sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_D_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_D_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_D_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT139 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT195 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT90 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT196 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT197 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_D_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT91 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection3(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "E" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_E_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_E_RP = sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_E_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_E_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_E_RPCount = sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_E_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_E_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_E_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT140 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT198 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT92 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT93 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT94 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_E_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT95 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection4(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "F" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_F_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_F_RP = sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_F_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_F_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_F_RPCount = sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_F_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_F_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_F_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT141 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT96 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT97 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT98 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT199 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_F_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT99 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection5(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "G" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_G_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_G_RP = sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_G_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_G_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_G_RPCount = sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_G_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_G_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_G_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT142 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT100 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT101 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT200 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT102 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_G_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT103 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection6(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "J" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_J_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_J_RP = sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_J_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_J_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_J_RPCount = sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_J_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_J_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_J_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT144 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT202 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT108 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT109 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT110 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_J_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT111 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection7(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "K" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_K_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_K_RP = sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_K_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_K_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_K_RPCount = sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_K_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_K_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_K_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT145 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT203 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT112 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT113 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT114 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_K_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT115 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection8(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "L" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_L_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_L_RP = sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_L_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_L_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_L_RPCount = sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_L_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_L_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_L_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT146 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT204 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT116 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT205 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT206 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_L_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT117 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection9(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "M" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_M_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_M_RP = sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_M_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_M_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_M_RPCount = sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_M_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_M_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_M_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT147 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT207 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT118 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT119 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT120 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_M_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT121 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection10(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "N" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_N_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_N_RP = sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_N_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_N_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_N_RPCount = sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_N_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_N_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_N_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT148 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT208 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT122 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT123 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT209 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_N_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT124 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection11(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
            
                    #region sbrProvidedFringeBenefitsDetailsCollection
            
                    if (sbrProvidedFringeBenefitsDetailsCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection;
                        sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection = sbrProvidedFringeBenefitsDetailsCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Remuneration.FringeBenefits.Type.Code" && te.Value == "P" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection != null && sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection.Count() > 0)
                        {
                            SBRElement sbrProvidedFringeBenefitsDetailsCollection_P_RP;
                            sbrProvidedFringeBenefitsDetailsCollection_P_RP = sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap;
                            sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap = sbrProvidedFringeBenefitsDetailsCollection_P_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.ProvidedFringeBenefitsDetailsCollection_P_RPExists = true;
                            report.ProvidedFringeBenefitsDetailsCollection_P_RPCount = sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection.Count();
                            report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_P_RP.OccurrenceIndex + 1;
                            report.ProvidedFringeBenefitsDetailsCollection_P_RPLastOccurrenceIndex = sbrProvidedFringeBenefitsDetailsCollection_P_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT149 = currentValue.Value;
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT210 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT125 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT211 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT212 = decimal.Parse(currentValue.Value);
                            }
                    
                            if (sbrProvidedFringeBenefitsDetailsCollection_P_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT126 = decimal.Parse(currentValue.Value);
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrProvidedFringeBenefitsDetailsCollection
                    if (validationMode) ValidateRPProvidedFringeBenefitsDetailsCollection12(errors, sbrProvidedFringeBenefitsDetailsCollection, sbrRPContexts, report);
            
        
                    IEnumerable<SBRElement> sbrDeclarationCollection;
                    if (populatedReportElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration", out currentValue))
                        sbrDeclarationCollection = currentValue.Occurrences;
                    else
                        sbrDeclarationCollection = null;
            
                    #region sbrDeclarationCollection
            
                    if (sbrDeclarationCollection != null)
                    {
                
                        IEnumerable<SBRElement> sbrDeclarationCollection_TrueAndCorrect_RPCollection;
                        sbrDeclarationCollection_TrueAndCorrect_RPCollection = sbrDeclarationCollection.Where(
                            ce => ce.ChildElements != null && 
                            ce.ChildElements.Any(te => te.Name == "Declaration.StatementType.Code" && te.Value == "TrueAndCorrect" &&
                            sbrRPContexts.Contains(te.Context)));
                        if (sbrDeclarationCollection_TrueAndCorrect_RPCollection != null && sbrDeclarationCollection_TrueAndCorrect_RPCollection.Count() > 0)
                        {
                            SBRElement sbrDeclarationCollection_TrueAndCorrect_RP;
                            sbrDeclarationCollection_TrueAndCorrect_RP = sbrDeclarationCollection_TrueAndCorrect_RPCollection.ElementAt(0);
                
                            IDictionary<string, SBRElement> sbrDeclarationCollection_TrueAndCorrect_RPTupleElementMap;
                            sbrDeclarationCollection_TrueAndCorrect_RPTupleElementMap = sbrDeclarationCollection_TrueAndCorrect_RP.PopulatedChildElementsMap ?? new Dictionary<string, SBRElement>();
                
                            report.DeclarationCollection_TrueAndCorrect_RPExists = true;
                            report.DeclarationCollection_TrueAndCorrect_RPCount = sbrDeclarationCollection_TrueAndCorrect_RPCollection.Count();
                            report.DeclarationCollection_TrueAndCorrect_RPOccurrenceIndex = sbrDeclarationCollection_TrueAndCorrect_RP.OccurrenceIndex + 1;
                            report.DeclarationCollection_TrueAndCorrect_RPLastOccurrenceIndex = sbrDeclarationCollection_TrueAndCorrect_RPCollection.Last().OccurrenceIndex + 1;
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementType.Code", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT185 = currentValue.Value;
                            }
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementAccepted.Indicator", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT215 = ToBoolean(currentValue.Value);
                            }
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.Signature.Date", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT214 = DateTime.Parse(currentValue.Value);
                            }
                    
                            if (sbrDeclarationCollection_TrueAndCorrect_RPTupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.SignatoryIdentifier.Text", out currentValue))
                            {
                                if (!currentValue.IsNil) report.FBT213 = currentValue.Value;
                            }
                        }  
                    } 
                    #endregion End of Tuple sbrDeclarationCollection
                    if (validationMode) ValidateRPDeclarationCollection(errors, sbrDeclarationCollection, sbrRPContexts, report);
            
            
                    if (sbrPopulatedRPElementsMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}RegulatoryDisclosures.GeneralInformationAboutFinancialStatements.Text", out currentValues))
                    {
                        if (!currentValues[0].IsNil) report.FBT239 = currentValues[0].Value;
                    }
                } 
            } 
            #endregion End of Context sbrRPContext
            return report;

        } // Of Consume Method
        #region ValidateINTDeclarationCollection
        protected virtual void ValidateINTDeclarationCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the INT Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT187Value = null;
                    string FBT187 = null;
                    SBRElement FBT219Value = null;
                    bool? FBT219 = null;
                    SBRElement FBT218Value = null;
                    DateTime? FBT218 = null;
                    SBRElement FBT217Value = null;
                    string FBT217 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementType.Code", out FBT187Value))
                    {
                        if (!FBT187Value.IsNil) FBT187 = FBT187Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementAccepted.Indicator", out FBT219Value))
                    {
                        if (!FBT219Value.IsNil) FBT219 = ToBoolean(FBT219Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.Signature.Date", out FBT218Value))
                    {
                        if (!FBT218Value.IsNil) FBT218 = DateTime.Parse(FBT218Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.SignatoryIdentifier.Text", out FBT217Value))
                    {
                        if (!FBT217Value.IsNil) FBT217 = FBT217Value.Value;
                    }
        
                    #region VR.ATO.GEN.438061

        /*  VR.ATO.GEN.438061
            If an Intermediary is present, Intermediary declaration statement type code must be supplied and must be “TrueAndCorrect”.

        Legacy Rule Format:
            IF INT<>NULL AND INT:pyin.xx.xx:Declaration.StatementType.Code <> "TrueAndCorrect"
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            ^INT <> NULL AND ^FBT187 <> 'TrueAndCorrect'

        Data Elements:

        ^FBT187 = INT:Declaration:Declaration.StatementType.Code WHERE [Declaration.StatementType.Code='TrueAndCorrect']

        ^INT = INT
        */
                    assertion = (report.INTExists != false && FBT187 != @"TrueAndCorrect");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438061", Severity = ProcessMessageSeverity.Error,
                            Description = @"Declaration statement type code is required.",
                            LongDescription = @"If an Intermediary is present, Intermediary declaration statement type code must be supplied and must be ""TrueAndCorrect"".",
                            Location = FBT187Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:Declaration.StatementType.Code" : DeriveSbrElementLocation(FBT187Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438061"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT187", Value = FBT187 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateINTPersonUnstructuredNameCollection
        protected virtual void ValidateINTPersonUnstructuredNameCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the INT Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT129Value = null;
                    string FBT129 = null;

                    SBRElement FBT172Value = null;
                    string FBT172 = null;
                    bool PersonUnstructuredNameCollection_Contact_INTExists = true;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonUnstructuredName.FullName.Text", out FBT129Value))
                    {
                        if (!FBT129Value.IsNil) FBT129 = FBT129Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonUnstructuredName.Usage.Code", out FBT172Value))
                    {
                        if (!FBT172Value.IsNil) FBT172 = FBT172Value.Value;
                    }
        
                    #region VR.ATO.FBT.000454

        /*  VR.ATO.FBT.000454
            Agent Contact Person Unstructured Name usage code must be "Contact"

        Legacy Rule Format:
            IF (INT:pyde.xx.xx:PersonUnstructuredName.FullName.Text <> NULLORBLANK)
            AND (INT:pyde.xx.xx:PersonUnstructuredName.Usage.Code <> “Contact”)
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT129 <> BLANK) AND (^FBT172 <> 'Contact')

        Data Elements:

        ^FBT172 = INT:PersonUnstructuredName:PersonUnstructuredName.Usage.Code WHERE [PersonUnstructuredName.Usage.Code='Contact']

        ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT129) != true && FBT172 != @"Contact");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000454", Severity = ProcessMessageSeverity.Error,
                            Description = @"Agent Contact Person Unstructured Name usage code must be ""Contact""",
                            Location = FBT172Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonUnstructuredName.Usage.Code" : DeriveSbrElementLocation(FBT172Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000454"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT129", Value = FBT129 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT172", Value = FBT172 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.FBT.000455

        /*  VR.ATO.FBT.000455
            Agent Contact Person Unstructured Name usage code is invalid. It must be "Contact"

        Legacy Rule Format:
            IF (INT:pyde.xx.xx:PersonUnstructuredName.Usage.Code <> NULLORBLANK)
            AND (INT:pyde.xx.xx:PersonUnstructuredName.Usage.Code <> "Contact")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT172 <> BLANK) AND (^FBT172 <> 'Contact')

        Data Elements:

        ^FBT172 = INT:PersonUnstructuredName:PersonUnstructuredName.Usage.Code WHERE [PersonUnstructuredName.Usage.Code='Contact']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT172) != true && FBT172 != @"Contact");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000455", Severity = ProcessMessageSeverity.Error,
                            Description = @"Agent Contact Person Unstructured Name usage code is invalid. It must be ""Contact""",
                            Location = FBT172Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonUnstructuredName.Usage.Code" : DeriveSbrElementLocation(FBT172Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000455"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT172", Value = FBT172 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.000243

        /*  VR.ATO.GEN.000243
            Both person unstructured name usage code and name must be provided

        Legacy Rule Format:
            WHERE IN TUPLE(personunstructuredname1.xx.xx:PersonUnstructuredName)
            IF pyde.xx.xx:PersonUnstructuredName.Usage.Code = NULLORBLANK OR pyde.xx.xx:PersonUnstructuredName.FullName.Text = NULLORBLANK
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^PersonUnstructuredName <> NULL) AND (^FBT172 = BLANK OR ^FBT129 = BLANK)

        Data Elements:

        ^FBT172 = INT:PersonUnstructuredName:PersonUnstructuredName.Usage.Code WHERE [PersonUnstructuredName.Usage.Code='Contact']

        ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']

        ^PersonUnstructuredName = INT:PersonUnstructuredName
        */
                    assertion = (PersonUnstructuredNameCollection_Contact_INTExists != false && (string.IsNullOrWhiteSpace(FBT172) == true || string.IsNullOrWhiteSpace(FBT129) == true));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.000243", Severity = ProcessMessageSeverity.Error,
                            Description = @"Both person unstructured name usage code and name must be provided",
                            Location = FBT172Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonUnstructuredName.Usage.Code" : DeriveSbrElementLocation(FBT172Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000243"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT172", Value = FBT172 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT129", Value = FBT129 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateINTElectronicContactTelephoneCollection
        protected virtual void ValidateINTElectronicContactTelephoneCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the INT Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                    bool ElectronicContactTelephoneCollection_03_INTExists = true;

                    SBRElement FBT128Value = null;
                    string FBT128 = null;

                    SBRElement FBT131Value = null;
                    string FBT131 = null;

                    SBRElement FBT132Value = null;
                    string FBT132 = null;
                    SBRElement FBT127Value = null;
                    string FBT127 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Minimal.Number", out FBT128Value))
                    {
                        if (!FBT128Value.IsNil) FBT128 = FBT128Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Usage.Code", out FBT131Value))
                    {
                        if (!FBT131Value.IsNil) FBT131 = FBT131Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.ServiceLine.Code", out FBT132Value))
                    {
                        if (!FBT132Value.IsNil) FBT132 = FBT132Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Area.Code", out FBT127Value))
                    {
                        if (!FBT127Value.IsNil) FBT127 = FBT127Value.Value;
                    }
        
                    #region VR.ATO.GEN.432016

        /*  VR.ATO.GEN.432016
            Telephone must include number, usage code '03' and service line code '01' or '02'.

        Legacy Rule Format:
            WHERE IN TUPLE(electroniccontacttelephone1.xx.xx:ElectronicContactTelephone)
            IF pyde.xx.xx:ElectronicContact.Telephone.Minimal.Number = NULL OR pyde.xx.xx:ElectronicContact.Telephone.Usage.Code <> "03" OR pyde.xx.xx:Electronic Contact.Telephone.ServiceLine.Code <> SET ("01", "02")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^ElectronicContactTelephone <> NULL) AND (^FBT128 = NULL OR ^FBT131 <> '03' OR NotInSet(^FBT132, '"01", "02"'))

        Data Elements:

        ^FBT128 = INT:ElectronicContactTelephone:ElectronicContact.Telephone.Minimal.Number WHERE [ElectronicContact.Telephone.Usage.Code='03']

        ^FBT131 = INT:ElectronicContactTelephone:ElectronicContact.Telephone.Usage.Code WHERE [ElectronicContact.Telephone.Usage.Code='03']

        ^FBT132 = INT:ElectronicContactTelephone:ElectronicContact.Telephone.ServiceLine.Code WHERE [ElectronicContact.Telephone.Usage.Code='03']

        ^ElectronicContactTelephone = INT:ElectronicContactTelephone
        */
                    assertion = (ElectronicContactTelephoneCollection_03_INTExists != false && (FBT128 == null || FBT131 != @"03" || !(IsMatch(FBT132, @"^(01|02)$",RegexOptions.IgnoreCase))));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.432016", Severity = ProcessMessageSeverity.Error,
                            Description = @"Telephone must include number, usage code '03' and service line code '01' or '02'.",
                            LongDescription = @"A telephone must include the number, a usage code of '03' - contact, and a service line code of '01' - Mobile or '02' - Landline or fixed line. An two digit area code should be provided for a landline.",
                            Location = FBT128Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:ElectronicContact.Telephone.Minimal.Number" : DeriveSbrElementLocation(FBT128Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432016"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT128", Value = FBT128 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT131", Value = FBT131 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT132", Value = FBT132 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPControllingParty_PersonNameDetailsCollection
        protected virtual void ValidateRPControllingParty_PersonNameDetailsCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                    bool ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPExists = true;

                    SBRElement FBT225Value = null;
                    string FBT225 = null;

                    SBRElement FBT6Value = null;
                    string FBT6 = null;

                    SBRElement FBT150Value = null;
                    string FBT150 = null;
                    SBRElement FBT151Value = null;
                    string FBT151 = null;
                    SBRElement FBT5Value = null;
                    string FBT5 = null;
                    SBRElement FBT7Value = null;
                    string FBT7 = null;
                    SBRElement FBT8Value = null;
                    string FBT8 = null;
                    SBRElement FBT9Value = null;
                    string FBT9 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out FBT225Value))
                    {
                        if (!FBT225Value.IsNil) FBT225 = FBT225Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out FBT6Value))
                    {
                        if (!FBT6Value.IsNil) FBT6 = FBT6Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out FBT150Value))
                    {
                        if (!FBT150Value.IsNil) FBT150 = FBT150Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out FBT151Value))
                    {
                        if (!FBT151Value.IsNil) FBT151 = FBT151Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out FBT5Value))
                    {
                        if (!FBT5Value.IsNil) FBT5 = FBT5Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out FBT7Value))
                    {
                        if (!FBT7Value.IsNil) FBT7 = FBT7Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out FBT8Value))
                    {
                        if (!FBT8Value.IsNil) FBT8 = FBT8Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out FBT9Value))
                    {
                        if (!FBT9Value.IsNil) FBT9 = FBT9Value.Value;
                    }
        
                    #region VR.ATO.FBT.000452

        /*  VR.ATO.FBT.000452
            Employer Current Contact Person Name Usage code is invalid. It must be "Contact" or ""Identifier"

        Legacy Rule Format:
            IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails)
            IF pyde.xx.xx:PersonNameDetails.Usage.Code <> SET("Identifier", "Contact")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND (NotInSet(^FBT225, '"Identifier", "Contact"'))

        Data Elements:

        ^FBT225 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.Usage.Code WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']

        ^PersonNameDetails = RP:ControllingParty:PersonNameDetails
        */
                    assertion = (ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPExists != false && !(IsMatch(FBT225, @"^(Identifier|Contact)$",RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000452", Severity = ProcessMessageSeverity.Error,
                            Description = @"Person Name Usage code is invalid. It must be either ""Identifier"" or ""Contact"".",
                            Location = FBT225Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonNameDetails.Usage.Code" : DeriveSbrElementLocation(FBT225Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000452"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.000462

        /*  VR.ATO.GEN.000462
            Person Name Type Code must be "LGL"

        Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.PersonNameType.Code <> "LGL")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT6 <> BLANK) AND (^FBT150 <> 'LGL')

        Data Elements:

        ^FBT150 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.PersonNameType.Code WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']

        ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT6) != true && FBT150 != @"LGL");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.000462", Severity = ProcessMessageSeverity.Error,
                            Description = @"Person Name Type Code must be ""LGL""",
                            Location = FBT150Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonNameDetails.PersonNameType.Code" : DeriveSbrElementLocation(FBT150Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000462"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPControllingParty_OrganisationNameDetailsCollection
        protected virtual void ValidateRPControllingParty_OrganisationNameDetailsCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT10Value = null;
                    string FBT10 = null;

                    SBRElement FBT152Value = null;
                    string FBT152 = null;
                    bool ControllingParty_OrganisationNameDetailsCollection_MN_C_RPExists = true;

                    SBRElement FBT176Value = null;
                    string FBT176 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out FBT10Value))
                    {
                        if (!FBT10Value.IsNil) FBT10 = FBT10Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out FBT152Value))
                    {
                        if (!FBT152Value.IsNil) FBT152 = FBT152Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out FBT176Value))
                    {
                        if (!FBT176Value.IsNil) FBT176 = FBT176Value.Value;
                    }
        
                    #region VR.ATO.GEN.000465

        /*  VR.ATO.GEN.000465
            Organisation name type code must be "MN" or "MTR"

        Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK)
            AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code <> SET("MN","MTR"))
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT10 <> BLANK) AND (NotInSet(^FBT152, '"MN","MTR"'))

        Data Elements:

        ^FBT152 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalNameType.Code WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']

        ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT10) != true && !(IsMatch(FBT152, @"^(MN|MTR)$",RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.000465", Severity = ProcessMessageSeverity.Error,
                            Description = @"Organisation name type code must be ""MN"" or ""MTR""",
                            Location = FBT152Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:OrganisationNameDetails.OrganisationalNameType.Code" : DeriveSbrElementLocation(FBT152Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000465"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.410140

        /*  VR.ATO.GEN.410140
            Organisation Name Currency Code must be present

        Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.Currency.Code = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT176 = BLANK)

        Data Elements:

        ^FBT176 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.Currency.Code WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']

        ^OrganisationNameDetails = RP:ControllingParty:OrganisationNameDetails
        */
                    assertion = (ControllingParty_OrganisationNameDetailsCollection_MN_C_RPExists != false && string.IsNullOrWhiteSpace(FBT176) == true);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.410140", Severity = ProcessMessageSeverity.Error,
                            Description = @"Organisation Name Currency Code must be present",
                            Location = FBT176Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:OrganisationNameDetails.Currency.Code" : DeriveSbrElementLocation(FBT176Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410140"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.410147

        /*  VR.ATO.GEN.410147
            Name Type Code must be present if Name of the Interposed Entity is present.

        Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT152 = BLANK)

        Data Elements:

        ^FBT152 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalNameType.Code WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']

        ^OrganisationNameDetails = RP:ControllingParty:OrganisationNameDetails
        */
                    assertion = (ControllingParty_OrganisationNameDetailsCollection_MN_C_RPExists != false && string.IsNullOrWhiteSpace(FBT152) == true);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.410147", Severity = ProcessMessageSeverity.Error,
                            Description = @"Name Type Code must be present if Name of the Interposed Entity is present.",
                            Location = FBT152Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:OrganisationNameDetails.OrganisationalNameType.Code" : DeriveSbrElementLocation(FBT152Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410147"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPControllingParty_PersonNameDetailsCollection1
        protected virtual void ValidateRPControllingParty_PersonNameDetailsCollection1(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPControllingParty_OrganisationNameDetailsCollection1
        protected virtual void ValidateRPControllingParty_OrganisationNameDetailsCollection1(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPPersonNameDetailsCollection
        protected virtual void ValidateRPPersonNameDetailsCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                    bool PersonNameDetailsCollection_LGL_Identifier_C_RPExists = true;

                    SBRElement FBT226Value = null;
                    string FBT226 = null;

                    SBRElement FBT12Value = null;
                    string FBT12 = null;

                    SBRElement FBT181Value = null;
                    string FBT181 = null;
                    SBRElement FBT182Value = null;
                    string FBT182 = null;
                    SBRElement FBT11Value = null;
                    string FBT11 = null;
                    SBRElement FBT13Value = null;
                    string FBT13 = null;
                    SBRElement FBT14Value = null;
                    string FBT14 = null;
                    SBRElement FBT15Value = null;
                    string FBT15 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Usage.Code", out FBT226Value))
                    {
                        if (!FBT226Value.IsNil) FBT226 = FBT226Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.FamilyName.Text", out FBT12Value))
                    {
                        if (!FBT12Value.IsNil) FBT12 = FBT12Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.PersonNameType.Code", out FBT181Value))
                    {
                        if (!FBT181Value.IsNil) FBT181 = FBT181Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Currency.Code", out FBT182Value))
                    {
                        if (!FBT182Value.IsNil) FBT182 = FBT182Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.Title.Text", out FBT11Value))
                    {
                        if (!FBT11Value.IsNil) FBT11 = FBT11Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.NameSuffix.Text", out FBT13Value))
                    {
                        if (!FBT13Value.IsNil) FBT13 = FBT13Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.GivenName.Text", out FBT14Value))
                    {
                        if (!FBT14Value.IsNil) FBT14 = FBT14Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}PersonNameDetails.OtherGivenName.Text", out FBT15Value))
                    {
                        if (!FBT15Value.IsNil) FBT15 = FBT15Value.Value;
                    }
        
                    #region VR.ATO.FBT.000452

        /*  VR.ATO.FBT.000452
            Employer Current Contact Person Name Usage code is invalid. It must be "Contact" or ""Identifier"

        Legacy Rule Format:
            IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails)
            IF pyde.xx.xx:PersonNameDetails.Usage.Code <> SET("Identifier", "Contact")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND (NotInSet(^FBT226, '"Identifier", "Contact"'))

        Data Elements:

        ^FBT226 = RP:PersonNameDetails:PersonNameDetails.Usage.Code WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']

        ^PersonNameDetails = RP:PersonNameDetails
        */
                    assertion = (PersonNameDetailsCollection_LGL_Identifier_C_RPExists != false && !(IsMatch(FBT226, @"^(Identifier|Contact)$",RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000452", Severity = ProcessMessageSeverity.Error,
                            Description = @"Person Name Usage code is invalid. It must be either ""Identifier"" or ""Contact"".",
                            Location = FBT226Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonNameDetails.Usage.Code" : DeriveSbrElementLocation(FBT226Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000452"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.000462

        /*  VR.ATO.GEN.000462
            Person Name Type Code must be "LGL"

        Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.PersonNameType.Code <> "LGL")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT12 <> BLANK) AND (^FBT181 <> 'LGL')

        Data Elements:

        ^FBT181 = RP:PersonNameDetails:PersonNameDetails.PersonNameType.Code WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']

        ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT12) != true && FBT181 != @"LGL");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.000462", Severity = ProcessMessageSeverity.Error,
                            Description = @"Person Name Type Code must be ""LGL""",
                            Location = FBT181Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonNameDetails.PersonNameType.Code" : DeriveSbrElementLocation(FBT181Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000462"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.410216

        /*  VR.ATO.GEN.410216
            Person NameType code must be present

        Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails)
            IF (pyde.xx.xx:PersonNameDetails.PersonNameType.Code = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND (^FBT181 = BLANK)

        Data Elements:

        ^FBT181 = RP:PersonNameDetails:PersonNameDetails.PersonNameType.Code WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']

        ^PersonNameDetails = RP:PersonNameDetails
        */
                    assertion = (PersonNameDetailsCollection_LGL_Identifier_C_RPExists != false && string.IsNullOrWhiteSpace(FBT181) == true);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.410216", Severity = ProcessMessageSeverity.Error,
                            Description = @"Person NameType code must be present",
                            Location = FBT181Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:PersonNameDetails.PersonNameType.Code" : DeriveSbrElementLocation(FBT181Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410216"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPOrganisationNameDetailsCollection
        protected virtual void ValidateRPOrganisationNameDetailsCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT16Value = null;
                    string FBT16 = null;

                    SBRElement FBT183Value = null;
                    string FBT183 = null;
                    bool OrganisationNameDetailsCollection_MN_C_RPExists = true;

                    SBRElement FBT177Value = null;
                    string FBT177 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalName.Text", out FBT16Value))
                    {
                        if (!FBT16Value.IsNil) FBT16 = FBT16Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.OrganisationalNameType.Code", out FBT183Value))
                    {
                        if (!FBT183Value.IsNil) FBT183 = FBT183Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}OrganisationNameDetails.Currency.Code", out FBT177Value))
                    {
                        if (!FBT177Value.IsNil) FBT177 = FBT177Value.Value;
                    }
        
                    #region VR.ATO.GEN.000465

        /*  VR.ATO.GEN.000465
            Organisation name type code must be "MN" or "MTR"

        Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK)
            AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code <> SET("MN","MTR"))
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT16 <> BLANK) AND (NotInSet(^FBT183, '"MN","MTR"'))

        Data Elements:

        ^FBT183 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalNameType.Code WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']

        ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT16) != true && !(IsMatch(FBT183, @"^(MN|MTR)$",RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.000465", Severity = ProcessMessageSeverity.Error,
                            Description = @"Organisation name type code must be ""MN"" or ""MTR""",
                            Location = FBT183Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:OrganisationNameDetails.OrganisationalNameType.Code" : DeriveSbrElementLocation(FBT183Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000465"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.410140

        /*  VR.ATO.GEN.410140
            Organisation Name Currency Code must be present

        Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.Currency.Code = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT177 = BLANK)

        Data Elements:

        ^FBT177 = RP:OrganisationNameDetails:OrganisationNameDetails.Currency.Code WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']

        ^OrganisationNameDetails = RP:OrganisationNameDetails
        */
                    assertion = (OrganisationNameDetailsCollection_MN_C_RPExists != false && string.IsNullOrWhiteSpace(FBT177) == true);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.410140", Severity = ProcessMessageSeverity.Error,
                            Description = @"Organisation Name Currency Code must be present",
                            Location = FBT177Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:OrganisationNameDetails.Currency.Code" : DeriveSbrElementLocation(FBT177Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410140"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.410147

        /*  VR.ATO.GEN.410147
            Name Type Code must be present if Name of the Interposed Entity is present.

        Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT183 = BLANK)

        Data Elements:

        ^FBT183 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalNameType.Code WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']

        ^OrganisationNameDetails = RP:OrganisationNameDetails
        */
                    assertion = (OrganisationNameDetailsCollection_MN_C_RPExists != false && string.IsNullOrWhiteSpace(FBT183) == true);
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.410147", Severity = ProcessMessageSeverity.Error,
                            Description = @"Name Type Code must be present if Name of the Interposed Entity is present.",
                            Location = FBT183Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:OrganisationNameDetails.OrganisationalNameType.Code" : DeriveSbrElementLocation(FBT183Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410147"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPAddressDetailsCollection
        protected virtual void ValidateRPAddressDetailsCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT17Value = null;
                    string FBT17 = null;

                    SBRElement FBT154Value = null;
                    string FBT154 = null;

                    SBRElement FBT153Value = null;
                    string FBT153 = null;
                    SBRElement FBT25Value = null;
                    bool? FBT25 = null;
                    SBRElement FBT18Value = null;
                    string FBT18 = null;
                    SBRElement FBT19Value = null;
                    string FBT19 = null;
                    SBRElement FBT20Value = null;
                    string FBT20 = null;
                    SBRElement FBT21Value = null;
                    string FBT21 = null;
                    SBRElement FBT23Value = null;
                    string FBT23 = null;
                    SBRElement FBT22Value = null;
                    string FBT22 = null;
                    SBRElement FBT24Value = null;
                    string FBT24 = null;
                    SBRElement FBT222Value = null;
                    string FBT222 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line1.Text", out FBT17Value))
                    {
                        if (!FBT17Value.IsNil) FBT17 = FBT17Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Usage.Code", out FBT154Value))
                    {
                        if (!FBT154Value.IsNil) FBT154 = FBT154Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Currency.Code", out FBT153Value))
                    {
                        if (!FBT153Value.IsNil) FBT153 = FBT153Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.OverseasAddress.Indicator", out FBT25Value))
                    {
                        if (!FBT25Value.IsNil) FBT25 = ToBoolean(FBT25Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line2.Text", out FBT18Value))
                    {
                        if (!FBT18Value.IsNil) FBT18 = FBT18Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line3.Text", out FBT19Value))
                    {
                        if (!FBT19Value.IsNil) FBT19 = FBT19Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Line4.Text", out FBT20Value))
                    {
                        if (!FBT20Value.IsNil) FBT20 = FBT20Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.LocalityName.Text", out FBT21Value))
                    {
                        if (!FBT21Value.IsNil) FBT21 = FBT21Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Postcode.Text", out FBT23Value))
                    {
                        if (!FBT23Value.IsNil) FBT23 = FBT23Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.StateOrTerritory.Code", out FBT22Value))
                    {
                        if (!FBT22Value.IsNil) FBT22 = FBT22Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.CountryName.Text", out FBT24Value))
                    {
                        if (!FBT24Value.IsNil) FBT24 = FBT24Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}AddressDetails.Country.Code", out FBT222Value))
                    {
                        if (!FBT222Value.IsNil) FBT222 = FBT222Value.Value;
                    }
        
                    #region VR.ATO.GEN.000467

        /*  VR.ATO.GEN.000467
            Address usage code must be "POS" or "BUS"

        Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text <> NULLORBLANK)
            AND (pyde.xx.xx:AddressDetails.Usage.Code <> SET("POS","BUS"))
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT17 <> BLANK) AND (NotInSet(^FBT154, '"POS","BUS"'))

        Data Elements:

        ^FBT154 = RP:AddressDetails:AddressDetails.Usage.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']

        ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT17) != true && !(IsMatch(FBT154, @"^(POS|BUS)$",RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.000467", Severity = ProcessMessageSeverity.Error,
                            Description = @"Address usage code must be ""POS"" or ""BUS""",
                            Location = FBT154Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:AddressDetails.Usage.Code" : DeriveSbrElementLocation(FBT154Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000467"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.GEN.428202

        /*  VR.ATO.GEN.428202
            Address currency code must be "C" or "P"

        Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Currency.Code <> NULLORBLANK)
            AND (pyde.xx.xx:AddressDetails.Currency.Code <> SET("C","P"))
             RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT153 <> BLANK) AND (NotInSet(^FBT153, '"C","P"'))

        Data Elements:

        ^FBT153 = RP:AddressDetails:AddressDetails.Currency.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
        */
                    assertion = (string.IsNullOrWhiteSpace(FBT153) != true && !(IsMatch(FBT153, @"^(C|P)$",RegexOptions.IgnoreCase)));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.428202", Severity = ProcessMessageSeverity.Error,
                            Description = @"Address currency code must be ""C"" or ""P""",
                            Location = FBT153Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:AddressDetails.Currency.Code" : DeriveSbrElementLocation(FBT153Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428202"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPPersonNameDetailsCollection1
        protected virtual void ValidateRPPersonNameDetailsCollection1(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPOrganisationNameDetailsCollection1
        protected virtual void ValidateRPOrganisationNameDetailsCollection1(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPAddressDetailsCollection1
        protected virtual void ValidateRPAddressDetailsCollection1(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPOrganisationNameDetailsCollection2
        protected virtual void ValidateRPOrganisationNameDetailsCollection2(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPAddressDetailsCollection2
        protected virtual void ValidateRPAddressDetailsCollection2(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPPersonNameDetailsCollection2
        protected virtual void ValidateRPPersonNameDetailsCollection2(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPElectronicContactTelephoneCollection
        protected virtual void ValidateRPElectronicContactTelephoneCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                    bool ElectronicContactTelephoneCollection_03_RPExists = true;

                    SBRElement FBT61Value = null;
                    string FBT61 = null;

                    SBRElement FBT134Value = null;
                    string FBT134 = null;

                    SBRElement FBT135Value = null;
                    string FBT135 = null;
                    SBRElement FBT60Value = null;
                    string FBT60 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Minimal.Number", out FBT61Value))
                    {
                        if (!FBT61Value.IsNil) FBT61 = FBT61Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Usage.Code", out FBT134Value))
                    {
                        if (!FBT134Value.IsNil) FBT134 = FBT134Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.ServiceLine.Code", out FBT135Value))
                    {
                        if (!FBT135Value.IsNil) FBT135 = FBT135Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.Telephone.Area.Code", out FBT60Value))
                    {
                        if (!FBT60Value.IsNil) FBT60 = FBT60Value.Value;
                    }
        
                    #region VR.ATO.GEN.432016

        /*  VR.ATO.GEN.432016
            Telephone must include number, usage code '03' and service line code '01' or '02'.

        Legacy Rule Format:
            WHERE IN TUPLE(electroniccontacttelephone1.xx.xx:ElectronicContactTelephone)
            IF pyde.xx.xx:ElectronicContact.Telephone.Minimal.Number = NULL OR pyde.xx.xx:ElectronicContact.Telephone.Usage.Code <> "03" OR pyde.xx.xx:Electronic Contact.Telephone.ServiceLine.Code <> SET ("01", "02")
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^ElectronicContactTelephone <> NULL) AND (^FBT61 = NULL OR ^FBT134 <> '03' OR NotInSet(^FBT135, '"01", "02"'))

        Data Elements:

        ^FBT61 = RP:ElectronicContactTelephone:ElectronicContact.Telephone.Minimal.Number WHERE [ElectronicContact.Telephone.Usage.Code='03']

        ^FBT134 = RP:ElectronicContactTelephone:ElectronicContact.Telephone.Usage.Code WHERE [ElectronicContact.Telephone.Usage.Code='03']

        ^FBT135 = RP:ElectronicContactTelephone:ElectronicContact.Telephone.ServiceLine.Code WHERE [ElectronicContact.Telephone.Usage.Code='03']

        ^ElectronicContactTelephone = RP:ElectronicContactTelephone
        */
                    assertion = (ElectronicContactTelephoneCollection_03_RPExists != false && (FBT61 == null || FBT134 != @"03" || !(IsMatch(FBT135, @"^(01|02)$",RegexOptions.IgnoreCase))));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.432016", Severity = ProcessMessageSeverity.Error,
                            Description = @"Telephone must include number, usage code '03' and service line code '01' or '02'.",
                            LongDescription = @"A telephone must include the number, a usage code of '03' - contact, and a service line code of '01' - Mobile or '02' - Landline or fixed line. An two digit area code should be provided for a landline.",
                            Location = FBT61Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:ElectronicContact.Telephone.Minimal.Number" : DeriveSbrElementLocation(FBT61Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432016"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT61", Value = FBT61 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT134", Value = FBT134 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT135", Value = FBT135 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPElectronicContactElectronicMailCollection
        protected virtual void ValidateRPElectronicContactElectronicMailCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                    bool ElectronicContactElectronicMailCollection_03_RPExists = true;

                    SBRElement FBT62Value = null;
                    string FBT62 = null;

                    SBRElement FBT133Value = null;
                    string FBT133 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.ElectronicMail.Address.Text", out FBT62Value))
                    {
                        if (!FBT62Value.IsNil) FBT62 = FBT62Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}ElectronicContact.ElectronicMail.Usage.Code", out FBT133Value))
                    {
                        if (!FBT133Value.IsNil) FBT133 = FBT133Value.Value;
                    }
        
                    #region VR.ATO.GEN.436276

        /*  VR.ATO.GEN.436276
            Email address must include an address and a usage code '03'

        Legacy Rule Format:
            WHERE IN TUPLE(ElectronicContactElectronicMail1.xx.xx:ElectronicContactElectronicMail)
            IF (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text = NULLORBLANK) OR (pyde.xx.xx:ElectronicContact.ElectronicMail.Usage.Code <> "03") 
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^ElectronicContactElectronicMail <> NULL) AND ((^FBT62 = BLANK) OR (^FBT133 <> '03'))

        Data Elements:

        ^FBT133 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Usage.Code WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']

        ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']

        ^ElectronicContactElectronicMail = RP:ElectronicContactElectronicMail
        */
                    assertion = (ElectronicContactElectronicMailCollection_03_RPExists != false && (string.IsNullOrWhiteSpace(FBT62) == true || FBT133 != @"03"));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.436276", Severity = ProcessMessageSeverity.Error,
                            Description = @"Email address must include an address and a usage code '03'",
                            Location = FBT133Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:ElectronicContact.ElectronicMail.Usage.Code" : DeriveSbrElementLocation(FBT133Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.436276"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT62", Value = FBT62 });
        
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT133", Value = FBT133 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT192Value = null;
                    decimal? FBT192 = null;

                    SBRElement FBT136Value = null;
                    string FBT136 = null;

                    SBRElement FBT80Value = null;
                    decimal? FBT80 = null;

                    SBRElement FBT78Value = null;
                    decimal? FBT78 = null;
                    SBRElement FBT79Value = null;
                    decimal? FBT79 = null;
                    SBRElement FBT81Value = null;
                    decimal? FBT81 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Reduction.Amount", out FBT192Value))
                    {
                        if (!FBT192Value.IsNil) FBT192 = decimal.Parse(FBT192Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.Type.Code", out FBT136Value))
                    {
                        if (!FBT136Value.IsNil) FBT136 = FBT136Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.EmployeeContribution.Amount", out FBT80Value))
                    {
                        if (!FBT80Value.IsNil) FBT80 = decimal.Parse(FBT80Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.ItemsProvided.Number", out FBT78Value))
                    {
                        if (!FBT78Value.IsNil) FBT78 = decimal.Parse(FBT78Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitGrossTaxable.Amount", out FBT79Value))
                    {
                        if (!FBT79Value.IsNil) FBT79 = decimal.Parse(FBT79Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Remuneration.FringeBenefits.BenefitNetTaxable.Amount", out FBT81Value))
                    {
                        if (!FBT81Value.IsNil) FBT81 = decimal.Parse(FBT81Value.Value);
                    }
        
                    #region VR.ATO.FBT.000396

        /*  VR.ATO.FBT.000396
            Value of reductions is not required for this Fringe Benefits type

        Legacy Rule Format:
            IF (lrla.xx.xx:Remuneration.Fringe Benefits.Reduction.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.Type.Code = SET("A","B","D","F","L","N","P"))
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT192 <> BLANK) AND (InSet(^FBT136, '"A","B","D","F","L","N","P"'))

        Data Elements:

        ^FBT192 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']

        ^FBT136 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='A']
        */
                    assertion = (FBT192 != null && IsMatch(FBT136, @"^(A|B|D|F|L|N|P)$"));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000396", Severity = ProcessMessageSeverity.Error,
                            Description = @"Value of reductions is not required for this Fringe Benefits type",
                            Location = FBT192Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:Remuneration.FringeBenefits.Reduction.Amount" : DeriveSbrElementLocation(FBT192Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000396"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.FBT.000398

        /*  VR.ATO.FBT.000398
            Employee contribution is not required for this Fringe benefits type

        Legacy Rule Format:
            IF (lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.Type.Code = SET("C","D","G","L","P"))
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT80 <> BLANK) AND (InSet(^FBT136, '"C","D","G","L","P"'))

        Data Elements:

        ^FBT80 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']

        ^FBT136 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='A']
        */
                    assertion = (FBT80 != null && IsMatch(FBT136, @"^(C|D|G|L|P)$"));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000398", Severity = ProcessMessageSeverity.Error,
                            Description = @"Employee contribution is not required for this Fringe benefits type",
                            Location = FBT80Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount" : DeriveSbrElementLocation(FBT80Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000398"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
        
                    #region VR.ATO.FBT.000399

        /*  VR.ATO.FBT.000399
            Number is not required for this Fringe Benefits type

        Legacy Rule Format:
            IF (lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.Type.Code = SET("D","E","J","K","L","M","N","P"))
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            (^FBT78 <> BLANK) AND (InSet(^FBT136, '"D","E","J","K","L","M","N","P"'))

        Data Elements:

        ^FBT78 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='A']

        ^FBT136 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='A']
        */
                    assertion = (FBT78 != null && IsMatch(FBT136, @"^(D|E|J|K|L|M|N|P)$"));
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.FBT.000399", Severity = ProcessMessageSeverity.Error,
                            Description = @"Number is not required for this Fringe Benefits type",
                            Location = FBT78Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number" : DeriveSbrElementLocation(FBT78Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000399"} },
                        };
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection1
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection1(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection2
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection2(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection3
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection3(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection4
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection4(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection5
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection5(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection6
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection6(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection7
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection7(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection8
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection8(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection9
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection9(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection10
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection10(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection11
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection11(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPProvidedFringeBenefitsDetailsCollection12
        protected virtual void ValidateRPProvidedFringeBenefitsDetailsCollection12(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;
                }
            }
        }
        #endregion

        #region ValidateRPDeclarationCollection
        protected virtual void ValidateRPDeclarationCollection(List<ProcessMessageDocument> errors, IEnumerable<SBRElement> tupleCollection, IEnumerable<SBRContext> contexts, FBT2018 report)
        {
            bool assertion;
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            HashSet<string> alreadyChecked = new HashSet<string>();

            if (tupleCollection != null)
            {
                foreach (SBRElement tupleElement in tupleCollection)
                {
                    //Only check this for the RP Context exit out otherwise
                     if (tupleElement.ChildElements == null || tupleElement.ChildElements.Count == 0 || contexts == null || !contexts.Contains(tupleElement.ChildElements[0].Context))
                        continue;

                    IDictionary<string, SBRElement> tupleElementMap = tupleElement.PopulatedChildElementsMap;

                    SBRElement FBT185Value = null;
                    string FBT185 = null;
                    SBRElement FBT215Value = null;
                    bool? FBT215 = null;
                    SBRElement FBT214Value = null;
                    DateTime? FBT214 = null;
                    SBRElement FBT213Value = null;
                    string FBT213 = null;

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementType.Code", out FBT185Value))
                    {
                        if (!FBT185Value.IsNil) FBT185 = FBT185Value.Value;
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.StatementAccepted.Indicator", out FBT215Value))
                    {
                        if (!FBT215Value.IsNil) FBT215 = ToBoolean(FBT215Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.Signature.Date", out FBT214Value))
                    {
                        if (!FBT214Value.IsNil) FBT214 = DateTime.Parse(FBT214Value.Value);
                    }

                    if (tupleElementMap.TryGetValue("{http://www.sbr.gov.au/ato/fbt}Declaration.SignatoryIdentifier.Text", out FBT213Value))
                    {
                        if (!FBT213Value.IsNil) FBT213 = FBT213Value.Value;
                    }
        
                    #region VR.ATO.GEN.438062

        /*  VR.ATO.GEN.438062
            If an Intermediary is not present, Reporting Party Declaration Statement Type Code must be supplied and must be “TrueAndCorrect”.

        Legacy Rule Format:
            IF INT=NULL AND RP:pyin.xx.xx:Declaration.StatementType.Code <> "TrueAndCorrect"
               RETURN VALIDATION MESSAGE
            ENDIF
    
        Technical Business Rule Format:
            ^INT = NULL AND ^FBT185 <> 'TrueAndCorrect'

        Data Elements:

        ^FBT185 = RP:Declaration:Declaration.StatementType.Code WHERE [Declaration.StatementType.Code='TrueAndCorrect']

        ^INT = INT
        */
                    assertion = (report.INTExists == false && FBT185 != @"TrueAndCorrect");
                    if (assertion)
                    {
                        processMessage = new ProcessMessageDocument()
                        {
                            Code = "CMN.ATO.GEN.438062", Severity = ProcessMessageSeverity.Error,
                            Description = @"Declaration statement type code is required.",
                            LongDescription = @"If an Intermediary is not present, Reporting Party Declaration Statement Type Code must be supplied and must be ""TrueAndCorrect"".",
                            Location = FBT185Value == null ? DeriveSbrElementLocation(tupleElement, true) + "/tns:Declaration.StatementType.Code" : DeriveSbrElementLocation(FBT185Value),
                            Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438062"} },
                        };
                    processMessage.Parameters.Add(new ProcessMessageParameter
                        { Name = "FBT185", Value = FBT185 });
        
                        errors.Add(processMessage);
                    }
                    #endregion
                }
            }
        }
        #endregion

    } // Of Class
} // Of Namespace

