using System;
using System.Collections.Generic;
using System.Linq;
using System.Xml;
using System.Text.RegularExpressions;
using Au.Gov.Sbr.Xbrl.Document;
using DataContracts;
using Au.Gov.Sbr.Xbrl.Metadata;
using System.Runtime.CompilerServices;

namespace Ato.EN.IntegrationServices.CodeGenerationFBT
{

    public partial class FBT2020Validator
    {
        /// <summary>
        /// The max parameter name length is restricted by the SBR1 and SBR2 schemas - the lowest common denominator of SBR 1 is used as the default
        /// </summary>
        private int _maxParameterNameLength;

        /// <summary>
        /// The max parameter value length is restricted by the SBR1 and SBR2 schemas
        /// </summary>
        private int _maxParameterValueLength;

        /// <summary>
        /// The SBR1 and ebms3 schemas do not allow parameter names or values to be the empty string
        /// </summary>
        private string _emptyParameterValue;

        /// <summary>
        /// Initializes a new instance of the <see cref="FBT2020Validator" /> class.
        /// </summary>
        /// <param name="maxParameterNameLength">Maximum length of the parameter name.</param>
        /// <param name="maxParameterValueLength">Maximum length of the parameter value.</param>
        /// <param name="emptyParameterValue">This value will be used in place of any parameter values that result in a null or empty value.</param>
        public FBT2020Validator(int maxParameterNameLength = 20, int maxParameterValueLength = 4096, string emptyParameterValue = "EMPTY")
        {
            _maxParameterNameLength = maxParameterNameLength;
            _maxParameterValueLength = maxParameterValueLength;
            _emptyParameterValue = emptyParameterValue;
        }

        #region Functions
        private static IEnumerable<string> Union(IEnumerable<string> list1, IEnumerable<string> list2)
        {
            IEnumerable<string> response;

            if (list1 == null && list2 == null)
            {
                response = null;
            }
            else if (list1 == null)
            {
                response = list2.Distinct();
            }
            else if (list2 == null)
            {
                response = list1.Distinct();
            }
            else
            {
                response = list1.Union(list2);
            }

            return response;
        }

        private static bool IsMatch(int? field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(Convert.ToString(field.Value), expression, options);
        }

        private static bool IsMatch(string field, string expression, RegexOptions options = RegexOptions.None)
        {
            if (field == null)
                return false;
            else
                return Regex.IsMatch(field, expression, options);
        }

        // This is just context and tuple counts where they are integer values - easier that changing the parsing logic to just return the value
        private static int Count(int count)
        {
            return count;
        }


        private static int Count<T>(IEnumerable<T> values)
        {
            return values == null ? 0 : values.Where(f => f != null).Count();
        }


        private static int Count<T>(ICollection<T> values)
        {
            return values == null ? 0 : values.Where(f => f != null).Count();
        }


        private static bool exists(bool value)
        {
            return value;
        }

        private static string GetValueOrEmpty(bool? val)
        {
            return (val.HasValue) ? val.ToString().ToLower() : string.Empty;
        }

        private static string GetValueOrEmpty(DateTime? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        private static string GetValueOrEmpty(string val)
        {
            return !string.IsNullOrWhiteSpace(val) ? val : string.Empty;
        }

        private static string GetValueOrEmpty(decimal? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

        private static string GetValueOrEmpty(int? val)
        {
            return (val.HasValue) ? val.ToString() : string.Empty;
        }

         /// <summary>
         /// Get string value between [first] a and [last] b.
         /// </summary>
        public static string Between(string value, string a, string b)
        {
            int posA = value.IndexOf(a);
            int posB = value.LastIndexOf(b);
            if (posA == -1)
            {
                return "";
            }
            if (posB == -1)
            {
                return "";
            }
            int adjustedPosA = posA + a.Length;
            if (adjustedPosA >= posB)
            {
                return "";
            }
            return value.Substring(adjustedPosA, posB - adjustedPosA);
        }

         /// <summary>
         /// Get string value after [first] a.
         /// </summary>
        public static string Before(string value, string a)
        {
            int posA = value.IndexOf(a);
            if (posA == -1)
            {
                return "";
            }
            return value.Substring(0, posA);
        }

         /// <summary>
         /// Get string value after [last] a.
         /// </summary>
        public static string After(string value, string a)
        {
            int posA = value.LastIndexOf(a);
            if (posA == -1)
            {
                return "";
            }
            int adjustedPosA = posA + a.Length;
            if (adjustedPosA >= value.Length)
            {
                return "";
            }
            return value.Substring(adjustedPosA);
        }

        private static int Length(object field)
        {
            if (field == null)
            return 0;
            else
            return field.ToString().Trim().Length;
        }

        private static bool NotSameValues(IEnumerable<object> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return NotSameValues(nodesArray);
        }

        private static bool NotSameValues(params object[] nodes)
        {
            if (nodes == null)
                return false;

            return (from x in nodes select x).Distinct().Count() != 1;
        }

        private static bool HasDuplicateValues(IEnumerable<object> nodes)
        {
            if (nodes == null)
                return false;

            object[] nodesArray = nodes.Cast<object>().ToArray();
            return HasDuplicateValues(nodesArray);
        }

        private static bool HasDuplicateValues(params object[] nodes)
        {
           if (nodes == null)
                return false;

            nodes = nodes.Where(x => x != null).ToArray();
            return !((from x in nodes select x).Distinct().Count() == nodes.Count());
        
        }

        private int DuplicateValueIndex(IEnumerable<object> values)
        {
            int response = 0;
            var hashset = new HashSet<object>();
            foreach (var value in values)
            {
                if (!hashset.Add(value))
                {
                    return response;
                }
                response++;
            }
            return response;
        }

        private int DuplicateValueIndex<T>(IEnumerable<T?> values) where T : struct
        {
            int response = 0;
            var hashset = new HashSet<T?>();
            foreach (var value in values)
            {
                if (!hashset.Add(value))
                {
                    return response;
                }
                response++;
            }
            return response;
        }

        private static bool IsDate(object value)
        {
            DateTime dateValue;
            return (value != null && DateTime.TryParse(value.ToString(), out dateValue));
        }

        public DateTime AsDate(string dateAsString)
        {
            DateTime response = DateTime.MinValue;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date;
            }

            return response;
        }

        public DateTime Date(DateTime? datetime)
        {                   
            return datetime.GetValueOrDefault().Date;
        }

				//The logic in After function expects "---" for day and "--" for month. 
				//Since hyphen was missing the date always returned null
        public DateTime? ConvertToDate(int day, int month, int year)
        {
					return ConvertToDate(day == 0 ? null : "---" + day.ToString(), month == 0 ? null : "--" + month.ToString(), year == 0 ? null : year.ToString());
        }

        public DateTime? ConvertToDate(string day, string month, string year)
        {
            DateTime? response;
            DateTime result;

            if (year == null || month == null || day == null)
            {
                return null;
            }
            string dateAsString = year + "-" + After(month, "--") + "-" + After(day, "---");
            if (DateTime.TryParse(dateAsString, out result))
            {
                response = result;
            }
            else
            {
                response = null;
            }
            return response;
        }


        public DateTime? ConvertToDate(string day, string month, int year)
        {
            DateTime? response;
            DateTime result;

            if (year == 0 || month == null || day == null)
            {
                return null;
            }
            string dateAsString = year.ToString() + "-" + After(month, "--") + "-" + After(day, "---");
            if (DateTime.TryParse(dateAsString, out result))
            {
                response = result;
            }
            else
            {
                response = null;
            }
            return response;
        }


        private static int Day(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Day;
            }

            return response;
        }


        private static int Day(DateTime? date)
        {
            if (date == null)
                return 0;
            else
                return date.Value.Day;

        }


        private static string Month(string dateAsString)
        {
            string response = null;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.ToString("MMMM");
            }
            else
            {
                return "NotAMonth";
            }

            return response;
        }

        private static string Month(DateTime? date)
        {
            if (date == null)
                return "NotAMonth";
            else
                return date.Value.ToString("MMMM");
        }


        private static int MonthAsInt(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Month;
            }

            return response;
        }

        private static int MonthAsInt(DateTime? date)
        {
            if (date == null)
            {
                return 0;
            }
            return date.Value.Month;
        }


        private static int Year(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
            {
                response = date.Year;
            }

            return response;
        }

        private static int Year(DateTime? date)
        {
            if (date == null)
                return 0;
            else
                return date.Value.Year;
        }


        private static int CurrentFinancialYear()
        {
            return DateToFinancialYear(DateTime.Now, 7);
        }

        private static int FinancialYear(string dateAsString)
        {
            return DateToFinancialYear(dateAsString, 7);
        }

        private static int FinancialYear(DateTime? date)
        {
            return DateToFinancialYear(date, 7);
        }

        private static int DateToFinancialYear(string dateAsString, int startingMonth)
        {
            int response = 0;
            DateTime date;
            if (DateTime.TryParse(dateAsString, out date))
            {
                response = DateToFinancialYear(date, startingMonth);
            }

            return response;
        }
        private static int DateToFinancialYear(DateTime? date, int startingMonth)
        {
            int response;
            if (date == null)
            {
                response = 0;
            }
            else
            {
                int year = date.Value.Year;
                int month = date.Value.Month;

                if (startingMonth > month)
                    response = year;
                else
                    response = year + 1;
            }
            return response;
        }


        private static int FBTYear(string dateAsString)
        {
            int response = 0;
            DateTime date;

            if (DateTime.TryParse(dateAsString, out date))
                response = FBTYear(date);
            return response;
        }

        private static int FBTYear(DateTime? date)
        {
            if (date == null)
            {
                return 0;
            }
            else
            {
                if (date.Value.Month > 3)
                    return date.Value.Year + 1;
                else
                    return date.Value.Year;
            }
        }

        private static DateTime? AddMonthsToDate(DateTime? dateTime, int months)
        {
            return dateTime == null ? null : (DateTime?)dateTime.Value.AddMonths(months);
        }

        private static bool IsNumeric(object value)
        {
            decimal numbervalue;
            return (value != null && decimal.TryParse(value.ToString(), out numbervalue));
        }

        private static bool NotMonetary(decimal? field, string sign, int digits, int decimals)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;
                string decimalExpression;
                int digitsToUse = digits - decimals;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                if (decimals > 0)
                    decimalExpression = @"(\.\d{1," + decimals + "})?$";
                else
                    decimalExpression = @"$";

                return !(Regex.IsMatch(field.Value.ToString("0.#########################"), signExpression + @"\d{1," + digitsToUse + "}" + decimalExpression));
            }
        }

        private static bool NotNumeric(decimal? field, string sign, int digits, int decimals)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;
                string decimalExpression;
                int digitsToUse = digits - decimals;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                if (decimals > 0)
                    decimalExpression = @"(\.\d{1," + decimals + "})?$";
                else
                    decimalExpression = @"$";

                return !(Regex.IsMatch(field.Value.ToString("0.#########################"), signExpression + @"\d{1," + digitsToUse + "}" + decimalExpression));
            }
        }

        private static bool NotNumeric(int? field, string sign, int digits, int decimals = 0)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                return !(Regex.IsMatch(field.Value.ToString(), signExpression + @"\d{1," + digits + "}$"));
            }
        }

        private static bool NotNumeric(long? field, string sign, int digits, int decimals = 0)
        {
            if (field == null)
            {
                return false;
            }
            else
            {
                string signExpression;

                if (sign == "U")
                    signExpression = "^";
                else
                    signExpression = "^-?";

                return !(Regex.IsMatch(field.Value.ToString(), signExpression + @"\d{1," + digits + "}$"));
            }
        }


        private static bool OutsideRange(decimal field, decimal expression, int range)
        {
            bool response;

            response = (field < (expression - range)) || (field > (expression + range));

            return response;
        }


        private static bool FailsUSIAlgorithm(string usi, string abn)
        {
            bool response = true;
            if (usi == null || abn == null)
            {
                response = false;
            }
            else
            {
                usi = usi.Trim();
                abn = abn.Trim();
                if (usi.Length == 14)
                {
                    int numeric;
                    if (usi.Substring(0, 11) == abn && int.TryParse(usi.Substring(11, 3), out numeric))
                        response = false;

                }
                else if (usi.Length == 9)
                {

                    if (Regex.IsMatch(usi, @"^([a-zA-Z]{3}\d{4}[a-zA-Z]{2})$"))
                        response = false;
                }
            }
            return response;
        }

        private static bool FailsTANAlgorithm(string tan)
        {
            bool response;
            decimal decimalTan;

            if (tan == null)
                return false;

            tan = tan.Trim();

            if (!decimal.TryParse(tan, out decimalTan))
                return true;

            if (tan.Length != 8)
                return true;

            decimal tanSum =
                7 * int.Parse(tan.Substring(0, 1)) +
                9 * int.Parse(tan.Substring(1, 1)) +
                8 * int.Parse(tan.Substring(2, 1)) +
                4 * int.Parse(tan.Substring(3, 1)) +
                6 * int.Parse(tan.Substring(4, 1)) +
                3 * int.Parse(tan.Substring(5, 1)) +
                5 * int.Parse(tan.Substring(6, 1)) +
                1 * int.Parse(tan.Substring(7, 1));

            if ((tanSum % 11) == 0)
                response = false;
            else
                response = true;

            return response;
        }


        private static bool FailsABNAlgorithm(string abn)
        {
            bool response;
            decimal decimalAbn;

            if (abn == null)
                return false;

            abn = abn.Trim();

            if (!decimal.TryParse(abn, out decimalAbn))
                return true;

            if (abn.Length != 11)
                return true;

            decimal abnSum =
                10 * (int.Parse(abn.Substring(0, 1)) - 1) +
                1 * int.Parse(abn.Substring(1, 1)) +
                3 * int.Parse(abn.Substring(2, 1)) +
                5 * int.Parse(abn.Substring(3, 1)) +
                7 * int.Parse(abn.Substring(4, 1)) +
                9 * int.Parse(abn.Substring(5, 1)) +
                11 * int.Parse(abn.Substring(6, 1)) +
                13 * int.Parse(abn.Substring(7, 1)) +
                15 * int.Parse(abn.Substring(8, 1)) +
                17 * int.Parse(abn.Substring(9, 1)) +
                19 * int.Parse(abn.Substring(10, 1));

            if ((abnSum % 89) == 0)
                response = false;
            else
                response = true;

            return response;
        }
        private static bool FailsACNAlgorithm(string acn)
        {
            bool response;
            decimal decimalAbn;
            if (acn == null)
                return false;

            acn = acn.Trim();

            if (!decimal.TryParse(acn, out decimalAbn))
                return true;

            if (acn.Length != 9)
                return true;

            decimal abnSum =
                8 * int.Parse(acn.Substring(0, 1)) +
                7 * int.Parse(acn.Substring(1, 1)) +
                6 * int.Parse(acn.Substring(2, 1)) +
                5 * int.Parse(acn.Substring(3, 1)) +
                4 * int.Parse(acn.Substring(4, 1)) +
                3 * int.Parse(acn.Substring(5, 1)) +
                2 * int.Parse(acn.Substring(6, 1)) +
                1 * int.Parse(acn.Substring(7, 1));

            decimal checkDigit = int.Parse(acn.Substring(8, 1));
            decimal acnRemainder = abnSum % 10;

            if (((10 - acnRemainder) % 10) == checkDigit)
                response = false;
            else
                response = true;

            return response;
        }


        private static bool FailsTFNAlgorithm(string tfn)
        {
            bool response;
            decimal decimalTfn;

            if (tfn == null)
                return false;

            tfn = tfn.Trim();
            tfn = Regex.Replace(tfn, "^0+", "");

            if (!decimal.TryParse(tfn, out decimalTfn))
                return true;

            if (tfn.Length < 8)
                return true;


            decimal tfn1To7Sum =
                1 * int.Parse(tfn.Substring(0, 1)) +
                4 * int.Parse(tfn.Substring(1, 1)) +
                3 * int.Parse(tfn.Substring(2, 1)) +
                7 * int.Parse(tfn.Substring(3, 1)) +
                5 * int.Parse(tfn.Substring(4, 1)) +
                8 * int.Parse(tfn.Substring(5, 1)) +
                6 * int.Parse(tfn.Substring(6, 1));

            decimal tfn8 = 9 * int.Parse(tfn.Substring(7, 1));

            if (tfn.Length == 8)
            {
                decimal tFNLg8WSum9 = 10 * int.Parse(tfn.Substring(7, 1));
                decimal tFNLg8WSum = tfn1To7Sum + tFNLg8WSum9;

                if ((tFNLg8WSum % 11) == 0)
                    response = false;
                else
                    response = true;
            }
            else if (tfn.Length == 9)
            {
                decimal tfn9 = 10 * int.Parse(tfn.Substring(8, 1));
                decimal tFNLg9WSum = tfn1To7Sum + tfn8 + tfn9;

                if ((tFNLg9WSum % 11) == 0)
                    response = false;
                else
                    response = true;
            }
            else
            {
                response = true;
            }

            return response;
        }


        private static decimal ConditionalValue(bool expression, decimal? trueVal, decimal? falseVal)
        {
             return expression ? trueVal.GetValueOrDefault() : falseVal.GetValueOrDefault();
        }

        private static decimal AsNumeric(string value)
        {
             decimal numberValue;
             decimal.TryParse(value, out numberValue);
             return numberValue;
        }

        private static bool RegexMatch(int? field, string expression, string flags="")
        {
            return IsMatch(field, expression, GetRegexOption(flags));
        }

        private static bool RegexMatch(string field, string expression, string flags="")
        {
            return IsMatch(field, expression, GetRegexOption(flags));
        }

        private static RegexOptions GetRegexOption(string flags)
        {
            RegexOptions options = RegexOptions.None;

            char[] characters = flags.ToCharArray();

            foreach (char character in characters)
            {
                switch (character)
                {
                    case 'i':                        
                        options = options | RegexOptions.IgnoreCase;                       
                        break;
                    case 'm':                        
                        options = options | RegexOptions.Multiline;                       
                        break;
                    case 's':                        
                            options = options | RegexOptions.Singleline;                       
                        break;
                    case 'n':                        
                            options = options | RegexOptions.ExplicitCapture;                       
                        break;
                    case 'x':                       
                            options = options | RegexOptions.IgnorePatternWhitespace;                       
                        break;
                }
            }

            return options;
        }

        /// <summary>
        /// Returns an occurrence index as [occurrenceIndex] of occurrenceIndex > 0, otherwise the empty string
        /// </summary>
        /// <param name="occurrenceIndex">Index of the occurrence.</param>
        /// <returns>Occurrence in XPath [#] format</returns>
        public string OccurrenceIndex(int occurrenceIndex)
        {
            return occurrenceIndex > 0 ? "[" + occurrenceIndex + "]" : "";
        }

        #endregion // Functions

        public FBT2018 ConsumedReport { get; private set; }

        private static Dictionary<string, ProcessMessageDocument> _processMessageDocuments = new Dictionary<string,ProcessMessageDocument>();

        [MethodImpl(MethodImplOptions.AggressiveInlining)]
        public List<ProcessMessageDocument> ValidateReport(FBT2018 report)
        {

            List<ProcessMessageDocument> response = new List<ProcessMessageDocument>();
            ProcessMessageDocument processMessage;
            ProcessMessageParameter parameter;
            bool assertion;

            this.ConsumedReport = report;

            // ------------------------------------------------------------------------------
            // Validations are now done in code.
            // This version supports full validation of a report - for those rules that have successfully parsed and could be generated.
            // Generated Validations include:
            //   - Validation logic in C#.
            //   - Production of errors in EBMS, SBR and SWS format.
            // 
            // The generation at this stage does not support the following - and has to be completed manually (later versions of the generation will do this for you)
            //   - Business Rules that did not parse.  The ESR team will help support you where this happens as an effort is being made to rectify these
            //   - You will get TODO tasks for those that the parser could not cope with
            // ------------------------------------------------------------------------------

    
            #region VR.ATO.FBT.000004
    
            /*  VR.ATO.FBT.000004
            Both Controlling party current family name and Non-Individual Name are not provided. One of these names is required
    
            Legacy Rule Format:
            IF (RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE (TUPLE ELEMENT EXPLICIT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT EXPLICIT pyde.xx.xx:PersonNameDetails.Currency.Code = "C") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Usage.Code = "Identifier")) = NULLORBLANK
            AND (RP:pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text WHERE(TUPLE ELEMENT EXPLICIT pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = MN) AND  (TUPLE ELEMENT EXPLICIT pyde.xx.xx:OrganisationNameDetails.Currency.Code = C)) = NULLORBLANK
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^ControllingParty <> NULL) AND ((^FBT6 = BLANK) AND (^FBT10 = BLANK))
    
            Data Elements:
    
            ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
    
            ^ControllingParty = RP:ControllingParty
            */
            assertion = (report.ControllingPartyCollectionExists != false && (string.IsNullOrWhiteSpace(report.FBT6) == true && string.IsNullOrWhiteSpace(report.FBT10) == true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000004", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both Controlling party current family name and Non-Individual Name are not provided. One of these names is required",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000004"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT6", Value = report.FBT6 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000004
    
            #region VR.ATO.FBT.000017
    
            /*  VR.ATO.FBT.000017
            Both Controlling party current family name and Non-Individual Name are present. Only one name is required
    
            Legacy Rule Format:
            WHERE IN TUPLE(fbt.0003.lodge.req.xx.xx:ControllingParty)
            IF (RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE ((TUPLE ELEMENT EXPLICIT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT EXPLICIT pyde.xx.xx:PersonNameDetails.Currency.Code = "C") AND (TUPLE ELEMENT EXPLICIT pyde.xx.xx:PersonNameDetails.Usage.Code = "Identifier")) <> NULLORBLANK) AND (RP:pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text WHERE((TUPLE ELEMENT EXPLICIT pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = "MN") AND (TUPLE ELEMENT EXPLICIT pyde.xx.xx:OrganisationNameDetails.Currency.Code = "C")) <> NULLORBLANK)
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT6 <> BLANK) AND (^FBT10 <> BLANK)
    
            Data Elements:
    
            ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT6) != true && string.IsNullOrWhiteSpace(report.FBT10) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000017", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both Controlling party current family name and Non-Individual Name are present. Only one name is required",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000017"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT6", Value = report.FBT6 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000017
    
            #region VR.ATO.FBT.000069
    
            /*  VR.ATO.FBT.000069
            Both Employers Family Name and Non-Individual Name are present . Only one name is required
    
            Legacy Rule Format:
            WHERE NOT IN TUPLE(fbt.0003.lodge.req.xx.xx:ControllingParty)
            IF ((RP:pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text WHERE(TUPLE ELEMENT pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = "MN") AND (TUPLE ELEMENT pyde.xx.xx:OrganisationNameDetails.Currency.Code = "C")) <> NULLORBLANK)
            AND ((RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE(TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Currency.Code = "C") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Usage.Code = "Identifier")) <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT16 <> BLANK) AND (^FBT12 <> BLANK)
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT16) != true && string.IsNullOrWhiteSpace(report.FBT12) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000069", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both Employers Family Name and Non-Individual Name are present . Only one name is required",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000069"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000069
    
            #region VR.ATO.FBT.000070
    
            /*  VR.ATO.FBT.000070
            Employer Family Name or Non-individual Name is not present.
    
            Legacy Rule Format:
            WHERE NOT IN TUPLE(fbt.0003.lodge.req.xx.xx:ControllingParty)
            IF ((RP:pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text WHERE(TUPLE ELEMENT pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = "MN") AND (TUPLE ELEMENT pyde.xx.xx:OrganisationNameDetails.Currency.Code = "C")) = NULLORBLANK)
            AND (RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE((TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Currency.Code = "C") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Usage.Code = "Identifier")) = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT16 = BLANK) AND (^FBT12 = BLANK)
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT16) == true && string.IsNullOrWhiteSpace(report.FBT12) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000070", Severity = ProcessMessageSeverity.Error,
                    Description = @"Employer Family Name or Non-individual Name is not present.",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000070"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000070
    
            #region VR.ATO.FBT.000145
    
            /*  VR.ATO.FBT.000145
            Both Employer previous family name and Employer previous non-individual name are present. Only one name is required
    
            Legacy Rule Format:
            IF (RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE((TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Currency.Code = "P") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Usage.Code = "Identifier")) <> NULLORBLANK) AND (RP:pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text WHERE((TUPLE ELEMENT pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = "MN") AND (TUPLE ELEMENT pyde.xx.xx:OrganisationNameDetails.Currency.Code = "P")) <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT27 <> BLANK) AND (^FBT31 <> BLANK)
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT27) != true && string.IsNullOrWhiteSpace(report.FBT31) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000145", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both Employer previous family name and Employer previous non-individual name are present. Only one name is required.",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000145"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000145
    
            #region VR.ATO.FBT.000187
    
            /*  VR.ATO.FBT.000187
            Current postal address and previous postal address are identical. Previous postal address is only required when an address change has occurred since the last return
    
            Legacy Rule Format:
            IF  [FBT32]=[FBT17] AND [FBT33]=[FBT18] AND [FBT36]=[FBT21] AND [FBT38]=[FBT23] AND [FBT37]=[FBT22] AND [FBT223]=[FBT222]
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT17] = FBT:RP:pyde.02.00:AddressDetails.Line1.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT18] = FBT:RP:pyde.02.00:AddressDetails.Line2.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT21] = FBT:RP:pyde.02.00:AddressDetails.LocalityName.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT22] = FBT:RP:pyde.02.00:AddressDetails.StateOrTerritory.Code WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT23] = FBT:RP:pyde.02.00:AddressDetails.Postcode.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT32] = FBT:RP:pyde.02.00:AddressDetails.Line1.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT33] = FBT:RP:pyde.02.00:AddressDetails.Line2.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT36] = FBT:RP:pyde.02.00:AddressDetails.LocalityName.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT37] = FBT:RP:pyde.02.00:AddressDetails.StateOrTerritory.Code WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT38] = FBT:RP:pyde.02.00:AddressDetails.Postcode.Text WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT222] = FBT:RP:pyde.02.08:AddressDetails.Country.Code WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)
            [FBT223] = FBT:RP:pyde.02.08:AddressDetails.Country.Code WHERE (pyde.02.01:AddressDetails.Usage.Code = "POS" AND pyde.02.00:AddressDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:AddressDetails)

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT32=^FBT17 AND ^FBT33=^FBT18 AND ^FBT36=^FBT21 AND ^FBT38=^FBT23 AND ^FBT37=^FBT22 AND ^FBT223=^FBT222)
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT18 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT21 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT22 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT23 = RP:AddressDetails:AddressDetails.Postcode.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT33 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT36 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT37 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT38 = RP:AddressDetails:AddressDetails.Postcode.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT222 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT223 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_P_RPExists != false && (report.FBT32 == report.FBT17 && report.FBT33 == report.FBT18 && report.FBT36 == report.FBT21 && report.FBT38 == report.FBT23 && report.FBT37 == report.FBT22 && report.FBT223 == report.FBT222));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000187", Severity = ProcessMessageSeverity.Error,
                    Description = @"Current postal address and previous postal address are identical. Previous postal address is only required when an address change has occurred since the last return",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000187"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT33", Value = GetValueOrEmpty(report.FBT33) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT18", Value = GetValueOrEmpty(report.FBT18) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT36", Value = report.FBT36 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT21", Value = report.FBT21 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT38", Value = GetValueOrEmpty(report.FBT38) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT23", Value = GetValueOrEmpty(report.FBT23) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT37", Value = GetValueOrEmpty(report.FBT37) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT22", Value = GetValueOrEmpty(report.FBT22) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT223", Value = GetValueOrEmpty(report.FBT223) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT222", Value = GetValueOrEmpty(report.FBT222) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000187
    
            #region VR.ATO.FBT.000250
    
            /*  VR.ATO.FBT.000250
            Both Controlling Party Previous Name Family name and Controlling Party Previous Name Non-individual name are present. Only one name is required
    
            Legacy Rule Format:
            WHERE IN TUPLE(fbt.0003.lodge.req.xx.xx:ControllingParty)
            IF (RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE((TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Currency.Code = "P") AND (TUPLE ELEMENT EXPLICIT pyde.xx.xx:PersonNameDetails.Usage.Code = "Identifier")) <> NULLORBLANK)
            AND (RP:pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text WHERE((TUPLE ELEMENT EXPLICIT pyde.xx.xx:OrganisationNameDetails.OrganisationalNameType.Code = "MN") AND (TUPLE ELEMENT EXPLICIT pyde.xx.xx:OrganisationNameDetails.Currency.Code = "P")) <> NULLORBLANK)
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT50 <> BLANK) AND (^FBT54 <> BLANK)
    
            Data Elements:
    
            ^FBT50 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT50) != true && string.IsNullOrWhiteSpace(report.FBT54) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000250", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both Controlling Party Previous Name Family name and Controlling Party Previous Name Non-individual name are present. Only one name is required",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000250"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT50", Value = report.FBT50 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000250
    
            #region VR.ATO.FBT.000332
    
            /*  VR.ATO.FBT.000332
            Type 1 aggregate factored amount is incorrect
    
            Legacy Rule Format:
            IF ((RP:rvctc3.xx.xx:FringeBenefitsTax.Type1Aggregate.Amount) > (((RP:lrla.xx.xx:Remuneration.FringeBenefits.Type1Aggregate.Amount) * GROSS UP HIGHER RATE) + 50)
            OR (RP:rvctc3.xx.xx:FringeBenefitsTax.Type1Aggregate.Amount) < (((RP:lrla.xx.xx:Remuneration.FringeBenefits.Type1Aggregate.Amount) * GROSS UP HIGHER RATE) - 50))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT67 > ((^FBT66 * Constant('GROSS UP HIGHER RATE')) + 50) OR ^FBT67 < ((^FBT66 * Constant('GROSS UP HIGHER RATE')) - 50))
    
            Data Elements:
    
            ^FBT67 = RP:FringeBenefitsTax.Type1Aggregate.Amount
    
            ^FBT66 = RP:Remuneration.FringeBenefits.Type1Aggregate.Amount
            */
            assertion = (report.FBT67.GetValueOrDefault() > report.FBT66.GetValueOrDefault() * 2.0802M + 50 || report.FBT67.GetValueOrDefault() < report.FBT66.GetValueOrDefault() * 2.0802M - 50);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000332", Severity = ProcessMessageSeverity.Error,
                    Description = @"Type 1 aggregate factored amount is incorrect",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Type1Aggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000332"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter() {Name = "GROSS UP HIGHER RATE", Value = "2.0802"} );
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT67", Value = GetValueOrEmpty(report.FBT67) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT66", Value = GetValueOrEmpty(report.FBT66) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000332
    
            #region VR.ATO.FBT.000333
    
            /*  VR.ATO.FBT.000333
            Type 2 aggregate factored amount is incorrect
    
            Legacy Rule Format:
            IF ((RP:rvctc3.xx.xx:FringeBenefitsTax.Type2Aggregate.Amount) > (((RP:lrla.xx.xx:Remuneration.FringeBenefits.Type2Aggregate.Amount) * GROSS UP LOWER RATE) + 50)
            OR (RP:rvctc3.xx.xx:FringeBenefitsTax.Type2Aggregate.Amount) < (((RP:lrla.xx.xx:Remuneration.FringeBenefits.Type2Aggregate.Amount) * GROSS UP LOWER RATE) - 50))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT69 > ((^FBT68 * Constant('GROSS UP LOWER RATE')) + 50) OR ^FBT69 < ((^FBT68 * Constant('GROSS UP LOWER RATE')) - 50))
    
            Data Elements:
    
            ^FBT69 = RP:FringeBenefitsTax.Type2Aggregate.Amount
    
            ^FBT68 = RP:Remuneration.FringeBenefits.Type2Aggregate.Amount
            */
            assertion = (report.FBT69.GetValueOrDefault() > report.FBT68.GetValueOrDefault() * 1.8868M + 50 || report.FBT69.GetValueOrDefault() < report.FBT68.GetValueOrDefault() * 1.8868M - 50);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000333", Severity = ProcessMessageSeverity.Error,
                    Description = @"Type 2 aggregate factored amount is incorrect",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Type2Aggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000333"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter() {Name = "GROSS UP LOWER RATE", Value = "1.8868"} );
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT69", Value = GetValueOrEmpty(report.FBT69) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT68", Value = GetValueOrEmpty(report.FBT68) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000333
    
            #region VR.ATO.FBT.000334
    
            /*  VR.ATO.FBT.000334
            Fringe benefits taxable amount (A + B) or C must equal Type 1 aggregate factored amount plus Type 2 aggregate factored amount plus Aggregate Non-exempt amount (hospitals, ambulances, public benevolent institutions and health promotion charities only)
    
            Legacy Rule Format:
            IF ((RP:rvctc3.xx.xx:FringeBenefitsTax.Type1Aggregate.Amount) + (RP:rvctc3.xx.xx:FringeBenefitsTax.Type2Aggregate.Amount) + (RP:lrla.xx.xx:Remuneration.FringeBenefits.AggregateNonExempt.Amount) +/- $1) <> (RP:lrla.xx.xx:Remuneration.FringeBenefits.TaxableTotal.Amount)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            OutsideRange(^FBT71, ^FBT67 + ^FBT69 + ^FBT70, 1)
    
            Data Elements:
    
            ^FBT71 = RP:Remuneration.FringeBenefits.TaxableTotal.Amount
    
            ^FBT67 = RP:FringeBenefitsTax.Type1Aggregate.Amount
    
            ^FBT69 = RP:FringeBenefitsTax.Type2Aggregate.Amount
    
            ^FBT70 = RP:Remuneration.FringeBenefits.AggregateNonExempt.Amount
            */
            assertion = OutsideRange(report.FBT71.GetValueOrDefault(), report.FBT67.GetValueOrDefault() + report.FBT69.GetValueOrDefault() + report.FBT70.GetValueOrDefault(), 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000334", Severity = ProcessMessageSeverity.Error,
                    Description = @"Fringe benefits taxable amount (A + B) or C must equal Type 1 aggregate factored amount plus Type 2 aggregate factored amount plus Aggregate Non-exempt amount (hospitals, ambulances, public benevolent institutions and health promotion charities only)",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.TaxableTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000334"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT71", Value = GetValueOrEmpty(report.FBT71) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT67", Value = GetValueOrEmpty(report.FBT67) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT69", Value = GetValueOrEmpty(report.FBT69) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT70", Value = GetValueOrEmpty(report.FBT70) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000334
    
            #region VR.ATO.FBT.000335
    
            /*  VR.ATO.FBT.000335
            Amount of tax payable is not equal to Fringe benefits taxable amount (A + B) or C multiplied by FBT TAX RATE
    
            Legacy Rule Format:
            IF RP:rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount > ((RP:lrla.xx.xx:Remuneration.FringeBenefits.TaxableTotal.Amount * FBT TAX RATE) + 50)
            OR RP:rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount < ((RP:lrla.xx.xx:Remuneration.FringeBenefits.TaxableTotal.Amount * FBT TAX RATE) - 50)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT72 > ((^FBT71 * Constant('FBT TAX RATE')) + 50) OR ^FBT72 < ((^FBT71 * Constant('FBT TAX RATE')) - 50)
    
            Data Elements:
    
            ^FBT72 = RP:FringeBenefitsTax.Payable.Amount
    
            ^FBT71 = RP:Remuneration.FringeBenefits.TaxableTotal.Amount
            */
            assertion = (report.FBT72.GetValueOrDefault() > report.FBT71.GetValueOrDefault() * 0.47M + 50 || report.FBT72.GetValueOrDefault() < report.FBT71.GetValueOrDefault() * 0.47M - 50);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000335", Severity = ProcessMessageSeverity.Error,
                    Description = @"Amount of tax payable is not equal to Fringe benefits taxable amount (A + B) or C multiplied by FBT TAX RATE",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Payable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000335"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter() {Name = "FBT TAX RATE", Value = "0.47"} );
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT72", Value = GetValueOrEmpty(report.FBT72) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT71", Value = GetValueOrEmpty(report.FBT71) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000335
    
            #region VR.ATO.FBT.000336
    
            /*  VR.ATO.FBT.000336
            Aggregate non rebatable amount cannot be greater than Amount of tax payable
    
            Legacy Rule Format:
            IF (RP:rvctc3.xx.xx:FringeBenefitsTax.NonRebatableAggregate.Amount <> NULLORBLANK) 
            AND (RP:rvctc3.xx.xx:FringeBenefitsTax.NonRebatableAggregate.Amount > RP:rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT73 <> BLANK) AND (^FBT73 > ^FBT72)
    
            Data Elements:
    
            ^FBT73 = RP:FringeBenefitsTax.NonRebatableAggregate.Amount
    
            ^FBT72 = RP:FringeBenefitsTax.Payable.Amount
            */
            assertion = (report.FBT73 != null && report.FBT73.GetValueOrDefault() > report.FBT72.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000336", Severity = ProcessMessageSeverity.Error,
                    Description = @"Aggregate non rebatable amount cannot be greater than Amount of tax payable",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.NonRebatableAggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000336"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT73", Value = GetValueOrEmpty(report.FBT73) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT72", Value = GetValueOrEmpty(report.FBT72) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000336
    
            #region VR.ATO.FBT.000337
    
            /*  VR.ATO.FBT.000337
            Aggregate non rebatable amount is absent and Amount of rebate is present. Enter zero if there is no non-rebatable amount
    
            Legacy Rule Format:
            IF ((RP:rvctc3.xx.xx:FringeBenefitsTax.NonRebatableAggregate.Amount) = NULLORBLANK) 
            AND ((RP:rvctc3.xx.xx:FringeBenefitsTax.Rebate.Amount) <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT73 = BLANK) AND (^FBT74 <> BLANK)
    
            Data Elements:
    
            ^FBT73 = RP:FringeBenefitsTax.NonRebatableAggregate.Amount
    
            ^FBT74 = RP:FringeBenefitsTax.Rebate.Amount
            */
            assertion = (report.FBT73 == null && report.FBT74 != null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000337", Severity = ProcessMessageSeverity.Error,
                    Description = @"Aggregate non rebatable amount is absent and Amount of rebate is present. Enter zero if there is no non-rebatable amount",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.NonRebatableAggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000337"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT73", Value = GetValueOrEmpty(report.FBT73) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT74", Value = GetValueOrEmpty(report.FBT74) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000337
    
            #region VR.ATO.FBT.000338
    
            /*  VR.ATO.FBT.000338
            Aggregate non rebatable amount is present and Amount of rebate is absent. Enter zero if there is no rebate amount
    
            Legacy Rule Format:
            IF ((RP:rvctc3.xx.xx:FringeBenefitsTax.NonRebatableAggregate.Amount) <> NULLORBLANK) 
            AND ((RP:rvctc3.xx.xx:FringeBenefitsTax.Rebate.Amount) = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT73 <> BLANK) AND (^FBT74 = BLANK)
    
            Data Elements:
    
            ^FBT74 = RP:FringeBenefitsTax.Rebate.Amount
    
            ^FBT73 = RP:FringeBenefitsTax.NonRebatableAggregate.Amount
            */
            assertion = (report.FBT73 != null && report.FBT74 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000338", Severity = ProcessMessageSeverity.Error,
                    Description = @"Aggregate non rebatable amount is present and Amount of rebate is absent. Enter zero if there is no rebate amount",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Rebate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000338"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT73", Value = GetValueOrEmpty(report.FBT73) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT74", Value = GetValueOrEmpty(report.FBT74) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000338
    
            #region VR.ATO.FBT.000339
    
            /*  VR.ATO.FBT.000339
            Amount of rebate is greater than zero and Amount of rebate is greater than 47% of Total amount of tax calculated
    
            Legacy Rule Format:
            IF [FBT74] > 0 AND ([FBT74] <> (([FBT72] - [FBT73]) *0.47 +/- 50)) 
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT72] = FBT:RP:rvctc3.02.00:FringeBenefitsTax.Payable.Amount
            [FBT73] = FBT:RP:rvctc3.02.00:FringeBenefitsTax.NonRebatableAggregate.Amount
            [FBT74] = FBT:RP:rvctc3.02.00:FringeBenefitsTax.Rebate.Amount

            Technical Business Rule Format:
            ^FBT74 > 0 AND OutsideRange(^FBT74, (^FBT72 - ^FBT73) *0.47, 50)
    
            Data Elements:
    
            ^FBT74 = RP:FringeBenefitsTax.Rebate.Amount
    
            ^FBT72 = RP:FringeBenefitsTax.Payable.Amount
    
            ^FBT73 = RP:FringeBenefitsTax.NonRebatableAggregate.Amount
            */
            assertion = (report.FBT74.GetValueOrDefault() > 0 && OutsideRange(report.FBT74.GetValueOrDefault(), (report.FBT72.GetValueOrDefault() - report.FBT73.GetValueOrDefault()) * 0.47M, 50));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.100063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Amount of rebate is greater than zero and Amount of rebate is greater than 47% of Total amount of tax calculated",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Rebate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000339"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT74", Value = GetValueOrEmpty(report.FBT74) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT72", Value = GetValueOrEmpty(report.FBT72) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT73", Value = GetValueOrEmpty(report.FBT73) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000339
    
            #region VR.ATO.FBT.000340
    
            /*  VR.ATO.FBT.000340
            Sub - total (Amount of tax payable less Amount of rebate) is not equal to Amount of tax payable less Amount of rebate
    
            Legacy Rule Format:
            IF (RP:rvctc3.xx.xx:FringeBenefitsTax.Liability.Amount) <> ((RP:rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount) - (RP:rvctc3.xx.xx:FringeBenefitsTax.Rebate.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT75 <> (^FBT72 - ^FBT74)
    
            Data Elements:
    
            ^FBT75 = RP:FringeBenefitsTax.Liability.Amount
    
            ^FBT72 = RP:FringeBenefitsTax.Payable.Amount
    
            ^FBT74 = RP:FringeBenefitsTax.Rebate.Amount
            */
            assertion = (report.FBT75.GetValueOrDefault() != report.FBT72.GetValueOrDefault() - report.FBT74.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000340", Severity = ProcessMessageSeverity.Error,
                    Description = @"Sub - total (Amount of tax payable less Amount of rebate) is not equal to Amount of tax payable less Amount of rebate",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Liability.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000340"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT75", Value = GetValueOrEmpty(report.FBT75) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT72", Value = GetValueOrEmpty(report.FBT72) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT74", Value = GetValueOrEmpty(report.FBT74) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000340
    
            #region VR.ATO.FBT.000341
    
            /*  VR.ATO.FBT.000341
            Payment due or credit due to you is not equal to Sub - total (Amount of tax payable less Amount of rebate) minus Less instalment amounts reported on activity statements
    
            Legacy Rule Format:
            IF (RP:rvctc3.xx.xx:FringeBenefitsTax.AdjustmentDue.Amount) <> ((RP:rvctc3.xx.xx:FringeBenefitsTax.Liability.Amount) - (RP:rvctc3.xx.xx:FringeBenefitsTax.LiabilityInstalmentsTotal.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT77 <> (^FBT75 - ^FBT76)
    
            Data Elements:
    
            ^FBT77 = RP:FringeBenefitsTax.AdjustmentDue.Amount
    
            ^FBT75 = RP:FringeBenefitsTax.Liability.Amount
    
            ^FBT76 = RP:FringeBenefitsTax.LiabilityInstalmentsTotal.Amount
            */
            assertion = (report.FBT77.GetValueOrDefault() != report.FBT75.GetValueOrDefault() - report.FBT76.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000341", Severity = ProcessMessageSeverity.Error,
                    Description = @"Payment due or credit due to you is not equal to Sub - total (Amount of tax payable less Amount of rebate) minus Less instalment amounts reported on activity statements",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.AdjustmentDue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000341"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT77", Value = GetValueOrEmpty(report.FBT77) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT75", Value = GetValueOrEmpty(report.FBT75) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT76", Value = GetValueOrEmpty(report.FBT76) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000341
    
            #region VR.ATO.FBT.000417
    
            /*  VR.ATO.FBT.000417
            Tax Agent number (TAN) is invalid
    
            Legacy Rule Format:
            IF ((INT:pyid.xx.xx:Identifiers.TaxAgentNumber.Identifier) <> NULLORBLANK)
            AND (ALGORITHM(INT:pyid.xx.xx:Identifiers.TaxAgentNumber.Identifier) = FALSE)
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT2 <> BLANK) AND FailsTANAlgorithm(^FBT2)
    
            Data Elements:
    
            ^FBT2 = INT:Identifiers.TaxAgentNumber.Identifier
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT2) != true && FailsTANAlgorithm(report.FBT2));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000417", Severity = ProcessMessageSeverity.Error,
                    Description = @"Tax Agent number (TAN) is invalid",
                    Location = "/xbrli:xbrl/tns:Identifiers.TaxAgentNumber.Identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000417"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT2", Value = report.FBT2 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000417
    
            #region VR.ATO.FBT.000424
    
            /*  VR.ATO.FBT.000424
            Both reporting party and intermediary contact telephone numbers are missing, at least one is required
    
            Legacy Rule Format:
            IF (INT:pyde.xx.xx:ElectronicContact.Telephone.Minimal.Number WHERE(TUPLE ELEMENT pyde.xx.xx:ElectronicContact.Telephone.Usage.Code = 03)) = NULLORBLANK
            AND (RP:pyde.xx.xx:ElectronicContact.Telephone.Minimal.Number WHERE(TUPLE ELEMENT pyde.xx.xx:ElectronicContact.Telephone.Usage.Code = 03)) = NULLORBLANK
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT61 = BLANK) AND (^FBT128 = BLANK)
    
            Data Elements:
    
            ^FBT61 = RP:ElectronicContactTelephone:ElectronicContact.Telephone.Minimal.Number WHERE [ElectronicContact.Telephone.Usage.Code='03']
    
            ^FBT128 = INT:ElectronicContactTelephone:ElectronicContact.Telephone.Minimal.Number WHERE [ElectronicContact.Telephone.Usage.Code='03']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT61) == true && string.IsNullOrWhiteSpace(report.FBT128) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000424", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both reporting party and intermediary contact telephone numbers are missing, at least one is required",
                    Location = "/xbrli:xbrl/tns:ElectronicContactTelephone" + OccurrenceIndex(report.ElectronicContactTelephoneCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.Telephone.Minimal.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000424"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT61", Value = report.FBT61 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT128", Value = report.FBT128 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000424
    
            #region VR.ATO.FBT.000436
    
            /*  VR.ATO.FBT.000436
            Agent contact name is required
    
            Legacy Rule Format:
            IF (INT:pyid.xx.xx:Identifiers.TaxAgentNumber.Identifier) <> NULLORBLANK
            AND (INT:pyde.xx.xx:PersonUnstructuredName.FullName.Text WHERE(TUPLE ELEMENT pyde.xx.xx:PersonUnstructuredName.Usage.Code = Contact) IN TUPLE (prsnunstrcnm1.xx.xx:PersonUnstructuredName)) = NULLORBLANK
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT2 <> BLANK AND ^FBT129 = BLANK
    
            Data Elements:
    
            ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']
    
            ^FBT2 = INT:Identifiers.TaxAgentNumber.Identifier
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT2) != true && string.IsNullOrWhiteSpace(report.FBT129) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000436", Severity = ProcessMessageSeverity.Error,
                    Description = @"Agent contact name is required",
                    Location = "/xbrli:xbrl/tns:PersonUnstructuredName" + OccurrenceIndex(report.PersonUnstructuredNameCollection_Contact_INTOccurrenceIndex) + "/tns:PersonUnstructuredName.FullName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000436"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT2", Value = report.FBT2 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT129", Value = report.FBT129 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000436
    
            #region VR.ATO.FBT.000453
    
            /*  VR.ATO.FBT.000453
            Both Agent Contact Person Unstructured Name usage code and Employer Current Contact Person Name Usage code are not provided. One of these is required
    
            Legacy Rule Format:
            IF (INT:pyde.xx.xx:PersonUnstructuredName.FullName.Text WHERE(TUPLE ELEMENT pyde.xx.xx:PersonUnstructuredName.Usage.Code = "Contact")) = NULLORBLANK
            AND (RP:pyde.xx.xx:PersonNameDetails.FamilyName.Text WHERE(TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.PersonNameType.Code = "LGL") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Usage.Code = "Contact") AND (TUPLE ELEMENT pyde.xx.xx:PersonNameDetails.Currency.Code = "C")) = NULLORBLANK
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT129 = BLANK AND ^FBT56 = BLANK
    
            Data Elements:
    
            ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT129) == true && string.IsNullOrWhiteSpace(report.FBT56) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000453", Severity = ProcessMessageSeverity.Error,
                    Description = @"Both Agent Contact Person Unstructured Name and Employer Current Contact Person Name are not provided. One of these is required",
                    Location = "/xbrli:xbrl/tns:PersonUnstructuredName" + OccurrenceIndex(report.PersonUnstructuredNameCollection_Contact_INTOccurrenceIndex) + "/tns:PersonUnstructuredName.Usage.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000453"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT129", Value = report.FBT129 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000453
    
            #region VR.ATO.FBT.000461
    
            /*  VR.ATO.FBT.000461
            TFN is mandatory
    
            Legacy Rule Format:
            IF (RP:pyid.xx.xx:Identifiers.TaxFileNumber.Identifier = NULL)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT3 = NULL
    
            Data Elements:
    
            ^FBT3 = RP:Identifiers.TaxFileNumber.Identifier
            */
            assertion = (report.FBT3 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000461", Severity = ProcessMessageSeverity.Error,
                    Description = @"Tax file number is required",
                    Location = "/xbrli:xbrl/tns:Identifiers.TaxFileNumber.Identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000461"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT3", Value = report.FBT3 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000461
    
            #region VR.ATO.FBT.000462
    
            /*  VR.ATO.FBT.000462
            Sub - total (Amount of tax payable less Amount of rebate) is required
    
            Legacy Rule Format:
            IF (RP:rvctc3.xx.xx:FringeBenefitsTax.Liability.Amount = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT75 = BLANK
    
            Data Elements:
    
            ^FBT75 = RP:FringeBenefitsTax.Liability.Amount
            */
            assertion = (report.FBT75 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000462", Severity = ProcessMessageSeverity.Error,
                    Description = @"Sub - total (Amount of tax payable less Amount of rebate) is required",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Liability.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000462"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT75", Value = GetValueOrEmpty(report.FBT75) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000462
    
            #region VR.ATO.FBT.000463
    
            /*  VR.ATO.FBT.000463
            Amount of tax payable is required
    
            Legacy Rule Format:
            IF (RP:rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT72 = BLANK
    
            Data Elements:
    
            ^FBT72 = RP:FringeBenefitsTax.Payable.Amount
            */
            assertion = (report.FBT72 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000463", Severity = ProcessMessageSeverity.Error,
                    Description = @"Amount of tax payable is required",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Payable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000463"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT72", Value = GetValueOrEmpty(report.FBT72) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000463
    
            #region VR.ATO.FBT.000464
    
            /*  VR.ATO.FBT.000464
            Fringe benefits taxable amount (A + B) or C is required
    
            Legacy Rule Format:
            IF (RP:lrla.xx.xx:Remuneration.FringeBenefits.TaxableTotal.Amount = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT71 = BLANK
    
            Data Elements:
    
            ^FBT71 = RP:Remuneration.FringeBenefits.TaxableTotal.Amount
            */
            assertion = (report.FBT71 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000464", Severity = ProcessMessageSeverity.Error,
                    Description = @"Fringe benefits taxable amount (A + B) or C is required",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.TaxableTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000464"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT71", Value = GetValueOrEmpty(report.FBT71) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000464
    
            #region VR.ATO.FBT.000465
    
            /*  VR.ATO.FBT.000465
            The start date is in a different FBT  year to the end date
    
            Legacy Rule Format:
            IF (FBT YEAR (period.startDate)) <> (FBT YEAR  (period.endDate))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FBTYear(^StartDate)) <> (FBTYear(^EndDate1))
    
            Data Elements:
    
            ^EndDate1 = INT
    
            ^StartDate = INT
            */
            assertion = (FBTYear(report.INTStartDate) != FBTYear(report.INTEndDate));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000465", Severity = ProcessMessageSeverity.Error,
                    Description = @"The start date is in a different FBT financial year to the end date",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:period/xbrli:startDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000465"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000465
    
            #region VR.ATO.FBT.000465
    
            /*  VR.ATO.FBT.000465
            The start date is in a different FBT  year to the end date
    
            Legacy Rule Format:
            IF (FBT YEAR (period.startDate)) <> (FBT YEAR  (period.endDate))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FBTYear(^StartDate)) <> (FBTYear(^EndDate1))
    
            Data Elements:
    
            ^EndDate1 = RP
    
            ^StartDate = RP
            */
            assertion = (FBTYear(report.RPStartDate) != FBTYear(report.RPEndDate));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000465", Severity = ProcessMessageSeverity.Error,
                    Description = @"The start date is in a different FBT financial year to the end date",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:period/xbrli:startDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000465"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000465
    
            #region VR.ATO.FBT.000466
    
            /*  VR.ATO.FBT.000466
            Start date must be 1st of April
    
            Legacy Rule Format:
            IF (DAY(period.startDate) <> 1) OR (MONTH(period.startDate) <> April)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((Day(^StartDate) <> 1) OR (Month(^StartDate) <> 'April'))
    
            Data Elements:
    
            ^StartDate = INT
    
            ^Context = INT
            */
            assertion = (report.INTExists != false && (Day(report.INTStartDate) != 1 || Month(report.INTStartDate) != @"April"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000466", Severity = ProcessMessageSeverity.Error,
                    Description = @"Start date must be 1st of April",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:period/xbrli:startDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000466"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000466
    
            #region VR.ATO.FBT.000466
    
            /*  VR.ATO.FBT.000466
            Start date must be 1st of April
    
            Legacy Rule Format:
            IF (DAY(period.startDate) <> 1) OR (MONTH(period.startDate) <> April)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((Day(^StartDate) <> 1) OR (Month(^StartDate) <> 'April'))
    
            Data Elements:
    
            ^StartDate = RP
    
            ^Context = RP
            */
            assertion = (report.RPExists != false && (Day(report.RPStartDate) != 1 || Month(report.RPStartDate) != @"April"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000466", Severity = ProcessMessageSeverity.Error,
                    Description = @"Start date must be 1st of April",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:period/xbrli:startDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000466"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000466
    
            #region VR.ATO.FBT.000467
    
            /*  VR.ATO.FBT.000467
            The end date must be 31 of March
    
            Legacy Rule Format:
            IF (DAY(period.endDate) <> 31) OR (MONTH(period.endDate) <> March)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((Day(^EndDate1) <> 31) OR (Month(^EndDate2) <> 'March'))
    
            Data Elements:
    
            ^Context = INT
    
            ^EndDate1 = INT
    
            ^EndDate2 = INT
            */
            assertion = (report.INTExists != false && (Day(report.INTEndDate) != 31 || Month(report.INTEndDate) != @"March"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000467", Severity = ProcessMessageSeverity.Error,
                    Description = @"The end date must be 31 of March",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:period/xbrli:endDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000467"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000467
    
            #region VR.ATO.FBT.000467
    
            /*  VR.ATO.FBT.000467
            The end date must be 31 of March
    
            Legacy Rule Format:
            IF (DAY(period.endDate) <> 31) OR (MONTH(period.endDate) <> March)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((Day(^EndDate1) <> 31) OR (Month(^EndDate2) <> 'March'))
    
            Data Elements:
    
            ^Context = RP
    
            ^EndDate1 = RP
    
            ^EndDate2 = RP
            */
            assertion = (report.RPExists != false && (Day(report.RPEndDate) != 31 || Month(report.RPEndDate) != @"March"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000467", Severity = ProcessMessageSeverity.Error,
                    Description = @"The end date must be 31 of March",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:period/xbrli:endDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000467"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000467
    
            #region VR.ATO.FBT.000469
    
            /*  VR.ATO.FBT.000469
            A given Fringe Benefits Type Code value must not be repeated.
    
            Legacy Rule Format:
            IF (lrla.xx.xx:Remuneration.FringeBenefits.Type.Code <> NULLORBLANK) AND ( lrla.xx.xx:Remuneration.FringeBenefits.Type.Code = ANY OTHER OCCURENCE OF( lrla.xx.xx:Remuneration.FringeBenefits.Type.Code ) )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^FBT136) > 1 OR Count(^FBT137) > 1 OR Count(^FBT138) > 1 OR Count(^FBT139) > 1 OR Count(^FBT140) > 1 OR Count(^FBT141) > 1 OR Count(^FBT142) > 1 OR Count(^FBT144) > 1 OR Count(^FBT145) > 1 OR Count(^FBT146) > 1 OR Count(^FBT147) > 1 OR Count(^FBT148) > 1 OR Count(^FBT149) > 1
    
            Data Elements:
    
            ^FBT136 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='A']
    
            ^FBT137 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='B']
    
            ^FBT138 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='C']
    
            ^FBT139 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='D']
    
            ^FBT140 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='E']
    
            ^FBT141 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='F']
    
            ^FBT142 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='G']
    
            ^FBT144 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='J']
    
            ^FBT145 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='K']
    
            ^FBT146 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='L']
    
            ^FBT147 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='M']
    
            ^FBT148 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='N']
    
            ^FBT149 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Type.Code WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = (Count(report.ProvidedFringeBenefitsDetailsCollection_A_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_B_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_C_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_D_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_E_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_F_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_G_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_J_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_K_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_L_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_M_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_N_RPCount) > 1 || Count(report.ProvidedFringeBenefitsDetailsCollection_P_RPCount) > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000469", Severity = ProcessMessageSeverity.Error,
                    Description = @"Fringe Benefits Type Code must not be repeated.",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPLastOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Type.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000469"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000469
    
            #region VR.ATO.FBT.000470
    
            /*  VR.ATO.FBT.000470
            Response to future returns question is required
    
            Legacy Rule Format:
            IF (RP:pyin.xx.xx:Lodgment.FutureReturn.Indicator) = NULL
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT238 = NULL
    
            Data Elements:
    
            ^FBT238 = RP:Lodgment.FutureReturn.Indicator
            */
            assertion = (report.FBT238 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.000470", Severity = ProcessMessageSeverity.Error,
                    Description = @"Response to future returns question is required",
                    Location = "/xbrli:xbrl/tns:Lodgment.FutureReturn.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000470"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT238", Value = GetValueOrEmpty(report.FBT238) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000470
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT111 <> BLANK) AND (^FBT111 <> (^FBT108 - ^FBT109 - ^FBT110))
    
            Data Elements:
    
            ^FBT111 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
    
            ^FBT108 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
    
            ^FBT109 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
    
            ^FBT110 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
            */
            assertion = (report.FBT111 != null && report.FBT111.GetValueOrDefault() != report.FBT108.GetValueOrDefault() - report.FBT109.GetValueOrDefault() - report.FBT110.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT111", Value = GetValueOrEmpty(report.FBT111) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT108", Value = GetValueOrEmpty(report.FBT108) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT109", Value = GetValueOrEmpty(report.FBT109) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT110", Value = GetValueOrEmpty(report.FBT110) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT124 <> BLANK) AND (^FBT124 <> (^FBT122 - ^FBT123 - ^FBT209))
    
            Data Elements:
    
            ^FBT124 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
    
            ^FBT122 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
    
            ^FBT123 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
    
            ^FBT209 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
            */
            assertion = (report.FBT124 != null && report.FBT124.GetValueOrDefault() != report.FBT122.GetValueOrDefault() - report.FBT123.GetValueOrDefault() - report.FBT209.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT124", Value = GetValueOrEmpty(report.FBT124) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT122", Value = GetValueOrEmpty(report.FBT122) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT123", Value = GetValueOrEmpty(report.FBT123) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT209", Value = GetValueOrEmpty(report.FBT209) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT85 <> BLANK) AND (^FBT85 <> (^FBT83 - ^FBT84 - ^FBT193))
    
            Data Elements:
    
            ^FBT85 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
    
            ^FBT83 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
    
            ^FBT84 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
    
            ^FBT193 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
            */
            assertion = (report.FBT85 != null && report.FBT85.GetValueOrDefault() != report.FBT83.GetValueOrDefault() - report.FBT84.GetValueOrDefault() - report.FBT193.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT85", Value = GetValueOrEmpty(report.FBT85) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT83", Value = GetValueOrEmpty(report.FBT83) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT84", Value = GetValueOrEmpty(report.FBT84) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT193", Value = GetValueOrEmpty(report.FBT193) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT81 <> BLANK) AND (^FBT81 <> (^FBT79 - ^FBT80 - ^FBT192))
    
            Data Elements:
    
            ^FBT81 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
    
            ^FBT79 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
    
            ^FBT80 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
    
            ^FBT192 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
            */
            assertion = (report.FBT81 != null && report.FBT81.GetValueOrDefault() != report.FBT79.GetValueOrDefault() - report.FBT80.GetValueOrDefault() - report.FBT192.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT81", Value = GetValueOrEmpty(report.FBT81) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT79", Value = GetValueOrEmpty(report.FBT79) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT80", Value = GetValueOrEmpty(report.FBT80) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT192", Value = GetValueOrEmpty(report.FBT192) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT91 <> BLANK) AND (^FBT91 <> (^FBT90 - ^FBT196 - ^FBT197))
    
            Data Elements:
    
            ^FBT91 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
    
            ^FBT90 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
    
            ^FBT196 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
    
            ^FBT197 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
            */
            assertion = (report.FBT91 != null && report.FBT91.GetValueOrDefault() != report.FBT90.GetValueOrDefault() - report.FBT196.GetValueOrDefault() - report.FBT197.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT91", Value = GetValueOrEmpty(report.FBT91) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT90", Value = GetValueOrEmpty(report.FBT90) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT196", Value = GetValueOrEmpty(report.FBT196) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT197", Value = GetValueOrEmpty(report.FBT197) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT103 <> BLANK) AND (^FBT103 <> (^FBT101 - ^FBT200 - ^FBT102))
    
            Data Elements:
    
            ^FBT103 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
    
            ^FBT101 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
    
            ^FBT200 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
    
            ^FBT102 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
            */
            assertion = (report.FBT103 != null && report.FBT103.GetValueOrDefault() != report.FBT101.GetValueOrDefault() - report.FBT200.GetValueOrDefault() - report.FBT102.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT103", Value = GetValueOrEmpty(report.FBT103) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT101", Value = GetValueOrEmpty(report.FBT101) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT200", Value = GetValueOrEmpty(report.FBT200) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT102", Value = GetValueOrEmpty(report.FBT102) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT95 <> BLANK) AND (^FBT95 <> (^FBT92 - ^FBT93 - ^FBT94))
    
            Data Elements:
    
            ^FBT95 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
    
            ^FBT92 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
    
            ^FBT93 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
    
            ^FBT94 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
            */
            assertion = (report.FBT95 != null && report.FBT95.GetValueOrDefault() != report.FBT92.GetValueOrDefault() - report.FBT93.GetValueOrDefault() - report.FBT94.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT95", Value = GetValueOrEmpty(report.FBT95) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT92", Value = GetValueOrEmpty(report.FBT92) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT93", Value = GetValueOrEmpty(report.FBT93) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT94", Value = GetValueOrEmpty(report.FBT94) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT99 <> BLANK) AND (^FBT99 <> (^FBT97 - ^FBT98 - ^FBT199))
    
            Data Elements:
    
            ^FBT99 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
    
            ^FBT97 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
    
            ^FBT98 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
    
            ^FBT199 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
            */
            assertion = (report.FBT99 != null && report.FBT99.GetValueOrDefault() != report.FBT97.GetValueOrDefault() - report.FBT98.GetValueOrDefault() - report.FBT199.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT99", Value = GetValueOrEmpty(report.FBT99) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT97", Value = GetValueOrEmpty(report.FBT97) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT98", Value = GetValueOrEmpty(report.FBT98) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT199", Value = GetValueOrEmpty(report.FBT199) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT117 <> BLANK) AND (^FBT117 <> (^FBT116 - ^FBT205 - ^FBT206))
    
            Data Elements:
    
            ^FBT117 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
    
            ^FBT116 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
    
            ^FBT205 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
    
            ^FBT206 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
            */
            assertion = (report.FBT117 != null && report.FBT117.GetValueOrDefault() != report.FBT116.GetValueOrDefault() - report.FBT205.GetValueOrDefault() - report.FBT206.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT117", Value = GetValueOrEmpty(report.FBT117) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT116", Value = GetValueOrEmpty(report.FBT116) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT205", Value = GetValueOrEmpty(report.FBT205) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT206", Value = GetValueOrEmpty(report.FBT206) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT89 <> BLANK) AND (^FBT89 <> (^FBT87 - ^FBT194 - ^FBT88))
    
            Data Elements:
    
            ^FBT89 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
    
            ^FBT87 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
    
            ^FBT194 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
    
            ^FBT88 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
            */
            assertion = (report.FBT89 != null && report.FBT89.GetValueOrDefault() != report.FBT87.GetValueOrDefault() - report.FBT194.GetValueOrDefault() - report.FBT88.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT89", Value = GetValueOrEmpty(report.FBT89) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT87", Value = GetValueOrEmpty(report.FBT87) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT194", Value = GetValueOrEmpty(report.FBT194) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT88", Value = GetValueOrEmpty(report.FBT88) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT126 <> BLANK) AND (^FBT126 <> (^FBT125 - ^FBT211 - ^FBT212))
    
            Data Elements:
    
            ^FBT126 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
    
            ^FBT125 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
    
            ^FBT211 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
    
            ^FBT212 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = (report.FBT126 != null && report.FBT126.GetValueOrDefault() != report.FBT125.GetValueOrDefault() - report.FBT211.GetValueOrDefault() - report.FBT212.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT126", Value = GetValueOrEmpty(report.FBT126) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT125", Value = GetValueOrEmpty(report.FBT125) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT211", Value = GetValueOrEmpty(report.FBT211) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT212", Value = GetValueOrEmpty(report.FBT212) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT121 <> BLANK) AND (^FBT121 <> (^FBT118 - ^FBT119 - ^FBT120))
    
            Data Elements:
    
            ^FBT121 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
    
            ^FBT118 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
    
            ^FBT119 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
    
            ^FBT120 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
            */
            assertion = (report.FBT121 != null && report.FBT121.GetValueOrDefault() != report.FBT118.GetValueOrDefault() - report.FBT119.GetValueOrDefault() - report.FBT120.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT121", Value = GetValueOrEmpty(report.FBT121) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT118", Value = GetValueOrEmpty(report.FBT118) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT119", Value = GetValueOrEmpty(report.FBT119) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT120", Value = GetValueOrEmpty(report.FBT120) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.000471
    
            /*  VR.ATO.FBT.000471
            For a given 'Details of fringe benefits provided' type, the Taxable value of benefits must equal the Gross Taxable value of benefits minus the Employee contribution minus the Value of reductions.
    
            Legacy Rule Format:
            WHERE IN TUPLE (fbt.0003.lodge.req.xx.xx:ProvidedFringeBenefitsDetails)
            IF (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> NULLORBLANK) AND (lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> (lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount - lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount - lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT115 <> BLANK) AND (^FBT115 <> (^FBT112 - ^FBT113 - ^FBT114))
    
            Data Elements:
    
            ^FBT115 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
    
            ^FBT112 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
    
            ^FBT113 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
    
            ^FBT114 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
            */
            assertion = (report.FBT115 != null && report.FBT115.GetValueOrDefault() != report.FBT112.GetValueOrDefault() - report.FBT113.GetValueOrDefault() - report.FBT114.GetValueOrDefault());
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000474", Severity = ProcessMessageSeverity.Error,
                    Description = @"Taxable value of benefits must equal Gross Taxable value of benefits minus Employee contribution (if applicable) minus Value of reductions (if applicable)",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.000471"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT115", Value = GetValueOrEmpty(report.FBT115) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT112", Value = GetValueOrEmpty(report.FBT112) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT113", Value = GetValueOrEmpty(report.FBT113) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT114", Value = GetValueOrEmpty(report.FBT114) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.000471
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT111, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT111 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
            */
            assertion = NotMonetary(report.FBT111, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT111", Value = GetValueOrEmpty(report.FBT111) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT124, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT124 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
            */
            assertion = NotMonetary(report.FBT124, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT124", Value = GetValueOrEmpty(report.FBT124) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT85, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT85 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
            */
            assertion = NotMonetary(report.FBT85, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT85", Value = GetValueOrEmpty(report.FBT85) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT81, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT81 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
            */
            assertion = NotMonetary(report.FBT81, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT81", Value = GetValueOrEmpty(report.FBT81) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT91, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT91 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
            */
            assertion = NotMonetary(report.FBT91, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT91", Value = GetValueOrEmpty(report.FBT91) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT103, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT103 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
            */
            assertion = NotMonetary(report.FBT103, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT103", Value = GetValueOrEmpty(report.FBT103) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT95, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT95 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
            */
            assertion = NotMonetary(report.FBT95, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT95", Value = GetValueOrEmpty(report.FBT95) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT99, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT99 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
            */
            assertion = NotMonetary(report.FBT99, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT99", Value = GetValueOrEmpty(report.FBT99) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT117, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT117 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
            */
            assertion = NotMonetary(report.FBT117, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT117", Value = GetValueOrEmpty(report.FBT117) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT89, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT89 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
            */
            assertion = NotMonetary(report.FBT89, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT89", Value = GetValueOrEmpty(report.FBT89) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT126, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT126 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = NotMonetary(report.FBT126, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT126", Value = GetValueOrEmpty(report.FBT126) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT121, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT121 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
            */
            assertion = NotMonetary(report.FBT121, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT121", Value = GetValueOrEmpty(report.FBT121) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010001
    
            /*  VR.ATO.FBT.010001
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitNetTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT115, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT115 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitNetTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
            */
            assertion = NotMonetary(report.FBT115, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitNetTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010001"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT115", Value = GetValueOrEmpty(report.FBT115) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010001
    
            #region VR.ATO.FBT.010002
    
            /*  VR.ATO.FBT.010002
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Type1Aggregate.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Type1Aggregate.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT66, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT66 = RP:Remuneration.FringeBenefits.Type1Aggregate.Amount
            */
            assertion = NotMonetary(report.FBT66, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.Type1Aggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010002"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT66", Value = GetValueOrEmpty(report.FBT66) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010002
    
            #region VR.ATO.FBT.010003
    
            /*  VR.ATO.FBT.010003
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.Type1Aggregate.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.Type1Aggregate.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT67, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT67 = RP:FringeBenefitsTax.Type1Aggregate.Amount
            */
            assertion = NotMonetary(report.FBT67, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Type1Aggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010003"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT67", Value = GetValueOrEmpty(report.FBT67) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010003
    
            #region VR.ATO.FBT.010004
    
            /*  VR.ATO.FBT.010004
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Type2Aggregate.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Type2Aggregate.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT68, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT68 = RP:Remuneration.FringeBenefits.Type2Aggregate.Amount
            */
            assertion = NotMonetary(report.FBT68, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.Type2Aggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010004"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT68", Value = GetValueOrEmpty(report.FBT68) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010004
    
            #region VR.ATO.FBT.010005
    
            /*  VR.ATO.FBT.010005
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.Type2Aggregate.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.Type2Aggregate.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT69, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT69 = RP:FringeBenefitsTax.Type2Aggregate.Amount
            */
            assertion = NotMonetary(report.FBT69, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Type2Aggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010005"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT69", Value = GetValueOrEmpty(report.FBT69) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010005
    
            #region VR.ATO.FBT.010006
    
            /*  VR.ATO.FBT.010006
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.AggregateNonExempt.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.AggregateNonExempt.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT70, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT70 = RP:Remuneration.FringeBenefits.AggregateNonExempt.Amount
            */
            assertion = NotMonetary(report.FBT70, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.AggregateNonExempt.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010006"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT70", Value = GetValueOrEmpty(report.FBT70) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010006
    
            #region VR.ATO.FBT.010007
    
            /*  VR.ATO.FBT.010007
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.TaxableTotal.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.TaxableTotal.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT71, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT71 = RP:Remuneration.FringeBenefits.TaxableTotal.Amount
            */
            assertion = NotMonetary(report.FBT71, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.TaxableTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010007"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT71", Value = GetValueOrEmpty(report.FBT71) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010007
    
            #region VR.ATO.FBT.010008
    
            /*  VR.ATO.FBT.010008
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.Payable.Amount <> MONETARY(U,13,2) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT72, 'U', 13, 2)
    
            Data Elements:
    
            ^FBT72 = RP:FringeBenefitsTax.Payable.Amount
            */
            assertion = NotMonetary(report.FBT72, @"U", 13, 2);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Payable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010008"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT72", Value = GetValueOrEmpty(report.FBT72) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010008
    
            #region VR.ATO.FBT.010009
    
            /*  VR.ATO.FBT.010009
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.NonRebatableAggregate.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.NonRebatableAggregate.Amount <> MONETARY(U,13,2) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT73, 'U', 13, 2)
    
            Data Elements:
    
            ^FBT73 = RP:FringeBenefitsTax.NonRebatableAggregate.Amount
            */
            assertion = NotMonetary(report.FBT73, @"U", 13, 2);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.NonRebatableAggregate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010009"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT73", Value = GetValueOrEmpty(report.FBT73) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010009
    
            #region VR.ATO.FBT.010010
    
            /*  VR.ATO.FBT.010010
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.Rebate.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.Rebate.Amount <> MONETARY(U,13,2) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT74, 'U', 13, 2)
    
            Data Elements:
    
            ^FBT74 = RP:FringeBenefitsTax.Rebate.Amount
            */
            assertion = NotMonetary(report.FBT74, @"U", 13, 2);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Rebate.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010010"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT74", Value = GetValueOrEmpty(report.FBT74) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010010
    
            #region VR.ATO.FBT.010011
    
            /*  VR.ATO.FBT.010011
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.AdjustmentDue.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.AdjustmentDue.Amount <> MONETARY(S,13,2) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT77, 'S', 13, 2)
    
            Data Elements:
    
            ^FBT77 = RP:FringeBenefitsTax.AdjustmentDue.Amount
            */
            assertion = NotMonetary(report.FBT77, @"S", 13, 2);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.AdjustmentDue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010011"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT77", Value = GetValueOrEmpty(report.FBT77) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010011
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT108, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT108 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
            */
            assertion = NotMonetary(report.FBT108, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT108", Value = GetValueOrEmpty(report.FBT108) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT122, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT122 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
            */
            assertion = NotMonetary(report.FBT122, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT122", Value = GetValueOrEmpty(report.FBT122) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT83, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT83 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
            */
            assertion = NotMonetary(report.FBT83, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT83", Value = GetValueOrEmpty(report.FBT83) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT79, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT79 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
            */
            assertion = NotMonetary(report.FBT79, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT79", Value = GetValueOrEmpty(report.FBT79) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT90, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT90 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
            */
            assertion = NotMonetary(report.FBT90, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT90", Value = GetValueOrEmpty(report.FBT90) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT101, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT101 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
            */
            assertion = NotMonetary(report.FBT101, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT101", Value = GetValueOrEmpty(report.FBT101) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT92, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT92 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
            */
            assertion = NotMonetary(report.FBT92, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT92", Value = GetValueOrEmpty(report.FBT92) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT97, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT97 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
            */
            assertion = NotMonetary(report.FBT97, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT97", Value = GetValueOrEmpty(report.FBT97) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT116, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT116 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
            */
            assertion = NotMonetary(report.FBT116, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT116", Value = GetValueOrEmpty(report.FBT116) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT87, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT87 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
            */
            assertion = NotMonetary(report.FBT87, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT87", Value = GetValueOrEmpty(report.FBT87) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT125, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT125 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = NotMonetary(report.FBT125, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT125", Value = GetValueOrEmpty(report.FBT125) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT118, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT118 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
            */
            assertion = NotMonetary(report.FBT118, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT118", Value = GetValueOrEmpty(report.FBT118) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010012
    
            /*  VR.ATO.FBT.010012
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT112, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT112 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
            */
            assertion = NotMonetary(report.FBT112, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.BenefitGrossTaxable.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010012"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT112", Value = GetValueOrEmpty(report.FBT112) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010012
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT109, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT109 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
            */
            assertion = NotMonetary(report.FBT109, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT109", Value = GetValueOrEmpty(report.FBT109) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT123, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT123 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
            */
            assertion = NotMonetary(report.FBT123, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT123", Value = GetValueOrEmpty(report.FBT123) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT84, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT84 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
            */
            assertion = NotMonetary(report.FBT84, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT84", Value = GetValueOrEmpty(report.FBT84) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT80, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT80 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
            */
            assertion = NotMonetary(report.FBT80, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT80", Value = GetValueOrEmpty(report.FBT80) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT196, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT196 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
            */
            assertion = NotMonetary(report.FBT196, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT196", Value = GetValueOrEmpty(report.FBT196) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT200, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT200 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
            */
            assertion = NotMonetary(report.FBT200, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT200", Value = GetValueOrEmpty(report.FBT200) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT93, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT93 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
            */
            assertion = NotMonetary(report.FBT93, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT93", Value = GetValueOrEmpty(report.FBT93) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT98, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT98 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
            */
            assertion = NotMonetary(report.FBT98, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT98", Value = GetValueOrEmpty(report.FBT98) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT205, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT205 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
            */
            assertion = NotMonetary(report.FBT205, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT205", Value = GetValueOrEmpty(report.FBT205) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT194, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT194 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
            */
            assertion = NotMonetary(report.FBT194, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT194", Value = GetValueOrEmpty(report.FBT194) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT211, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT211 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = NotMonetary(report.FBT211, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT211", Value = GetValueOrEmpty(report.FBT211) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT119, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT119 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
            */
            assertion = NotMonetary(report.FBT119, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT119", Value = GetValueOrEmpty(report.FBT119) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010013
    
            /*  VR.ATO.FBT.010013
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.EmployeeContribution.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT113, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT113 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.EmployeeContribution.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
            */
            assertion = NotMonetary(report.FBT113, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.EmployeeContribution.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT113", Value = GetValueOrEmpty(report.FBT113) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010013
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT110, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT110 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='J']
            */
            assertion = NotMonetary(report.FBT110, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT110", Value = GetValueOrEmpty(report.FBT110) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT209, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT209 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='N']
            */
            assertion = NotMonetary(report.FBT209, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT209", Value = GetValueOrEmpty(report.FBT209) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT193, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT193 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='B']
            */
            assertion = NotMonetary(report.FBT193, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT193", Value = GetValueOrEmpty(report.FBT193) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT192, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT192 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='A']
            */
            assertion = NotMonetary(report.FBT192, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT192", Value = GetValueOrEmpty(report.FBT192) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT197, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT197 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='D']
            */
            assertion = NotMonetary(report.FBT197, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT197", Value = GetValueOrEmpty(report.FBT197) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT102, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT102 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='G']
            */
            assertion = NotMonetary(report.FBT102, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT102", Value = GetValueOrEmpty(report.FBT102) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT94, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT94 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='E']
            */
            assertion = NotMonetary(report.FBT94, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT94", Value = GetValueOrEmpty(report.FBT94) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT199, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT199 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='F']
            */
            assertion = NotMonetary(report.FBT199, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT199", Value = GetValueOrEmpty(report.FBT199) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT206, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT206 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='L']
            */
            assertion = NotMonetary(report.FBT206, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT206", Value = GetValueOrEmpty(report.FBT206) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT88, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT88 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='C']
            */
            assertion = NotMonetary(report.FBT88, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT88", Value = GetValueOrEmpty(report.FBT88) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT212, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT212 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = NotMonetary(report.FBT212, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT212", Value = GetValueOrEmpty(report.FBT212) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT120, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT120 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='M']
            */
            assertion = NotMonetary(report.FBT120, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT120", Value = GetValueOrEmpty(report.FBT120) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010014
    
            /*  VR.ATO.FBT.010014
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Reduction.Amount <> MONETARY(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT114, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT114 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.Reduction.Amount WHERE [Remuneration.FringeBenefits.Type.Code='K']
            */
            assertion = NotMonetary(report.FBT114, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.Reduction.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010014"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT114", Value = GetValueOrEmpty(report.FBT114) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010014
    
            #region VR.ATO.FBT.010015
    
            /*  VR.ATO.FBT.010015
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.Liability.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.Liability.Amount <> MONETARY(U,13,2) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT75, 'U', 13, 2)
    
            Data Elements:
    
            ^FBT75 = RP:FringeBenefitsTax.Liability.Amount
            */
            assertion = NotMonetary(report.FBT75, @"U", 13, 2);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.Liability.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010015"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT75", Value = GetValueOrEmpty(report.FBT75) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010015
    
            #region VR.ATO.FBT.010016
    
            /*  VR.ATO.FBT.010016
            Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.LiabilityInstalmentsTotal.Amount<>NULL AND rvctc3.xx.xx:FringeBenefitsTax.LiabilityInstalmentsTotal.Amount <> MONETARY(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotMonetary(^FBT76, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT76 = RP:FringeBenefitsTax.LiabilityInstalmentsTotal.Amount
            */
            assertion = NotMonetary(report.FBT76, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a monetary field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.LiabilityInstalmentsTotal.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010016"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT76", Value = GetValueOrEmpty(report.FBT76) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010016
    
            #region VR.ATO.FBT.010017
    
            /*  VR.ATO.FBT.010017
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.Recipients.Count<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.Recipients.Count <> NUMBER(U,10,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT63, 'U', 10, 0)
    
            Data Elements:
    
            ^FBT63 = RP:Remuneration.FringeBenefits.Recipients.Count
            */
            assertion = NotNumeric(report.FBT63, @"U", 10, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Remuneration.FringeBenefits.Recipients.Count",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010017"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT63", Value = report.FBT63.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010017
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT202, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT202 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='J']
            */
            assertion = NotNumeric(report.FBT202, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_J_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT202", Value = report.FBT202.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT208, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT208 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='N']
            */
            assertion = NotNumeric(report.FBT208, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_N_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT208", Value = report.FBT208.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT82, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT82 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='B']
            */
            assertion = NotNumeric(report.FBT82, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_B_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT82", Value = report.FBT82.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT78, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT78 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='A']
            */
            assertion = NotNumeric(report.FBT78, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_A_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT78", Value = report.FBT78.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT195, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT195 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='D']
            */
            assertion = NotNumeric(report.FBT195, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_D_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT195", Value = report.FBT195.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT100, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT100 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='G']
            */
            assertion = NotNumeric(report.FBT100, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_G_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT100", Value = report.FBT100.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT198, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT198 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='E']
            */
            assertion = NotNumeric(report.FBT198, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_E_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT198", Value = report.FBT198.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT96, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT96 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='F']
            */
            assertion = NotNumeric(report.FBT96, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_F_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT96", Value = report.FBT96.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT204, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT204 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='L']
            */
            assertion = NotNumeric(report.FBT204, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_L_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT204", Value = report.FBT204.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT86, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT86 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='C']
            */
            assertion = NotNumeric(report.FBT86, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_C_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT86", Value = report.FBT86.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT210, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT210 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='P']
            */
            assertion = NotNumeric(report.FBT210, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_P_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT210", Value = report.FBT210.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT207, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT207 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='M']
            */
            assertion = NotNumeric(report.FBT207, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_M_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT207", Value = report.FBT207.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010018
    
            /*  VR.ATO.FBT.010018
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number<>NULL AND lrla.xx.xx:Remuneration.FringeBenefits.ItemsProvided.Number <> NUMBER(U,6,0) THEN
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT203, 'U', 6, 0)
    
            Data Elements:
    
            ^FBT203 = RP:ProvidedFringeBenefitsDetails:Remuneration.FringeBenefits.ItemsProvided.Number WHERE [Remuneration.FringeBenefits.Type.Code='K']
            */
            assertion = NotNumeric(report.FBT203, @"U", 6, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:ProvidedFringeBenefitsDetails" + OccurrenceIndex(report.ProvidedFringeBenefitsDetailsCollection_K_RPOccurrenceIndex) + "/tns:Remuneration.FringeBenefits.ItemsProvided.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010018"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT203", Value = report.FBT203.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010018
    
            #region VR.ATO.FBT.010019
    
            /*  VR.ATO.FBT.010019
            Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character
    
            Legacy Rule Format:
            IF pyin.xx.xx:Report.CompletionHours.Number<>NULL AND pyin.xx.xx:Report.CompletionHours.Number <> NUMBER(U,11,0) THEN
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            NotNumeric(^FBT64, 'U', 11, 0)
    
            Data Elements:
    
            ^FBT64 = RP:Report.CompletionHours.Number
            */
            assertion = NotNumeric(report.FBT64, @"U", 11, 0);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.400012", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field incorrect format. Exceeds maximum digits or decimals and/or contains illegal characters",
                    LongDescription = @"Field is in incorrect format for a numeric field. Field either exceeds maximum digits or decimals and/or contains illegal characters and/or for a signed field does not have the sign as the first character",
                    Location = "/xbrli:xbrl/tns:Report.CompletionHours.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010019"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT64", Value = report.FBT64.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010019
    
            #region VR.ATO.FBT.010023
    
            /*  VR.ATO.FBT.010023
            Value must not exceed 27 characters.
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text <> NULLORBLANK) AND LENGTH(pyde.xx.xx:AddressDetails.LocalityName.Text) > 27
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT45) > 27
    
            Data Elements:
    
            ^FBT45 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT45) > 27);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010023"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT45", Value = report.FBT45 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010023
    
            #region VR.ATO.FBT.010023
    
            /*  VR.ATO.FBT.010023
            Value must not exceed 27 characters.
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text <> NULLORBLANK) AND LENGTH(pyde.xx.xx:AddressDetails.LocalityName.Text) > 27
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT21) > 27
    
            Data Elements:
    
            ^FBT21 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT21) > 27);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010023"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT21", Value = report.FBT21 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010023
    
            #region VR.ATO.FBT.010023
    
            /*  VR.ATO.FBT.010023
            Value must not exceed 27 characters.
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text <> NULLORBLANK) AND LENGTH(pyde.xx.xx:AddressDetails.LocalityName.Text) > 27
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT36) > 27
    
            Data Elements:
    
            ^FBT36 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT36) > 27);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010023"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT36", Value = report.FBT36 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010023
    
            #region VR.ATO.FBT.010024
    
            /*  VR.ATO.FBT.010024
            Value must not exceed 15 characters.
    
            Legacy Rule Format:
            IF (pyde.xx.xx:ElectronicContact.Telephone.Minimal.Number <> NULLORBLANK)
            AND LENGTH(pyde.xx.xx:ElectronicContact.Telephone.Minimal.Number) > 15
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT61) > 15
    
            Data Elements:
    
            ^FBT61 = RP:ElectronicContactTelephone:ElectronicContact.Telephone.Minimal.Number WHERE [ElectronicContact.Telephone.Usage.Code='03']
            */
            assertion = (Length(report.FBT61) > 15);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ElectronicContactTelephone" + OccurrenceIndex(report.ElectronicContactTelephoneCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.Telephone.Minimal.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010024"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT61", Value = report.FBT61 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010024
    
            #region VR.ATO.FBT.010025
    
            /*  VR.ATO.FBT.010025
            Value must not exceed 10 characters.
    
            Legacy Rule Format:
            IF [FBT130] <> NULLORBLANK AND LENGTH([FBT130]) > 10
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT130] = FBT:INT:pyid.02.00:Identifiers.TaxAgentClientReference.Text

            Technical Business Rule Format:
            Length(^FBT130) > 10
    
            Data Elements:
    
            ^FBT130 = INT:Identifiers.TaxAgentClientReference.Text
            */
            assertion = (Length(report.FBT130) > 10);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:Identifiers.TaxAgentClientReference.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010025"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT130", Value = GetValueOrEmpty(report.FBT130) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010025
    
            #region VR.ATO.FBT.010027
    
            /*  VR.ATO.FBT.010027
            Value must not exceed 76 characters.
    
            Legacy Rule Format:
            IF [FBT62] <> NULLORBLANK AND LENGTH([FBT62]) > 76
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT62] = FBT:RP:pyde.02.00:ElectronicContact.ElectronicMail.Address.Text WHERE (pyde.02.00:ElectronicContact.ElectronicMail.Usage.Code = "03") IN TUPLE(fbt.0003.lodge.req.02.00:ElectronicContactElectronicMail)

            Technical Business Rule Format:
            Length(^FBT62) > 76
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (Length(report.FBT62) > 76);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010027"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010027
    
            #region VR.ATO.FBT.010033
    
            /*  VR.ATO.FBT.010033
            Bank account name must not exceed 32 characters.
    
            Legacy Rule Format:
            IF LENGTH([FBT231]) > 32
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT231] = FBT:RP:pyid.02.00:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text IN TUPLE(fbt.0003.lodge.req.02.00:FinancialInstitutionAccount)

            Technical Business Rule Format:
            Length(^FBT231) > 32
    
            Data Elements:
    
            ^FBT231 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text
            */
            assertion = (Length(report.FBT231) > 32);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.010033", Severity = ProcessMessageSeverity.Error,
                    Description = @"Bank account name must not be longer than 32 characters.",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount/tns:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010033"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT231", Value = report.FBT231 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010033
    
            #region VR.ATO.FBT.010036
    
            /*  VR.ATO.FBT.010036
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT12] <> NULLORBLANK AND LENGTH([FBT12]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT12] = FBT:RP:pyde.02.00:PersonNameDetails.FamilyName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT12) > 30
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT12) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010036"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010036
    
            #region VR.ATO.FBT.010037
    
            /*  VR.ATO.FBT.010037
            Value must not exceed 15 characters.
    
            Legacy Rule Format:
            IF [FBT14] <> NULLORBLANK AND LENGTH([FBT14]) > 15
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT14] = FBT:RP:pyde.02.00:PersonNameDetails.GivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT14) > 15
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT14) > 15);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010037"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010037
    
            #region VR.ATO.FBT.010038
    
            /*  VR.ATO.FBT.010038
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT15] <> NULLORBLANK AND LENGTH([FBT15]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT15] = FBT:RP:pyde.02.00:PersonNameDetails.OtherGivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT15) > 30
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT15) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010038"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010038
    
            #region VR.ATO.FBT.010040
    
            /*  VR.ATO.FBT.010040
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT27] <> NULLORBLANK AND LENGTH([FBT27]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT27] = FBT:RP:pyde.02.00:PersonNameDetails.FamilyName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT27) > 30
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT27) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010040"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010040
    
            #region VR.ATO.FBT.010041
    
            /*  VR.ATO.FBT.010041
            Value must not exceed 15 characters.
    
            Legacy Rule Format:
            IF [FBT29] <> NULLORBLANK AND LENGTH([FBT29]) > 15
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT29] = FBT:RP:pyde.02.00:PersonNameDetails.GivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT29) > 15
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT29) > 15);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010041"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010041
    
            #region VR.ATO.FBT.010042
    
            /*  VR.ATO.FBT.010042
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT30] <> NULLORBLANK AND LENGTH([FBT30]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT30] = FBT:RP:pyde.02.00:PersonNameDetails.OtherGivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT30) > 30
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT30) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010042"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010042
    
            #region VR.ATO.FBT.010045
    
            /*  VR.ATO.FBT.010045
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT6] <> NULLORBLANK AND LENGTH([FBT6]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT6] = FBT:RP:pyde.02.00:PersonNameDetails.FamilyName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT6) > 30
    
            Data Elements:
    
            ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT6) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010045"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT6", Value = report.FBT6 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010045
    
            #region VR.ATO.FBT.010046
    
            /*  VR.ATO.FBT.010046
            Value must not exceed 15 characters.
    
            Legacy Rule Format:
            IF [FBT8] <> NULLORBLANK AND LENGTH([FBT8]) > 15
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT8] = FBT:RP:pyde.02.00:PersonNameDetails.GivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT8) > 15
    
            Data Elements:
    
            ^FBT8 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT8) > 15);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010046"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT8", Value = GetValueOrEmpty(report.FBT8) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010046
    
            #region VR.ATO.FBT.010047
    
            /*  VR.ATO.FBT.010047
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT9] <> NULLORBLANK AND LENGTH([FBT9]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT9] = FBT:RP:pyde.02.00:PersonNameDetails.OtherGivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT9) > 30
    
            Data Elements:
    
            ^FBT9 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT9) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010047"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT9", Value = GetValueOrEmpty(report.FBT9) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010047
    
            #region VR.ATO.FBT.010048
    
            /*  VR.ATO.FBT.010048
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT50] <> NULLORBLANK AND LENGTH([FBT50]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT50] = FBT:RP:pyde.02.00:PersonNameDetails.FamilyName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT50) > 30
    
            Data Elements:
    
            ^FBT50 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT50) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010048"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT50", Value = report.FBT50 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010048
    
            #region VR.ATO.FBT.010049
    
            /*  VR.ATO.FBT.010049
            Value must not exceed 15 characters.
    
            Legacy Rule Format:
            IF [FBT52] <> NULLORBLANK AND LENGTH([FBT52]) > 15
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT52] = FBT:RP:pyde.02.00:PersonNameDetails.GivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT52) > 15
    
            Data Elements:
    
            ^FBT52 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT52) > 15);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010049"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT52", Value = GetValueOrEmpty(report.FBT52) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010049
    
            #region VR.ATO.FBT.010050
    
            /*  VR.ATO.FBT.010050
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT53] <> NULLORBLANK AND LENGTH([FBT53]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT53] = FBT:RP:pyde.02.00:PersonNameDetails.OtherGivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Identifier" AND pyde.02.00:PersonNameDetails.Currency.Code = "P") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT53) > 30
    
            Data Elements:
    
            ^FBT53 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT53) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010050"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT53", Value = GetValueOrEmpty(report.FBT53) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010050
    
            #region VR.ATO.FBT.010052
    
            /*  VR.ATO.FBT.010052
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT56] <> NULLORBLANK AND LENGTH([FBT56]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT56] = FBT:RP:pyde.02.00:PersonNameDetails.FamilyName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Contact" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT56) > 30
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT56) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010052"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010052
    
            #region VR.ATO.FBT.010053
    
            /*  VR.ATO.FBT.010053
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT58] <> NULLORBLANK AND LENGTH([FBT58]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT58] = FBT:RP:pyde.02.00:PersonNameDetails.GivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Contact" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT58) > 30
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT58) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010053"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010053
    
            #region VR.ATO.FBT.010054
    
            /*  VR.ATO.FBT.010054
            Value must not exceed 30 characters.
    
            Legacy Rule Format:
            IF [FBT59] <> NULLORBLANK AND LENGTH([FBT59]) > 30
               RETURN VALIDATION MESSAGE
            ENDIF
            
            [FBT59] = FBT:RP:pyde.02.00:PersonNameDetails.OtherGivenName.Text WHERE (pyde.02.00:PersonNameDetails.PersonNameType.Code = "LGL" AND pyde.02.05:PersonNameDetails.Usage.Code = "Contact" AND pyde.02.00:PersonNameDetails.Currency.Code = "C") IN TUPLE(fbt.0003.lodge.req.02.00:PersonNameDetails)

            Technical Business Rule Format:
            Length(^FBT59) > 30
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT59) > 30);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010054"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010054
    
            #region VR.ATO.FBT.010056
    
            /*  VR.ATO.FBT.010056
            Field length must align with length in paper form
    
            Legacy Rule Format:
            IF pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK AND LENGTH(pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text) > 76
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT40) > 76
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT40) > 76);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010056"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010056
    
            #region VR.ATO.FBT.010056
    
            /*  VR.ATO.FBT.010056
            Field length must align with length in paper form
    
            Legacy Rule Format:
            IF pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK AND LENGTH(pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text) > 76
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT16) > 76
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT16) > 76);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010056"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010056
    
            #region VR.ATO.FBT.010056
    
            /*  VR.ATO.FBT.010056
            Field length must align with length in paper form
    
            Legacy Rule Format:
            IF pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK AND LENGTH(pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text) > 76
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT31) > 76
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT31) > 76);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010056"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010056
    
            #region VR.ATO.FBT.010056
    
            /*  VR.ATO.FBT.010056
            Field length must align with length in paper form
    
            Legacy Rule Format:
            IF pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK AND LENGTH(pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text) > 76
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT10) > 76
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT10) > 76);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010056"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010056
    
            #region VR.ATO.FBT.010056
    
            /*  VR.ATO.FBT.010056
            Field length must align with length in paper form
    
            Legacy Rule Format:
            IF pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text <> NULLORBLANK AND LENGTH(pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text) > 76
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT54) > 76
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT54) > 76);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.001011", Severity = ProcessMessageSeverity.Error,
                    Description = @"Field value supplied exceeds maximum field length",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.010056"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.010056
    
            #region VR.ATO.FBT.100057
    
            /*  VR.ATO.FBT.100057
            Payment due or credit due to you is less than zero (credit is due) and Bank Account Number is not present
    
            Legacy Rule Format:
            IF rvctc3.xx.xx:FringeBenefitsTax.AdjustmentDue.Amount < 0 AND pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionAccount.Number = NULL
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT77 < 0 AND ^FBT230 = NULL
    
            Data Elements:
    
            ^FBT77 = RP:FringeBenefitsTax.AdjustmentDue.Amount
    
            ^FBT230 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionAccount.Number
            */
            assertion = (report.FBT77.GetValueOrDefault() < 0 && report.FBT230 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432268", Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial institution details must be entered when a credit (refund) is due.",
                    LongDescription = @"Based on the return calculation details a credit or refund is due. In order for the ATO to pay this credit or refund, Australian financial institution account details must be provided. If account details are not available please phone the Tax Office on: For self lodgers 13 28 61 options 2 2 and for tax agents 13 72 86 options 1 3 1 2.",
                    Location = "/xbrli:xbrl/tns:FringeBenefitsTax.AdjustmentDue.Amount",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.100057"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT77", Value = GetValueOrEmpty(report.FBT77) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT230", Value = report.FBT230 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.100057
    
            #region VR.ATO.FBT.436277
    
            /*  VR.ATO.FBT.436277
            Year of return must be either the current or next (future) lodgment year associated with this FBT service. If a future year lodgment is required, then it must be lodged prior to the 1st of April of that future year, unless it is an amendment. After the 1st April of that future year, a return for that lodgment year must be submitted using the new FBT service associated to that specific lodgment year.
    
            Legacy Rule Format:
            IF (FBT YEAR (Period.EndDate) <> SET(2020, 2021))
            OR (FBT YEAR (Period.EndDate) = 2021 AND DATE(Today) > 2021-03-31 AND pyin.xx.xx:Report.Amendment.Indicator <> TRUE)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((NotInSet(FBTYear(^EndDate1), '"2020", "2021"')) OR (FBTYear(^EndDate2) = 2021 AND Today() > AsDate('2021-03-31') AND ^FBT234 <> TRUE))
    
            Data Elements:
    
            ^Context = INT
    
            ^EndDate1 = INT
    
            ^EndDate2 = INT
    
            ^FBT234 = RP:Report.Amendment.Indicator
            */
            assertion = (report.INTExists != false && (!(IsMatch(FBTYear(report.INTEndDate), @"^(2020|2021)$",RegexOptions.IgnoreCase)) || FBTYear(report.INTEndDate) == 2021 && DateTime.Now.Date > AsDate(@"2021-03-31") && report.FBT234 != true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.100062", Severity = ProcessMessageSeverity.Error,
                    Description = @"Year of return is invalid",
                    LongDescription = @"Year of return must be either the current or next (future) lodgment year associated with this FBT service. If a future year lodgment is required, then it must be lodged prior to the 1st of April of that future year, unless it is an amendment. After the 1st April of the next lodgment year, a return for that lodgment year must be submitted using the new FBT service associated to that specific lodgment year.",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:period/xbrli:endDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.436277"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT234", Value = GetValueOrEmpty(report.FBT234) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.436277
    
            #region VR.ATO.FBT.436277
    
            /*  VR.ATO.FBT.436277
            Year of return must be either the current or next (future) lodgment year associated with this FBT service. If a future year lodgment is required, then it must be lodged prior to the 1st of April of that future year, unless it is an amendment. After the 1st April of that future year, a return for that lodgment year must be submitted using the new FBT service associated to that specific lodgment year.
    
            Legacy Rule Format:
            IF (FBT YEAR (Period.EndDate) <> SET(2020, 2021))
            OR (FBT YEAR (Period.EndDate) = 2021 AND DATE(Today) > 2021-03-31 AND pyin.xx.xx:Report.Amendment.Indicator <> TRUE)
             RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((NotInSet(FBTYear(^EndDate1), '"2020", "2021"')) OR (FBTYear(^EndDate2) = 2021 AND Today() > AsDate('2021-03-31') AND ^FBT234 <> TRUE))
    
            Data Elements:
    
            ^Context = RP
    
            ^EndDate1 = RP
    
            ^EndDate2 = RP
    
            ^FBT234 = RP:Report.Amendment.Indicator
            */
            assertion = (report.RPExists != false && (!(IsMatch(FBTYear(report.RPEndDate), @"^(2020|2021)$",RegexOptions.IgnoreCase)) || FBTYear(report.RPEndDate) == 2021 && DateTime.Now.Date > AsDate(@"2021-03-31") && report.FBT234 != true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.100062", Severity = ProcessMessageSeverity.Error,
                    Description = @"Year of return is invalid",
                    LongDescription = @"Year of return must be either the current or next (future) lodgment year associated with this FBT service. If a future year lodgment is required, then it must be lodged prior to the 1st of April of that future year, unless it is an amendment. After the 1st April of the next lodgment year, a return for that lodgment year must be submitted using the new FBT service associated to that specific lodgment year.",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:period/xbrli:endDate",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.436277"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT234", Value = GetValueOrEmpty(report.FBT234) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.436277
    
            #region VR.ATO.FBT.436278
    
            /*  VR.ATO.FBT.436278
            Value must not exceed 3000 characters
    
            Legacy Rule Format:
            IF [FBT239] <> NULLORBLANK AND LENGTH([FBT239]) > 3000
               RETURN VALIDATION MESSAGE
            END IF
            
            
            [FBT239] = FBT:RP:bafot.02.00:RegulatoryDisclosures.GeneralInformationAboutFinancialStatements.Text

            Technical Business Rule Format:
            Length(^FBT239) > 3000
    
            Data Elements:
    
            ^FBT239 = RP:RegulatoryDisclosures.GeneralInformationAboutFinancialStatements.Text
            */
            assertion = (Length(report.FBT239) > 3000);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.FBT.436278", Severity = ProcessMessageSeverity.Error,
                    Description = @"Additional Information must not exceed 3000 characters",
                    Location = "/xbrli:xbrl/tns:RegulatoryDisclosures.GeneralInformationAboutFinancialStatements.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.FBT.436278"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT239", Value = GetValueOrEmpty(report.FBT239) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.FBT.436278
    
            #region VR.ATO.GEN.000209
    
            /*  VR.ATO.GEN.000209
            Invalid context. The number of Reporting party contexts must equal 1
    
            Legacy Rule Format:
            IF COUNT(RP) <> 1
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) <> 1
    
            Data Elements:
    
            ^Context = RP
            */
            assertion = (Count(report.RPCount) != 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430296", Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid context. The number of Reporting party contexts must equal 1",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPLastOccurrenceIndex),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000209"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000209
    
            #region VR.ATO.GEN.000227
    
            /*  VR.ATO.GEN.000227
            Invalid context. The number of Intermediary contexts must not exceed 1
    
            Legacy Rule Format:
            IF COUNT(INT) > 1
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^Context) > 1
    
            Data Elements:
    
            ^Context = INT
            */
            assertion = (Count(report.INTCount) > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.436280", Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid context. The number of Intermediary contexts must not exceed 1",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTLastOccurrenceIndex),
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000227"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000227
    
            #region VR.ATO.GEN.000239
    
            /*  VR.ATO.GEN.000239
            Either an ABN or a TFN must be present as an identifier cheme
    
            Legacy Rule Format:
            IF (Identifier Scheme <> “http://www.ato.gov.au/abn”) AND (Identifier Scheme <> “http://www.ato.gov.au/tfn”)
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((^IdentifierScheme <> 'http://www.ato.gov.au/abn') AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn'))
    
            Data Elements:
    
            ^IdentifierScheme = INT
    
            ^Context = INT
            */
            assertion = (report.INTExists != false && (report.INTIdentifierScheme != @"http://www.ato.gov.au/abn" && report.INTIdentifierScheme != @"http://www.ato.gov.au/tfn"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.200007", Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid XBRL schema",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000239"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000239
    
            #region VR.ATO.GEN.000239
    
            /*  VR.ATO.GEN.000239
            Either an ABN or a TFN must be present as an identifier cheme
    
            Legacy Rule Format:
            IF (Identifier Scheme <> “http://www.ato.gov.au/abn”) AND (Identifier Scheme <> “http://www.ato.gov.au/tfn”)
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^Context <> NULL) AND ((^IdentifierScheme <> 'http://www.ato.gov.au/abn') AND (^IdentifierScheme <> 'http://www.ato.gov.au/tfn'))
    
            Data Elements:
    
            ^IdentifierScheme = RP
    
            ^Context = RP
            */
            assertion = (report.RPExists != false && (report.RPIdentifierScheme != @"http://www.ato.gov.au/abn" && report.RPIdentifierScheme != @"http://www.ato.gov.au/tfn"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.200007", Severity = ProcessMessageSeverity.Error,
                    Description = @"Invalid XBRL schema",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000239"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000239
    
            #region VR.ATO.GEN.000406
    
            /*  VR.ATO.GEN.000406
            Address line 1 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Line1.Text STARTSWITH SET("C/O ","C/ ","Care Of ","CO ")) OR (pyde.xx.xx:AddressDetails.Line1.Text CONTAINS SET(" C/O "," C/ "," Care Of "))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT41 <> BLANK) AND (StartsWithSet(^FBT41,'"C/O ","C/ ","Care Of ","CO "')) OR (ContainsSet(^FBT41, '" C/O "," C/ "," Care Of "'))
    
            Data Elements:
    
            ^FBT41 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT41) != true && IsMatch(report.FBT41, @"^(C/O |C/ |Care Of |CO )",RegexOptions.IgnoreCase) || IsMatch(report.FBT41, @" C/O | C/ | Care Of ",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000406", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 1 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000406"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT41", Value = report.FBT41 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000406
    
            #region VR.ATO.GEN.000406
    
            /*  VR.ATO.GEN.000406
            Address line 1 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Line1.Text STARTSWITH SET("C/O ","C/ ","Care Of ","CO ")) OR (pyde.xx.xx:AddressDetails.Line1.Text CONTAINS SET(" C/O "," C/ "," Care Of "))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT17 <> BLANK) AND (StartsWithSet(^FBT17,'"C/O ","C/ ","Care Of ","CO "')) OR (ContainsSet(^FBT17, '" C/O "," C/ "," Care Of "'))
    
            Data Elements:
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT17) != true && IsMatch(report.FBT17, @"^(C/O |C/ |Care Of |CO )",RegexOptions.IgnoreCase) || IsMatch(report.FBT17, @" C/O | C/ | Care Of ",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000406", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 1 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000406"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000406
    
            #region VR.ATO.GEN.000406
    
            /*  VR.ATO.GEN.000406
            Address line 1 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Line1.Text STARTSWITH SET("C/O ","C/ ","Care Of ","CO ")) OR (pyde.xx.xx:AddressDetails.Line1.Text CONTAINS SET(" C/O "," C/ "," Care Of "))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT32 <> BLANK) AND (StartsWithSet(^FBT32,'"C/O ","C/ ","Care Of ","CO "')) OR (ContainsSet(^FBT32, '" C/O "," C/ "," Care Of "'))
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT32) != true && IsMatch(report.FBT32, @"^(C/O |C/ |Care Of |CO )",RegexOptions.IgnoreCase) || IsMatch(report.FBT32, @" C/O | C/ | Care Of ",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000406", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 1 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000406"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000406
    
            #region VR.ATO.GEN.000408
    
            /*  VR.ATO.GEN.000408
            Address line 2 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line2.Text <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Line2.Text STARTSWITH SET("C/- ","C/O ","C/ ","Care Of ","CO ") OR pyde.xx.xx:AddressDetails.Line2.Text CONTAINS SET(" C/- "," C/O "," C/ "," Care Of "))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT42 <> BLANK) AND (StartsWithSet(^FBT42,'"C/- ","C/O ","C/ ","Care Of ","CO "') OR ContainsSet(^FBT42, '" C/- "," C/O "," C/ "," Care Of "'))
    
            Data Elements:
    
            ^FBT42 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT42) != true && (IsMatch(report.FBT42, @"^(C/- |C/O |C/ |Care Of |CO )",RegexOptions.IgnoreCase) || IsMatch(report.FBT42, @" C/- | C/O | C/ | Care Of ",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000408", Severity = ProcessMessageSeverity.Error,
                    Description = @"Care of' is not valid for address line 2",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line2.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000408"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT42", Value = GetValueOrEmpty(report.FBT42) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000408
    
            #region VR.ATO.GEN.000408
    
            /*  VR.ATO.GEN.000408
            Address line 2 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line2.Text <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Line2.Text STARTSWITH SET("C/- ","C/O ","C/ ","Care Of ","CO ") OR pyde.xx.xx:AddressDetails.Line2.Text CONTAINS SET(" C/- "," C/O "," C/ "," Care Of "))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT18 <> BLANK) AND (StartsWithSet(^FBT18,'"C/- ","C/O ","C/ ","Care Of ","CO "') OR ContainsSet(^FBT18, '" C/- "," C/O "," C/ "," Care Of "'))
    
            Data Elements:
    
            ^FBT18 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT18) != true && (IsMatch(report.FBT18, @"^(C/- |C/O |C/ |Care Of |CO )",RegexOptions.IgnoreCase) || IsMatch(report.FBT18, @" C/- | C/O | C/ | Care Of ",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000408", Severity = ProcessMessageSeverity.Error,
                    Description = @"Care of' is not valid for address line 2",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line2.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000408"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT18", Value = GetValueOrEmpty(report.FBT18) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000408
    
            #region VR.ATO.GEN.000408
    
            /*  VR.ATO.GEN.000408
            Address line 2 contains incorrect 'care of' reference.  The only acceptable 'care of' reference is C/-
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line2.Text <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Line2.Text STARTSWITH SET("C/- ","C/O ","C/ ","Care Of ","CO ") OR pyde.xx.xx:AddressDetails.Line2.Text CONTAINS SET(" C/- "," C/O "," C/ "," Care Of "))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT33 <> BLANK) AND (StartsWithSet(^FBT33,'"C/- ","C/O ","C/ ","Care Of ","CO "') OR ContainsSet(^FBT33, '" C/- "," C/O "," C/ "," Care Of "'))
    
            Data Elements:
    
            ^FBT33 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT33) != true && (IsMatch(report.FBT33, @"^(C/- |C/O |C/ |Care Of |CO )",RegexOptions.IgnoreCase) || IsMatch(report.FBT33, @" C/- | C/O | C/ | Care Of ",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000408", Severity = ProcessMessageSeverity.Error,
                    Description = @"Care of' is not valid for address line 2",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line2.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000408"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT33", Value = GetValueOrEmpty(report.FBT33) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000408
    
            #region VR.ATO.GEN.000458
    
            /*  VR.ATO.GEN.000458
            Suffix is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> SET(DOMAIN(SUFFIX CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT57 <> BLANK) AND (NotInDomain(^FBT57, 'SUFFIX CODES'))
    
            Data Elements:
    
            ^FBT57 = RP:PersonNameDetails:PersonNameDetails.NameSuffix.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT57) != true && !(IsMatch(report.FBT57, @"^(ESQ|II|III|IV|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000458", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suffix is invalid",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.NameSuffix.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000458"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT57", Value = GetValueOrEmpty(report.FBT57) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000458
    
            #region VR.ATO.GEN.000458
    
            /*  VR.ATO.GEN.000458
            Suffix is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> SET(DOMAIN(SUFFIX CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT13 <> BLANK) AND (NotInDomain(^FBT13, 'SUFFIX CODES'))
    
            Data Elements:
    
            ^FBT13 = RP:PersonNameDetails:PersonNameDetails.NameSuffix.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT13) != true && !(IsMatch(report.FBT13, @"^(ESQ|II|III|IV|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000458", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suffix is invalid",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.NameSuffix.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000458"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT13", Value = GetValueOrEmpty(report.FBT13) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000458
    
            #region VR.ATO.GEN.000458
    
            /*  VR.ATO.GEN.000458
            Suffix is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> SET(DOMAIN(SUFFIX CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT28 <> BLANK) AND (NotInDomain(^FBT28, 'SUFFIX CODES'))
    
            Data Elements:
    
            ^FBT28 = RP:PersonNameDetails:PersonNameDetails.NameSuffix.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT28) != true && !(IsMatch(report.FBT28, @"^(ESQ|II|III|IV|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000458", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suffix is invalid",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.NameSuffix.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000458"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT28", Value = GetValueOrEmpty(report.FBT28) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000458
    
            #region VR.ATO.GEN.000458
    
            /*  VR.ATO.GEN.000458
            Suffix is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> SET(DOMAIN(SUFFIX CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT7 <> BLANK) AND (NotInDomain(^FBT7, 'SUFFIX CODES'))
    
            Data Elements:
    
            ^FBT7 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.NameSuffix.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT7) != true && !(IsMatch(report.FBT7, @"^(ESQ|II|III|IV|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000458", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suffix is invalid",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.NameSuffix.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000458"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT7", Value = GetValueOrEmpty(report.FBT7) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000458
    
            #region VR.ATO.GEN.000458
    
            /*  VR.ATO.GEN.000458
            Suffix is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.NameSuffix.Text <> SET(DOMAIN(SUFFIX CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT51 <> BLANK) AND (NotInDomain(^FBT51, 'SUFFIX CODES'))
    
            Data Elements:
    
            ^FBT51 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.NameSuffix.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT51) != true && !(IsMatch(report.FBT51, @"^(ESQ|II|III|IV|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000458", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suffix is invalid",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.NameSuffix.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000458"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT51", Value = GetValueOrEmpty(report.FBT51) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000458
    
            #region VR.ATO.GEN.000459
    
            /*  VR.ATO.GEN.000459
            Title is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.Title.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.Title.Text <> SET(DOMAIN(TITLE CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT55 <> BLANK) AND (NotInDomain(^FBT55, 'TITLE CODES'))
    
            Data Elements:
    
            ^FBT55 = RP:PersonNameDetails:PersonNameDetails.Title.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT55) != true && !(IsMatch(report.FBT55, @"^(2LT|AB|ABBOT|AC|ACM|ADM|AIR CDRE|ALDERMAN|AM|ARCHBISHOP|ARCHDEACON|ASSOC PROF|AVM|BARON|BARONESS|BISHOP|BR|BRIG|CANON|CAPT|CARDINAL|CDRE|CDT|CHAP|CMDR|CMM|COL|CONST|COUNT|COUNTESS|CPL|CPO|DAME|DEACON|DEACONESS|DEAN|DEPUTY SUPT|DR|DUCHESS|DUKE|EARL|EF|FLGOFF|FLT LT|FR|FSGT|GEN|GNR|GP CAPT|HON JUDGE|HON JUST|HON|HRH|INSP|JUDGE|JUST|LAC|LACW|LADY|LBDR|LCPL|LORD|LS|LT CMDR|LT COL|LT GEN|LT|MADAM|MAJ GEN|MAJ|MASTER|MATRON|MAYOR|MAYORESS|MIDN|MISS|MON|MOST REV|MR|MRS|MS|PASTOR|PATRIARCH|PLT OFF|PO|PRIOR|PROF|PTE|RABBI|RADM|RECTOR|REV|RF|RT HON|RT REV MON|RT REV|RTREV BISHOP|SBLT|SEN|SGT|SIR|SMN|SNR CONST|SQN LDR|SR|SSGT|SUPR|SWAMI|TF|VADM|VERY REV|VICAR|VISCOUNT|WG CDR|WO|WO1|WO2)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000459", Severity = ProcessMessageSeverity.Error,
                    Description = @"Title is invalid",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.Title.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000459"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT55", Value = GetValueOrEmpty(report.FBT55) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000459
    
            #region VR.ATO.GEN.000459
    
            /*  VR.ATO.GEN.000459
            Title is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.Title.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.Title.Text <> SET(DOMAIN(TITLE CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT11 <> BLANK) AND (NotInDomain(^FBT11, 'TITLE CODES'))
    
            Data Elements:
    
            ^FBT11 = RP:PersonNameDetails:PersonNameDetails.Title.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT11) != true && !(IsMatch(report.FBT11, @"^(2LT|AB|ABBOT|AC|ACM|ADM|AIR CDRE|ALDERMAN|AM|ARCHBISHOP|ARCHDEACON|ASSOC PROF|AVM|BARON|BARONESS|BISHOP|BR|BRIG|CANON|CAPT|CARDINAL|CDRE|CDT|CHAP|CMDR|CMM|COL|CONST|COUNT|COUNTESS|CPL|CPO|DAME|DEACON|DEACONESS|DEAN|DEPUTY SUPT|DR|DUCHESS|DUKE|EARL|EF|FLGOFF|FLT LT|FR|FSGT|GEN|GNR|GP CAPT|HON JUDGE|HON JUST|HON|HRH|INSP|JUDGE|JUST|LAC|LACW|LADY|LBDR|LCPL|LORD|LS|LT CMDR|LT COL|LT GEN|LT|MADAM|MAJ GEN|MAJ|MASTER|MATRON|MAYOR|MAYORESS|MIDN|MISS|MON|MOST REV|MR|MRS|MS|PASTOR|PATRIARCH|PLT OFF|PO|PRIOR|PROF|PTE|RABBI|RADM|RECTOR|REV|RF|RT HON|RT REV MON|RT REV|RTREV BISHOP|SBLT|SEN|SGT|SIR|SMN|SNR CONST|SQN LDR|SR|SSGT|SUPR|SWAMI|TF|VADM|VERY REV|VICAR|VISCOUNT|WG CDR|WO|WO1|WO2)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000459", Severity = ProcessMessageSeverity.Error,
                    Description = @"Title is invalid",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.Title.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000459"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT11", Value = GetValueOrEmpty(report.FBT11) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000459
    
            #region VR.ATO.GEN.000459
    
            /*  VR.ATO.GEN.000459
            Title is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.Title.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.Title.Text <> SET(DOMAIN(TITLE CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT26 <> BLANK) AND (NotInDomain(^FBT26, 'TITLE CODES'))
    
            Data Elements:
    
            ^FBT26 = RP:PersonNameDetails:PersonNameDetails.Title.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT26) != true && !(IsMatch(report.FBT26, @"^(2LT|AB|ABBOT|AC|ACM|ADM|AIR CDRE|ALDERMAN|AM|ARCHBISHOP|ARCHDEACON|ASSOC PROF|AVM|BARON|BARONESS|BISHOP|BR|BRIG|CANON|CAPT|CARDINAL|CDRE|CDT|CHAP|CMDR|CMM|COL|CONST|COUNT|COUNTESS|CPL|CPO|DAME|DEACON|DEACONESS|DEAN|DEPUTY SUPT|DR|DUCHESS|DUKE|EARL|EF|FLGOFF|FLT LT|FR|FSGT|GEN|GNR|GP CAPT|HON JUDGE|HON JUST|HON|HRH|INSP|JUDGE|JUST|LAC|LACW|LADY|LBDR|LCPL|LORD|LS|LT CMDR|LT COL|LT GEN|LT|MADAM|MAJ GEN|MAJ|MASTER|MATRON|MAYOR|MAYORESS|MIDN|MISS|MON|MOST REV|MR|MRS|MS|PASTOR|PATRIARCH|PLT OFF|PO|PRIOR|PROF|PTE|RABBI|RADM|RECTOR|REV|RF|RT HON|RT REV MON|RT REV|RTREV BISHOP|SBLT|SEN|SGT|SIR|SMN|SNR CONST|SQN LDR|SR|SSGT|SUPR|SWAMI|TF|VADM|VERY REV|VICAR|VISCOUNT|WG CDR|WO|WO1|WO2)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000459", Severity = ProcessMessageSeverity.Error,
                    Description = @"Title is invalid",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.Title.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000459"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT26", Value = GetValueOrEmpty(report.FBT26) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000459
    
            #region VR.ATO.GEN.000459
    
            /*  VR.ATO.GEN.000459
            Title is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.Title.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.Title.Text <> SET(DOMAIN(TITLE CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT5 <> BLANK) AND (NotInDomain(^FBT5, 'TITLE CODES'))
    
            Data Elements:
    
            ^FBT5 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.Title.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT5) != true && !(IsMatch(report.FBT5, @"^(2LT|AB|ABBOT|AC|ACM|ADM|AIR CDRE|ALDERMAN|AM|ARCHBISHOP|ARCHDEACON|ASSOC PROF|AVM|BARON|BARONESS|BISHOP|BR|BRIG|CANON|CAPT|CARDINAL|CDRE|CDT|CHAP|CMDR|CMM|COL|CONST|COUNT|COUNTESS|CPL|CPO|DAME|DEACON|DEACONESS|DEAN|DEPUTY SUPT|DR|DUCHESS|DUKE|EARL|EF|FLGOFF|FLT LT|FR|FSGT|GEN|GNR|GP CAPT|HON JUDGE|HON JUST|HON|HRH|INSP|JUDGE|JUST|LAC|LACW|LADY|LBDR|LCPL|LORD|LS|LT CMDR|LT COL|LT GEN|LT|MADAM|MAJ GEN|MAJ|MASTER|MATRON|MAYOR|MAYORESS|MIDN|MISS|MON|MOST REV|MR|MRS|MS|PASTOR|PATRIARCH|PLT OFF|PO|PRIOR|PROF|PTE|RABBI|RADM|RECTOR|REV|RF|RT HON|RT REV MON|RT REV|RTREV BISHOP|SBLT|SEN|SGT|SIR|SMN|SNR CONST|SQN LDR|SR|SSGT|SUPR|SWAMI|TF|VADM|VERY REV|VICAR|VISCOUNT|WG CDR|WO|WO1|WO2)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000459", Severity = ProcessMessageSeverity.Error,
                    Description = @"Title is invalid",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.Title.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000459"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT5", Value = GetValueOrEmpty(report.FBT5) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000459
    
            #region VR.ATO.GEN.000459
    
            /*  VR.ATO.GEN.000459
            Title is invalid
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.Title.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.Title.Text <> SET(DOMAIN(TITLE CODES)))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT49 <> BLANK) AND (NotInDomain(^FBT49, 'TITLE CODES'))
    
            Data Elements:
    
            ^FBT49 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.Title.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT49) != true && !(IsMatch(report.FBT49, @"^(2LT|AB|ABBOT|AC|ACM|ADM|AIR CDRE|ALDERMAN|AM|ARCHBISHOP|ARCHDEACON|ASSOC PROF|AVM|BARON|BARONESS|BISHOP|BR|BRIG|CANON|CAPT|CARDINAL|CDRE|CDT|CHAP|CMDR|CMM|COL|CONST|COUNT|COUNTESS|CPL|CPO|DAME|DEACON|DEACONESS|DEAN|DEPUTY SUPT|DR|DUCHESS|DUKE|EARL|EF|FLGOFF|FLT LT|FR|FSGT|GEN|GNR|GP CAPT|HON JUDGE|HON JUST|HON|HRH|INSP|JUDGE|JUST|LAC|LACW|LADY|LBDR|LCPL|LORD|LS|LT CMDR|LT COL|LT GEN|LT|MADAM|MAJ GEN|MAJ|MASTER|MATRON|MAYOR|MAYORESS|MIDN|MISS|MON|MOST REV|MR|MRS|MS|PASTOR|PATRIARCH|PLT OFF|PO|PRIOR|PROF|PTE|RABBI|RADM|RECTOR|REV|RF|RT HON|RT REV MON|RT REV|RTREV BISHOP|SBLT|SEN|SGT|SIR|SMN|SNR CONST|SQN LDR|SR|SSGT|SUPR|SWAMI|TF|VADM|VERY REV|VICAR|VISCOUNT|WG CDR|WO|WO1|WO2)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000459", Severity = ProcessMessageSeverity.Error,
                    Description = @"Title is invalid",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.Title.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.000459"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT49", Value = GetValueOrEmpty(report.FBT49) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.000459
    
            #region VR.ATO.GEN.010028
    
            /*  VR.ATO.GEN.010028
            If the return is an amendment, sequence number, type and reason must be present
    
            Legacy Rule Format:
            IF pyin.xx.xx:Report.Amendment.Indicator = TRUE AND (pyin.xx.xx:Report.AmendmentSequence.Number = NULL OR pyin.xx.xx:Report.AmendmentType.Code = NULLORBLANK OR pyin.xx.xx:Report.AmendmentReason.Text = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT234 = TRUE AND (^FBT235 = NULL OR ^FBT236 = BLANK OR ^FBT237 = BLANK)
    
            Data Elements:
    
            ^FBT234 = RP:Report.Amendment.Indicator
    
            ^FBT235 = RP:Report.AmendmentSequence.Number
    
            ^FBT236 = RP:Report.AmendmentType.Code
    
            ^FBT237 = RP:Report.AmendmentReason.Text
            */
            assertion = (report.FBT234 == true && (report.FBT235 == null || string.IsNullOrWhiteSpace(report.FBT236) == true || string.IsNullOrWhiteSpace(report.FBT237) == true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010028", Severity = ProcessMessageSeverity.Error,
                    Description = @"If the return is an amendment, sequence number, type and reason must be present",
                    LongDescription = @"If the Amendment Indicator is 'yes' (true), then the Amendment Sequence Number, Amendment Type and Amendment Reason must be present and not blank.",
                    Location = "/xbrli:xbrl/tns:Report.Amendment.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.010028"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT234", Value = GetValueOrEmpty(report.FBT234) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT235", Value = report.FBT235.GetValueOrDefault().ToString() });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT236", Value = GetValueOrEmpty(report.FBT236) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT237", Value = GetValueOrEmpty(report.FBT237) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.010028
    
            #region VR.ATO.GEN.010029
    
            /*  VR.ATO.GEN.010029
            If the return is an amendment, Amendment Indicator must be 'yes' (true)
    
            Legacy Rule Format:
            IF pyin.xx.xx:Report.Amendment.Indicator <> TRUE AND (pyin.xx.xx:Report.AmendmentSequence.Number <> NULL OR pyin.xx.xx:Report.AmendmentType.Code <> NULLORBLANK OR pyin.xx.xx:Report.AmendmentReason.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT234 <> TRUE AND (^FBT235 <> NULL OR ^FBT236 <> BLANK OR ^FBT237 <> BLANK)
    
            Data Elements:
    
            ^FBT234 = RP:Report.Amendment.Indicator
    
            ^FBT235 = RP:Report.AmendmentSequence.Number
    
            ^FBT236 = RP:Report.AmendmentType.Code
    
            ^FBT237 = RP:Report.AmendmentReason.Text
            */
            assertion = (report.FBT234 != true && (report.FBT235 != null || string.IsNullOrWhiteSpace(report.FBT236) != true || string.IsNullOrWhiteSpace(report.FBT237) != true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010029", Severity = ProcessMessageSeverity.Error,
                    Description = @"If the return is an amendment, Amendment Indicator must be 'yes' (true)",
                    LongDescription = @"If an Amendment Sequence Number, Amendment Type or Amendment Reason is present, then the Amendment Indicator must be 'yes' (true)",
                    Location = "/xbrli:xbrl/tns:Report.Amendment.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.010029"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT234", Value = GetValueOrEmpty(report.FBT234) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT235", Value = report.FBT235.GetValueOrDefault().ToString() });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT236", Value = GetValueOrEmpty(report.FBT236) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT237", Value = GetValueOrEmpty(report.FBT237) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.010029
    
            #region VR.ATO.GEN.010030
    
            /*  VR.ATO.GEN.010030
            Amendment sequence number must be a number between 1 and 9
    
            Legacy Rule Format:
            IF pyin.xx.xx:Report.AmendmentSequence.Number <> NULL AND pyin.xx.xx:Report.AmendmentSequence.Number <> SET(1-9)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT235 <> NULL AND (^FBT235 < 1 OR ^FBT235 > 9)
    
            Data Elements:
    
            ^FBT235 = RP:Report.AmendmentSequence.Number
            */
            assertion = (report.FBT235 != null && (report.FBT235.GetValueOrDefault() < 1 || report.FBT235.GetValueOrDefault() > 9));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010030", Severity = ProcessMessageSeverity.Error,
                    Description = @"Amendment sequence number must be a number between 1 and 9",
                    Location = "/xbrli:xbrl/tns:Report.AmendmentSequence.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.010030"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT235", Value = report.FBT235.GetValueOrDefault().ToString() });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.010030
    
            #region VR.ATO.GEN.300003
    
            /*  VR.ATO.GEN.300003
            For an Australian address, state or territory must be one of: ACT, NSW, NT, QLD, SA, VIC, WA, TAS, AAT
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.StateOrTerritory.Code <> NULLORBLANK)
            AND (pyde.xx.xx:AddressDetails.StateOrTerritory.Code <> SET ("ACT","NSW","NT","QLD","SA","VIC","WA","TAS","AAT"))
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT46 <> BLANK) AND (NotInSet(^FBT46, '"ACT","NSW","NT","QLD","SA","VIC","WA","TAS","AAT"'))
    
            Data Elements:
    
            ^FBT46 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT46) != true && !(IsMatch(report.FBT46, @"^(ACT|NSW|NT|QLD|SA|VIC|WA|TAS|AAT)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.300003", Severity = ProcessMessageSeverity.Error,
                    Description = @"For an Australian address, state or territory must be one of: ACT, NSW, NT, QLD, SA, VIC, WA, TAS, AAT",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.StateOrTerritory.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.300003"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT46", Value = GetValueOrEmpty(report.FBT46) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.300003
    
            #region VR.ATO.GEN.300003
    
            /*  VR.ATO.GEN.300003
            For an Australian address, state or territory must be one of: ACT, NSW, NT, QLD, SA, VIC, WA, TAS, AAT
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.StateOrTerritory.Code <> NULLORBLANK)
            AND (pyde.xx.xx:AddressDetails.StateOrTerritory.Code <> SET ("ACT","NSW","NT","QLD","SA","VIC","WA","TAS","AAT"))
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT22 <> BLANK) AND (NotInSet(^FBT22, '"ACT","NSW","NT","QLD","SA","VIC","WA","TAS","AAT"'))
    
            Data Elements:
    
            ^FBT22 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT22) != true && !(IsMatch(report.FBT22, @"^(ACT|NSW|NT|QLD|SA|VIC|WA|TAS|AAT)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.300003", Severity = ProcessMessageSeverity.Error,
                    Description = @"For an Australian address, state or territory must be one of: ACT, NSW, NT, QLD, SA, VIC, WA, TAS, AAT",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.StateOrTerritory.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.300003"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT22", Value = GetValueOrEmpty(report.FBT22) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.300003
    
            #region VR.ATO.GEN.300003
    
            /*  VR.ATO.GEN.300003
            For an Australian address, state or territory must be one of: ACT, NSW, NT, QLD, SA, VIC, WA, TAS, AAT
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.StateOrTerritory.Code <> NULLORBLANK)
            AND (pyde.xx.xx:AddressDetails.StateOrTerritory.Code <> SET ("ACT","NSW","NT","QLD","SA","VIC","WA","TAS","AAT"))
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT37 <> BLANK) AND (NotInSet(^FBT37, '"ACT","NSW","NT","QLD","SA","VIC","WA","TAS","AAT"'))
    
            Data Elements:
    
            ^FBT37 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT37) != true && !(IsMatch(report.FBT37, @"^(ACT|NSW|NT|QLD|SA|VIC|WA|TAS|AAT)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.300003", Severity = ProcessMessageSeverity.Error,
                    Description = @"For an Australian address, state or territory must be one of: ACT, NSW, NT, QLD, SA, VIC, WA, TAS, AAT",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.StateOrTerritory.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.300003"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT37", Value = GetValueOrEmpty(report.FBT37) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.300003
    
            #region VR.ATO.GEN.408010
    
            /*  VR.ATO.GEN.408010
            Name field cannot contain 'space hyphen space'.
    
            Legacy Rule Format:
            WHERE IN TUPLE(personunstructuredname1.xx.xx:PersonUnstructuredName)
            IF (pyde.xx.xx:PersonUnstructuredName.FullName.Text CONTAINS " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT129, ' - ')
    
            Data Elements:
    
            ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']
            */
            assertion = (report.FBT129 == null ? false : report.FBT129.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.408010", Severity = ProcessMessageSeverity.Error,
                    Description = @"Name field cannot contain 'space hyphen space'.",
                    LongDescription = @"Name field cannot contain 'space hyphen space'.",
                    Location = "/xbrli:xbrl/tns:PersonUnstructuredName" + OccurrenceIndex(report.PersonUnstructuredNameCollection_Contact_INTOccurrenceIndex) + "/tns:PersonUnstructuredName.FullName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.408010"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT129", Value = report.FBT129 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.408010
    
            #region VR.ATO.GEN.410002
    
            /*  VR.ATO.GEN.410002
            Address Line 2 must be present if Address Line 1 contains 'C/-'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF ((pyde.xx.xx:AddressDetails.Line1.Text CONTAINS "C/-") AND (pyde.xx.xx:AddressDetails.Line2.Text = NULLORBLANK))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ((Contains(^FBT41, 'C/-')) AND (^FBT42 = BLANK))
    
            Data Elements:
    
            ^FBT41 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT42 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = ((report.FBT41 == null ? false : report.FBT41.ToUpperInvariant().Contains(@"C/-")) && string.IsNullOrWhiteSpace(report.FBT42) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410002", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 2 must be present if Address Line 1 contains 'C/-'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410002"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT41", Value = report.FBT41 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT42", Value = GetValueOrEmpty(report.FBT42) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410002
    
            #region VR.ATO.GEN.410002
    
            /*  VR.ATO.GEN.410002
            Address Line 2 must be present if Address Line 1 contains 'C/-'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF ((pyde.xx.xx:AddressDetails.Line1.Text CONTAINS "C/-") AND (pyde.xx.xx:AddressDetails.Line2.Text = NULLORBLANK))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ((Contains(^FBT17, 'C/-')) AND (^FBT18 = BLANK))
    
            Data Elements:
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT18 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = ((report.FBT17 == null ? false : report.FBT17.ToUpperInvariant().Contains(@"C/-")) && string.IsNullOrWhiteSpace(report.FBT18) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410002", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 2 must be present if Address Line 1 contains 'C/-'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410002"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT18", Value = GetValueOrEmpty(report.FBT18) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410002
    
            #region VR.ATO.GEN.410002
    
            /*  VR.ATO.GEN.410002
            Address Line 2 must be present if Address Line 1 contains 'C/-'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF ((pyde.xx.xx:AddressDetails.Line1.Text CONTAINS "C/-") AND (pyde.xx.xx:AddressDetails.Line2.Text = NULLORBLANK))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ((Contains(^FBT32, 'C/-')) AND (^FBT33 = BLANK))
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT33 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = ((report.FBT32 == null ? false : report.FBT32.ToUpperInvariant().Contains(@"C/-")) && string.IsNullOrWhiteSpace(report.FBT33) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410002", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 2 must be present if Address Line 1 contains 'C/-'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410002"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT33", Value = GetValueOrEmpty(report.FBT33) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410002
    
            #region VR.ATO.GEN.410008
    
            /*  VR.ATO.GEN.410008
            Address Line 3 must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line3.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT43 <> BLANK
    
            Data Elements:
    
            ^FBT43 = RP:AddressDetails:AddressDetails.Line3.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT43) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410008", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 3 must be left blank",
                    LongDescription = @"Lines 3 and 4 of the address are not used on this form",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line3.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410008"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT43", Value = GetValueOrEmpty(report.FBT43) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410008
    
            #region VR.ATO.GEN.410008
    
            /*  VR.ATO.GEN.410008
            Address Line 3 must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line3.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT19 <> BLANK
    
            Data Elements:
    
            ^FBT19 = RP:AddressDetails:AddressDetails.Line3.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT19) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410008", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 3 must be left blank",
                    LongDescription = @"Lines 3 and 4 of the address are not used on this form",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line3.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410008"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT19", Value = GetValueOrEmpty(report.FBT19) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410008
    
            #region VR.ATO.GEN.410008
    
            /*  VR.ATO.GEN.410008
            Address Line 3 must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line3.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT34 <> BLANK
    
            Data Elements:
    
            ^FBT34 = RP:AddressDetails:AddressDetails.Line3.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT34) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410008", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 3 must be left blank",
                    LongDescription = @"Lines 3 and 4 of the address are not used on this form",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line3.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410008"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT34", Value = GetValueOrEmpty(report.FBT34) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410008
    
            #region VR.ATO.GEN.410013
    
            /*  VR.ATO.GEN.410013
            Address Line 4 must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line4.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT44 <> BLANK
    
            Data Elements:
    
            ^FBT44 = RP:AddressDetails:AddressDetails.Line4.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT44) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410013", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 4 must be left blank",
                    LongDescription = @"Lines 3 and 4 of the address are not used on this form",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line4.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT44", Value = GetValueOrEmpty(report.FBT44) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410013
    
            #region VR.ATO.GEN.410013
    
            /*  VR.ATO.GEN.410013
            Address Line 4 must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line4.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT20 <> BLANK
    
            Data Elements:
    
            ^FBT20 = RP:AddressDetails:AddressDetails.Line4.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT20) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410013", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 4 must be left blank",
                    LongDescription = @"Lines 3 and 4 of the address are not used on this form",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line4.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT20", Value = GetValueOrEmpty(report.FBT20) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410013
    
            #region VR.ATO.GEN.410013
    
            /*  VR.ATO.GEN.410013
            Address Line 4 must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line4.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT35 <> BLANK
    
            Data Elements:
    
            ^FBT35 = RP:AddressDetails:AddressDetails.Line4.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT35) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410013", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 4 must be left blank",
                    LongDescription = @"Lines 3 and 4 of the address are not used on this form",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line4.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410013"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT35", Value = GetValueOrEmpty(report.FBT35) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410013
    
            #region VR.ATO.GEN.410038
    
            /*  VR.ATO.GEN.410038
            Non-individual name field cannot contain 'Pship', 'P'ship or 'P/Ship'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text STARTSWITH "T/A ") AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" Pship"," P'ship"," P/ship"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT40, 'T/A ')) AND (EndsWithSet(^FBT40, '" Pship"," P'ship"," P/ship"'))
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (IsMatch(report.FBT40, @"^(T/A )",RegexOptions.IgnoreCase) && IsMatch(report.FBT40, @"( Pship| P'ship| P/ship)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410038", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non-individual name field cannot start with 'T/A' and end with 'Pship', 'P'ship or 'P/Ship'",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410038"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410038
    
            #region VR.ATO.GEN.410038
    
            /*  VR.ATO.GEN.410038
            Non-individual name field cannot contain 'Pship', 'P'ship or 'P/Ship'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text STARTSWITH "T/A ") AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" Pship"," P'ship"," P/ship"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT16, 'T/A ')) AND (EndsWithSet(^FBT16, '" Pship"," P'ship"," P/ship"'))
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (IsMatch(report.FBT16, @"^(T/A )",RegexOptions.IgnoreCase) && IsMatch(report.FBT16, @"( Pship| P'ship| P/ship)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410038", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non-individual name field cannot start with 'T/A' and end with 'Pship', 'P'ship or 'P/Ship'",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410038"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410038
    
            #region VR.ATO.GEN.410038
    
            /*  VR.ATO.GEN.410038
            Non-individual name field cannot contain 'Pship', 'P'ship or 'P/Ship'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text STARTSWITH "T/A ") AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" Pship"," P'ship"," P/ship"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT31, 'T/A ')) AND (EndsWithSet(^FBT31, '" Pship"," P'ship"," P/ship"'))
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (IsMatch(report.FBT31, @"^(T/A )",RegexOptions.IgnoreCase) && IsMatch(report.FBT31, @"( Pship| P'ship| P/ship)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410038", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non-individual name field cannot start with 'T/A' and end with 'Pship', 'P'ship or 'P/Ship'",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410038"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410038
    
            #region VR.ATO.GEN.410038
    
            /*  VR.ATO.GEN.410038
            Non-individual name field cannot contain 'Pship', 'P'ship or 'P/Ship'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text STARTSWITH "T/A ") AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" Pship"," P'ship"," P/ship"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT10, 'T/A ')) AND (EndsWithSet(^FBT10, '" Pship"," P'ship"," P/ship"'))
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (IsMatch(report.FBT10, @"^(T/A )",RegexOptions.IgnoreCase) && IsMatch(report.FBT10, @"( Pship| P'ship| P/ship)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410038", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non-individual name field cannot start with 'T/A' and end with 'Pship', 'P'ship or 'P/Ship'",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410038"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410038
    
            #region VR.ATO.GEN.410038
    
            /*  VR.ATO.GEN.410038
            Non-individual name field cannot contain 'Pship', 'P'ship or 'P/Ship'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text STARTSWITH "T/A ") AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" Pship"," P'ship"," P/ship"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT54, 'T/A ')) AND (EndsWithSet(^FBT54, '" Pship"," P'ship"," P/ship"'))
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (IsMatch(report.FBT54, @"^(T/A )",RegexOptions.IgnoreCase) && IsMatch(report.FBT54, @"( Pship| P'ship| P/ship)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410038", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non-individual name field cannot start with 'T/A' and end with 'Pship', 'P'ship or 'P/Ship'",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410038"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410038
    
            #region VR.ATO.GEN.410039
    
            /*  VR.ATO.GEN.410039
            Organisation name must contain at least one alpha or numeric character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  <> NULLORBLANK) AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  DOES NOT CONTAIN SET("a-z", "A-Z", "0-9"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT40  <> BLANK) AND (NotContainsSet(^FBT40, '"a-z", "A-Z", "0-9"'))
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT40) != true && !(IsMatch(report.FBT40, @"[a-z]|[A-Z]|[0-9]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410039", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must contain at least one alpha or numeric character",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410039"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410039
    
            #region VR.ATO.GEN.410039
    
            /*  VR.ATO.GEN.410039
            Organisation name must contain at least one alpha or numeric character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  <> NULLORBLANK) AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  DOES NOT CONTAIN SET("a-z", "A-Z", "0-9"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT16  <> BLANK) AND (NotContainsSet(^FBT16, '"a-z", "A-Z", "0-9"'))
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT16) != true && !(IsMatch(report.FBT16, @"[a-z]|[A-Z]|[0-9]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410039", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must contain at least one alpha or numeric character",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410039"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410039
    
            #region VR.ATO.GEN.410039
    
            /*  VR.ATO.GEN.410039
            Organisation name must contain at least one alpha or numeric character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  <> NULLORBLANK) AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  DOES NOT CONTAIN SET("a-z", "A-Z", "0-9"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT31  <> BLANK) AND (NotContainsSet(^FBT31, '"a-z", "A-Z", "0-9"'))
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT31) != true && !(IsMatch(report.FBT31, @"[a-z]|[A-Z]|[0-9]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410039", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must contain at least one alpha or numeric character",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410039"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410039
    
            #region VR.ATO.GEN.410039
    
            /*  VR.ATO.GEN.410039
            Organisation name must contain at least one alpha or numeric character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  <> NULLORBLANK) AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  DOES NOT CONTAIN SET("a-z", "A-Z", "0-9"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT10  <> BLANK) AND (NotContainsSet(^FBT10, '"a-z", "A-Z", "0-9"'))
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT10) != true && !(IsMatch(report.FBT10, @"[a-z]|[A-Z]|[0-9]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410039", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must contain at least one alpha or numeric character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410039"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410039
    
            #region VR.ATO.GEN.410039
    
            /*  VR.ATO.GEN.410039
            Organisation name must contain at least one alpha or numeric character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  <> NULLORBLANK) AND (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text  DOES NOT CONTAIN SET("a-z", "A-Z", "0-9"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT54  <> BLANK) AND (NotContainsSet(^FBT54, '"a-z", "A-Z", "0-9"'))
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT54) != true && !(IsMatch(report.FBT54, @"[a-z]|[A-Z]|[0-9]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410039", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must contain at least one alpha or numeric character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410039"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410039
    
            #region VR.ATO.GEN.410040
    
            /*  VR.ATO.GEN.410040
            Family name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.FamilyName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT56 <> BLANK) AND (NotContainsSet(^FBT56, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT56) != true && !(IsMatch(report.FBT56, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410040", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410040"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410040
    
            #region VR.ATO.GEN.410040
    
            /*  VR.ATO.GEN.410040
            Family name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.FamilyName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT12 <> BLANK) AND (NotContainsSet(^FBT12, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT12) != true && !(IsMatch(report.FBT12, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410040", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410040"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410040
    
            #region VR.ATO.GEN.410040
    
            /*  VR.ATO.GEN.410040
            Family name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.FamilyName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT27 <> BLANK) AND (NotContainsSet(^FBT27, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT27) != true && !(IsMatch(report.FBT27, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410040", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410040"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410040
    
            #region VR.ATO.GEN.410040
    
            /*  VR.ATO.GEN.410040
            Family name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.FamilyName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT6 <> BLANK) AND (NotContainsSet(^FBT6, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT6) != true && !(IsMatch(report.FBT6, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410040", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410040"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT6", Value = report.FBT6 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410040
    
            #region VR.ATO.GEN.410040
    
            /*  VR.ATO.GEN.410040
            Family name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.FamilyName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT50 <> BLANK) AND (NotContainsSet(^FBT50, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT50 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT50) != true && !(IsMatch(report.FBT50, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410040", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410040"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT50", Value = report.FBT50 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410040
    
            #region VR.ATO.GEN.410063
    
            /*  VR.ATO.GEN.410063
            Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT58 <> BLANK) AND (NotContainsSet(^FBT58, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT58) != true && !(IsMatch(report.FBT58, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410063"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410063
    
            #region VR.ATO.GEN.410063
    
            /*  VR.ATO.GEN.410063
            Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT14 <> BLANK) AND (NotContainsSet(^FBT14, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT14) != true && !(IsMatch(report.FBT14, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410063"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410063
    
            #region VR.ATO.GEN.410063
    
            /*  VR.ATO.GEN.410063
            Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT29 <> BLANK) AND (NotContainsSet(^FBT29, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT29) != true && !(IsMatch(report.FBT29, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410063"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410063
    
            #region VR.ATO.GEN.410063
    
            /*  VR.ATO.GEN.410063
            Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT8 <> BLANK) AND (NotContainsSet(^FBT8, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT8 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT8) != true && !(IsMatch(report.FBT8, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410063"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT8", Value = GetValueOrEmpty(report.FBT8) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410063
    
            #region VR.ATO.GEN.410063
    
            /*  VR.ATO.GEN.410063
            Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT52 <> BLANK) AND (NotContainsSet(^FBT52, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT52 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT52) != true && !(IsMatch(report.FBT52, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410063"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT52", Value = GetValueOrEmpty(report.FBT52) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410063
    
            #region VR.ATO.GEN.410131
    
            /*  VR.ATO.GEN.410131
            Other Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT59 <> BLANK) AND (NotContainsSet(^FBT59, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT59) != true && !(IsMatch(report.FBT59, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410131", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410131"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410131
    
            #region VR.ATO.GEN.410131
    
            /*  VR.ATO.GEN.410131
            Other Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT15 <> BLANK) AND (NotContainsSet(^FBT15, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT15) != true && !(IsMatch(report.FBT15, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410131", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410131"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410131
    
            #region VR.ATO.GEN.410131
    
            /*  VR.ATO.GEN.410131
            Other Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT30 <> BLANK) AND (NotContainsSet(^FBT30, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT30) != true && !(IsMatch(report.FBT30, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410131", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410131"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410131
    
            #region VR.ATO.GEN.410131
    
            /*  VR.ATO.GEN.410131
            Other Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT9 <> BLANK) AND (NotContainsSet(^FBT9, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT9 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT9) != true && !(IsMatch(report.FBT9, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410131", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410131"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT9", Value = GetValueOrEmpty(report.FBT9) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410131
    
            #region VR.ATO.GEN.410131
    
            /*  VR.ATO.GEN.410131
            Other Given Name must contain at least one alphabetical character
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text DOES NOT CONTAIN SET("A-Z","a-z"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT53 <> BLANK) AND (NotContainsSet(^FBT53, '"A-Z","a-z"'))
    
            Data Elements:
    
            ^FBT53 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT53) != true && !(IsMatch(report.FBT53, @"[A-Z]|[a-z]",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410131", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other Given Name must contain at least one alphabetical character",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410131"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT53", Value = GetValueOrEmpty(report.FBT53) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410131
    
            #region VR.ATO.GEN.410191
    
            /*  VR.ATO.GEN.410191
            Country code must be present for overseas address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = TRUE) AND (pyde.xx.xx:AddressDetails.Country.Code = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT164 = TRUE) AND (^FBT224 = NULL)
    
            Data Elements:
    
            ^FBT224 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT164 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT164 == true && report.FBT224 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410191", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country code must be present for overseas address",
                    LongDescription = @"When the overseas address indicator is 'TRUE', the corresponding Country Code must be supplied",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410191"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT164", Value = GetValueOrEmpty(report.FBT164) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT224", Value = GetValueOrEmpty(report.FBT224) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410191
    
            #region VR.ATO.GEN.410191
    
            /*  VR.ATO.GEN.410191
            Country code must be present for overseas address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = TRUE) AND (pyde.xx.xx:AddressDetails.Country.Code = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT25 = TRUE) AND (^FBT222 = NULL)
    
            Data Elements:
    
            ^FBT222 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT25 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT25 == true && report.FBT222 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410191", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country code must be present for overseas address",
                    LongDescription = @"When the overseas address indicator is 'TRUE', the corresponding Country Code must be supplied",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410191"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT25", Value = GetValueOrEmpty(report.FBT25) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT222", Value = GetValueOrEmpty(report.FBT222) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410191
    
            #region VR.ATO.GEN.410191
    
            /*  VR.ATO.GEN.410191
            Country code must be present for overseas address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = TRUE) AND (pyde.xx.xx:AddressDetails.Country.Code = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT159 = TRUE) AND (^FBT223 = NULL)
    
            Data Elements:
    
            ^FBT223 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT159 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (report.FBT159 == true && report.FBT223 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410191", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country code must be present for overseas address",
                    LongDescription = @"When the overseas address indicator is 'TRUE', the corresponding Country Code must be supplied",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410191"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT159", Value = GetValueOrEmpty(report.FBT159) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT223", Value = GetValueOrEmpty(report.FBT223) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410191
    
            #region VR.ATO.GEN.410192
    
            /*  VR.ATO.GEN.410192
            Country code must be a valid code
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Country.Code <> SET(DOMAIN(COUNTRY CODES)))
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT224 <> BLANK) AND (NotInDomain(^FBT224, 'COUNTRY CODES'))
    
            Data Elements:
    
            ^FBT224 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT224) != true && !(IsMatch(report.FBT224, @"^(ad|ae|af|ag|ai|al|am|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bl|bm|bn|bo|bq|br|bs|bt|bv|bw|by|bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cu|cv|cw|cx|cy|cz|de|dj|dk|dm|do|dz|ec|ee|eg|eh|er|es|et|fi|fj|fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mf|mg|mh|mk|ml|mm|mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|sk|sl|sm|sn|so|sr|ss|st|sv|sx|sy|sz|tc|td|tf|tg|th|tj|tk|tl|tm|tn|to|tr|tt|tv|tw|tz|ua|ug|um|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|za|zm|zw)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410192", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country code must be a valid code",
                    LongDescription = @"Country Code must be one of the two character lower-case codes from Australian Standard 4590, Section 5, Sub-section 5.15",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410192"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT224", Value = GetValueOrEmpty(report.FBT224) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410192
    
            #region VR.ATO.GEN.410192
    
            /*  VR.ATO.GEN.410192
            Country code must be a valid code
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Country.Code <> SET(DOMAIN(COUNTRY CODES)))
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT222 <> BLANK) AND (NotInDomain(^FBT222, 'COUNTRY CODES'))
    
            Data Elements:
    
            ^FBT222 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT222) != true && !(IsMatch(report.FBT222, @"^(ad|ae|af|ag|ai|al|am|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bl|bm|bn|bo|bq|br|bs|bt|bv|bw|by|bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cu|cv|cw|cx|cy|cz|de|dj|dk|dm|do|dz|ec|ee|eg|eh|er|es|et|fi|fj|fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mf|mg|mh|mk|ml|mm|mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|sk|sl|sm|sn|so|sr|ss|st|sv|sx|sy|sz|tc|td|tf|tg|th|tj|tk|tl|tm|tn|to|tr|tt|tv|tw|tz|ua|ug|um|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|za|zm|zw)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410192", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country code must be a valid code",
                    LongDescription = @"Country Code must be one of the two character lower-case codes from Australian Standard 4590, Section 5, Sub-section 5.15",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410192"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT222", Value = GetValueOrEmpty(report.FBT222) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410192
    
            #region VR.ATO.GEN.410192
    
            /*  VR.ATO.GEN.410192
            Country code must be a valid code
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Country.Code <> SET(DOMAIN(COUNTRY CODES)))
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT223 <> BLANK) AND (NotInDomain(^FBT223, 'COUNTRY CODES'))
    
            Data Elements:
    
            ^FBT223 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT223) != true && !(IsMatch(report.FBT223, @"^(ad|ae|af|ag|ai|al|am|ao|aq|ar|as|at|au|aw|ax|az|ba|bb|bd|be|bf|bg|bh|bi|bj|bl|bm|bn|bo|bq|br|bs|bt|bv|bw|by|bz|ca|cc|cd|cf|cg|ch|ci|ck|cl|cm|cn|co|cr|cu|cv|cw|cx|cy|cz|de|dj|dk|dm|do|dz|ec|ee|eg|eh|er|es|et|fi|fj|fk|fm|fo|fr|ga|gb|gd|ge|gf|gg|gh|gi|gl|gm|gn|gp|gq|gr|gs|gt|gu|gw|gy|hk|hm|hn|hr|ht|hu|id|ie|il|im|in|io|iq|ir|is|it|je|jm|jo|jp|ke|kg|kh|ki|km|kn|kp|kr|kw|ky|kz|la|lb|lc|li|lk|lr|ls|lt|lu|lv|ly|ma|mc|md|me|mf|mg|mh|mk|ml|mm|mn|mo|mp|mq|mr|ms|mt|mu|mv|mw|mx|my|mz|na|nc|ne|nf|ng|ni|nl|no|np|nr|nu|nz|om|pa|pe|pf|pg|ph|pk|pl|pm|pn|pr|ps|pt|pw|py|qa|re|ro|rs|ru|rw|sa|sb|sc|sd|se|sg|sh|si|sj|sk|sl|sm|sn|so|sr|ss|st|sv|sx|sy|sz|tc|td|tf|tg|th|tj|tk|tl|tm|tn|to|tr|tt|tv|tw|tz|ua|ug|um|us|uy|uz|va|vc|ve|vg|vi|vn|vu|wf|ws|ye|yt|za|zm|zw)$",RegexOptions.IgnoreCase)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410192", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country code must be a valid code",
                    LongDescription = @"Country Code must be one of the two character lower-case codes from Australian Standard 4590, Section 5, Sub-section 5.15",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410192"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT223", Value = GetValueOrEmpty(report.FBT223) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410192
    
            #region VR.ATO.GEN.410194
    
            /*  VR.ATO.GEN.410194
            Address Line 1 must not exceed 38 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:AddressDetails.Line1.Text) > 38
                 RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT41) > 38
    
            Data Elements:
    
            ^FBT41 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT41) > 38);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410194", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must not exceed 38 characters",
                    LongDescription = @"Although SBR sets a limit of 50 characters for the Line 1 of an address, the maximum allowable for this form is 38",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410194"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT41", Value = report.FBT41 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410194
    
            #region VR.ATO.GEN.410194
    
            /*  VR.ATO.GEN.410194
            Address Line 1 must not exceed 38 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:AddressDetails.Line1.Text) > 38
                 RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT17) > 38
    
            Data Elements:
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT17) > 38);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410194", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must not exceed 38 characters",
                    LongDescription = @"Although SBR sets a limit of 50 characters for the Line 1 of an address, the maximum allowable for this form is 38",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410194"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410194
    
            #region VR.ATO.GEN.410194
    
            /*  VR.ATO.GEN.410194
            Address Line 1 must not exceed 38 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:AddressDetails.Line1.Text) > 38
                 RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT32) > 38
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT32) > 38);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410194", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must not exceed 38 characters",
                    LongDescription = @"Although SBR sets a limit of 50 characters for the Line 1 of an address, the maximum allowable for this form is 38",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410194"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410194
    
            #region VR.ATO.GEN.410195
    
            /*  VR.ATO.GEN.410195
            Address Line 2 must not exceed 38 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:AddressDetails.Line2.Text) > 38
                 RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT42) > 38
    
            Data Elements:
    
            ^FBT42 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT42) > 38);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410195", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 2 must not exceed 38 characters",
                    LongDescription = @"Although SBR sets a limit of 50 characters for the Line 2 of an address, the maximum allowable for this form is 38",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410195"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT42", Value = GetValueOrEmpty(report.FBT42) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410195
    
            #region VR.ATO.GEN.410195
    
            /*  VR.ATO.GEN.410195
            Address Line 2 must not exceed 38 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:AddressDetails.Line2.Text) > 38
                 RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT18) > 38
    
            Data Elements:
    
            ^FBT18 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (Length(report.FBT18) > 38);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410195", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 2 must not exceed 38 characters",
                    LongDescription = @"Although SBR sets a limit of 50 characters for the Line 2 of an address, the maximum allowable for this form is 38",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410195"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT18", Value = GetValueOrEmpty(report.FBT18) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410195
    
            #region VR.ATO.GEN.410195
    
            /*  VR.ATO.GEN.410195
            Address Line 2 must not exceed 38 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:AddressDetails.Line2.Text) > 38
                 RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT33) > 38
    
            Data Elements:
    
            ^FBT33 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (Length(report.FBT33) > 38);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410195", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 2 must not exceed 38 characters",
                    LongDescription = @"Although SBR sets a limit of 50 characters for the Line 2 of an address, the maximum allowable for this form is 38",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410195"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT33", Value = GetValueOrEmpty(report.FBT33) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410195
    
            #region VR.ATO.GEN.410200
    
            /*  VR.ATO.GEN.410200
            Family name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT56, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT56, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000424", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410200"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410200
    
            #region VR.ATO.GEN.410200
    
            /*  VR.ATO.GEN.410200
            Family name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT12, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT12, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000424", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410200"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410200
    
            #region VR.ATO.GEN.410200
    
            /*  VR.ATO.GEN.410200
            Family name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT27, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT27, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000424", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410200"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410200
    
            #region VR.ATO.GEN.410200
    
            /*  VR.ATO.GEN.410200
            Family name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT6, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT6, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000424", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410200"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT6", Value = report.FBT6 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410200
    
            #region VR.ATO.GEN.410200
    
            /*  VR.ATO.GEN.410200
            Family name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT50, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT50 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT50, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000424", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410200"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT50", Value = report.FBT50 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410200
    
            #region VR.ATO.GEN.410201
    
            /*  VR.ATO.GEN.410201
            Family name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT56, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT56, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000426", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410201"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410201
    
            #region VR.ATO.GEN.410201
    
            /*  VR.ATO.GEN.410201
            Family name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT12, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT12, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000426", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410201"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410201
    
            #region VR.ATO.GEN.410201
    
            /*  VR.ATO.GEN.410201
            Family name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT27, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT27, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000426", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410201"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410201
    
            #region VR.ATO.GEN.410201
    
            /*  VR.ATO.GEN.410201
            Family name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT6, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT6 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT6, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000426", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410201"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT6", Value = report.FBT6 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410201
    
            #region VR.ATO.GEN.410201
    
            /*  VR.ATO.GEN.410201
            Family name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT50, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT50 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT50, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000426", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410201"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT50", Value = report.FBT50 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410201
    
            #region VR.ATO.GEN.410203
    
            /*  VR.ATO.GEN.410203
            First name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT58, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT58, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000437", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410203"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410203
    
            #region VR.ATO.GEN.410203
    
            /*  VR.ATO.GEN.410203
            First name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT14, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT14, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000437", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410203"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410203
    
            #region VR.ATO.GEN.410203
    
            /*  VR.ATO.GEN.410203
            First name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT29, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT29, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000437", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410203"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410203
    
            #region VR.ATO.GEN.410203
    
            /*  VR.ATO.GEN.410203
            First name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT8, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT8 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT8, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000437", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410203"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT8", Value = GetValueOrEmpty(report.FBT8) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410203
    
            #region VR.ATO.GEN.410203
    
            /*  VR.ATO.GEN.410203
            First name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT52, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT52 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT52, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000437", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410203"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT52", Value = GetValueOrEmpty(report.FBT52) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410203
    
            #region VR.ATO.GEN.410204
    
            /*  VR.ATO.GEN.410204
            First name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT58, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT58, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000438", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410204"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410204
    
            #region VR.ATO.GEN.410204
    
            /*  VR.ATO.GEN.410204
            First name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT14, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT14, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000438", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410204"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410204
    
            #region VR.ATO.GEN.410204
    
            /*  VR.ATO.GEN.410204
            First name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT29, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT29, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000438", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410204"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410204
    
            #region VR.ATO.GEN.410204
    
            /*  VR.ATO.GEN.410204
            First name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT8, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT8 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT8, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000438", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410204"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT8", Value = GetValueOrEmpty(report.FBT8) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410204
    
            #region VR.ATO.GEN.410204
    
            /*  VR.ATO.GEN.410204
            First name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT52, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT52 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT52, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000438", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410204"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT52", Value = GetValueOrEmpty(report.FBT52) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410204
    
            #region VR.ATO.GEN.410205
    
            /*  VR.ATO.GEN.410205
            Address Line 1 must not contain 'AS ABOVE'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text = FOUND("AS ABOVE"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT41, '"AS ABOVE"'))
    
            Data Elements:
    
            ^FBT41 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT41, @"(^(AS ABOVE)$)|(^(.*)( AS ABOVE )(.*)$)|(^(AS ABOVE )(.*)$)|(^(.*)( AS ABOVE)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410001", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must not contain 'AS ABOVE'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410205"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT41", Value = report.FBT41 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410205
    
            #region VR.ATO.GEN.410205
    
            /*  VR.ATO.GEN.410205
            Address Line 1 must not contain 'AS ABOVE'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text = FOUND("AS ABOVE"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT17, '"AS ABOVE"'))
    
            Data Elements:
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT17, @"(^(AS ABOVE)$)|(^(.*)( AS ABOVE )(.*)$)|(^(AS ABOVE )(.*)$)|(^(.*)( AS ABOVE)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410001", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must not contain 'AS ABOVE'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410205"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410205
    
            #region VR.ATO.GEN.410205
    
            /*  VR.ATO.GEN.410205
            Address Line 1 must not contain 'AS ABOVE'
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text = FOUND("AS ABOVE"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT32, '"AS ABOVE"'))
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT32, @"(^(AS ABOVE)$)|(^(.*)( AS ABOVE )(.*)$)|(^(AS ABOVE )(.*)$)|(^(.*)( AS ABOVE)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410001", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must not contain 'AS ABOVE'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410205"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410205
    
            #region VR.ATO.GEN.410208
    
            /*  VR.ATO.GEN.410208
            Other given name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT59, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT59, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000449", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410208"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410208
    
            #region VR.ATO.GEN.410208
    
            /*  VR.ATO.GEN.410208
            Other given name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT15, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT15, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000449", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410208"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410208
    
            #region VR.ATO.GEN.410208
    
            /*  VR.ATO.GEN.410208
            Other given name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT30, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT30, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000449", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410208"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410208
    
            #region VR.ATO.GEN.410208
    
            /*  VR.ATO.GEN.410208
            Other given name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT9, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT9 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT9, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000449", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410208"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT9", Value = GetValueOrEmpty(report.FBT9) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410208
    
            #region VR.ATO.GEN.410208
    
            /*  VR.ATO.GEN.410208
            Other given name cannot contain "Exec for", "Rep for" or "Trustee for"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("Exec for","Rep for","Trustee for"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT53, '"Exec for","Rep for","Trustee for"'))
    
            Data Elements:
    
            ^FBT53 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT53, @"(^(Exec for|Rep for|Trustee for)$)|(^(.*)( Exec for | Rep for | Trustee for )(.*)$)|(^(Exec for |Rep for |Trustee for )(.*)$)|(^(.*)( Exec for| Rep for| Trustee for)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000449", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""Exec for"", ""Rep for"" or ""Trustee for""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410208"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT53", Value = GetValueOrEmpty(report.FBT53) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410208
    
            #region VR.ATO.GEN.410209
    
            /*  VR.ATO.GEN.410209
            Other given name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT59, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT59, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000450", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410209"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410209
    
            #region VR.ATO.GEN.410209
    
            /*  VR.ATO.GEN.410209
            Other given name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT15, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT15, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000450", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410209"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410209
    
            #region VR.ATO.GEN.410209
    
            /*  VR.ATO.GEN.410209
            Other given name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT30, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT30, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000450", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410209"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410209
    
            #region VR.ATO.GEN.410209
    
            /*  VR.ATO.GEN.410209
            Other given name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT9, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT9 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT9, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000450", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410209"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT9", Value = GetValueOrEmpty(report.FBT9) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410209
    
            #region VR.ATO.GEN.410209
    
            /*  VR.ATO.GEN.410209
            Other given name cannot contain "MR", "MRS", "MISS" or "MS"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("MR","MRS","MISS","MS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT53, '"MR","MRS","MISS","MS"'))
    
            Data Elements:
    
            ^FBT53 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT53, @"(^(MR|MRS|MISS|MS)$)|(^(.*)( MR | MRS | MISS | MS )(.*)$)|(^(MR |MRS |MISS |MS )(.*)$)|(^(.*)( MR| MRS| MISS| MS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000450", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain ""MR"", ""MRS"", ""MISS"" or ""MS""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410209"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT53", Value = GetValueOrEmpty(report.FBT53) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410209
    
            #region VR.ATO.GEN.410211
    
            /*  VR.ATO.GEN.410211
            Overseas address indicator must not be 'TRUE' if Country Code is 'au'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code = "au") AND  (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = TRUE) 
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT224 = 'au') AND  (^FBT164 = TRUE)
    
            Data Elements:
    
            ^FBT224 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT164 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT224 == @"au" && report.FBT164 == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410211", Severity = ProcessMessageSeverity.Error,
                    Description = @"Overseas address indicator must not be 'TRUE' if Country Code is 'au'",
                    LongDescription = @"The overseas address indicator must be 'FALSE' if the Country Code is 'au' - representing Australia. If the address is an overseas address please supply the correct Country Code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410211"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT224", Value = GetValueOrEmpty(report.FBT224) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT164", Value = GetValueOrEmpty(report.FBT164) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410211
    
            #region VR.ATO.GEN.410211
    
            /*  VR.ATO.GEN.410211
            Overseas address indicator must not be 'TRUE' if Country Code is 'au'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code = "au") AND  (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = TRUE) 
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT222 = 'au') AND  (^FBT25 = TRUE)
    
            Data Elements:
    
            ^FBT222 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT25 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT222 == @"au" && report.FBT25 == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410211", Severity = ProcessMessageSeverity.Error,
                    Description = @"Overseas address indicator must not be 'TRUE' if Country Code is 'au'",
                    LongDescription = @"The overseas address indicator must be 'FALSE' if the Country Code is 'au' - representing Australia. If the address is an overseas address please supply the correct Country Code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410211"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT222", Value = GetValueOrEmpty(report.FBT222) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT25", Value = GetValueOrEmpty(report.FBT25) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410211
    
            #region VR.ATO.GEN.410211
    
            /*  VR.ATO.GEN.410211
            Overseas address indicator must not be 'TRUE' if Country Code is 'au'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code = "au") AND  (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = TRUE) 
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT223 = 'au') AND  (^FBT159 = TRUE)
    
            Data Elements:
    
            ^FBT223 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT159 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (report.FBT223 == @"au" && report.FBT159 == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410211", Severity = ProcessMessageSeverity.Error,
                    Description = @"Overseas address indicator must not be 'TRUE' if Country Code is 'au'",
                    LongDescription = @"The overseas address indicator must be 'FALSE' if the Country Code is 'au' - representing Australia. If the address is an overseas address please supply the correct Country Code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410211"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT223", Value = GetValueOrEmpty(report.FBT223) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT159", Value = GetValueOrEmpty(report.FBT159) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410211
    
            #region VR.ATO.GEN.410212
    
            /*  VR.ATO.GEN.410212
            If an overseas Country Code is used, the Overseas Address indicator must be 'TRUE'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Country.Code <> "au") AND  (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE) 
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT224 <> BLANK) AND (^FBT224 <> 'au') AND  (^FBT164 = FALSE)
    
            Data Elements:
    
            ^FBT224 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT164 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT224) != true && report.FBT224 != @"au" && report.FBT164 == false);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410212", Severity = ProcessMessageSeverity.Error,
                    Description = @"If an overseas Country Code is used, the Overseas Address indicator must be 'TRUE'",
                    LongDescription = @"If the address is an Australian address, the overseas address indicator must be set to 'FALSE' and you do not need to supply a Country Code. If the address is an overseas address, the overseas address indicator must be set to 'TRUE' and you must supply a Country Code other than 'au'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410212"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT224", Value = GetValueOrEmpty(report.FBT224) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT164", Value = GetValueOrEmpty(report.FBT164) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410212
    
            #region VR.ATO.GEN.410212
    
            /*  VR.ATO.GEN.410212
            If an overseas Country Code is used, the Overseas Address indicator must be 'TRUE'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Country.Code <> "au") AND  (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE) 
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT222 <> BLANK) AND (^FBT222 <> 'au') AND  (^FBT25 = FALSE)
    
            Data Elements:
    
            ^FBT222 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT25 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT222) != true && report.FBT222 != @"au" && report.FBT25 == false);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410212", Severity = ProcessMessageSeverity.Error,
                    Description = @"If an overseas Country Code is used, the Overseas Address indicator must be 'TRUE'",
                    LongDescription = @"If the address is an Australian address, the overseas address indicator must be set to 'FALSE' and you do not need to supply a Country Code. If the address is an overseas address, the overseas address indicator must be set to 'TRUE' and you must supply a Country Code other than 'au'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410212"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT222", Value = GetValueOrEmpty(report.FBT222) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT25", Value = GetValueOrEmpty(report.FBT25) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410212
    
            #region VR.ATO.GEN.410212
    
            /*  VR.ATO.GEN.410212
            If an overseas Country Code is used, the Overseas Address indicator must be 'TRUE'
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Country.Code <> NULLORBLANK) AND (pyde.xx.xx:AddressDetails.Country.Code <> "au") AND  (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE) 
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT223 <> BLANK) AND (^FBT223 <> 'au') AND  (^FBT159 = FALSE)
    
            Data Elements:
    
            ^FBT223 = RP:AddressDetails:AddressDetails.Country.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT159 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT223) != true && report.FBT223 != @"au" && report.FBT159 == false);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410212", Severity = ProcessMessageSeverity.Error,
                    Description = @"If an overseas Country Code is used, the Overseas Address indicator must be 'TRUE'",
                    LongDescription = @"If the address is an Australian address, the overseas address indicator must be set to 'FALSE' and you do not need to supply a Country Code. If the address is an overseas address, the overseas address indicator must be set to 'TRUE' and you must supply a Country Code other than 'au'",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Country.Code",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410212"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT223", Value = GetValueOrEmpty(report.FBT223) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT159", Value = GetValueOrEmpty(report.FBT159) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410212
    
            #region VR.ATO.GEN.410213
    
            /*  VR.ATO.GEN.410213
            Country Name must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.CountryName.Text <> NULLORBLANK)
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT48 <> BLANK
    
            Data Elements:
    
            ^FBT48 = RP:AddressDetails:AddressDetails.CountryName.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT48) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410213", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country Name must be left blank",
                    LongDescription = @"For SBR submissions to the ATO, the Country Name must be left blank. To supply the country for an overseas address please supply a Country Code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.CountryName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410213"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT48", Value = GetValueOrEmpty(report.FBT48) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410213
    
            #region VR.ATO.GEN.410213
    
            /*  VR.ATO.GEN.410213
            Country Name must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.CountryName.Text <> NULLORBLANK)
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT24 <> BLANK
    
            Data Elements:
    
            ^FBT24 = RP:AddressDetails:AddressDetails.CountryName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT24) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410213", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country Name must be left blank",
                    LongDescription = @"For SBR submissions to the ATO, the Country Name must be left blank. To supply the country for an overseas address please supply a Country Code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.CountryName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410213"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT24", Value = GetValueOrEmpty(report.FBT24) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410213
    
            #region VR.ATO.GEN.410213
    
            /*  VR.ATO.GEN.410213
            Country Name must be left blank
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.CountryName.Text <> NULLORBLANK)
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT39 <> BLANK
    
            Data Elements:
    
            ^FBT39 = RP:AddressDetails:AddressDetails.CountryName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT39) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410213", Severity = ProcessMessageSeverity.Error,
                    Description = @"Country Name must be left blank",
                    LongDescription = @"For SBR submissions to the ATO, the Country Name must be left blank. To supply the country for an overseas address please supply a Country Code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.CountryName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410213"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT39", Value = GetValueOrEmpty(report.FBT39) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410213
    
            #region VR.ATO.GEN.410214
    
            /*  VR.ATO.GEN.410214
            Address Line 1 must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Line1.Text = NULLORBLANK)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT41 = BLANK)
    
            Data Elements:
    
            ^FBT41 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_BUS_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT41) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410214", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must be present",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410214"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT41", Value = report.FBT41 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410214
    
            #region VR.ATO.GEN.410214
    
            /*  VR.ATO.GEN.410214
            Address Line 1 must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Line1.Text = NULLORBLANK)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT17 = BLANK)
    
            Data Elements:
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT17) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410214", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must be present",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410214"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410214
    
            #region VR.ATO.GEN.410214
    
            /*  VR.ATO.GEN.410214
            Address Line 1 must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.Line1.Text = NULLORBLANK)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT32 = BLANK)
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_P_RPExists != false && string.IsNullOrWhiteSpace(report.FBT32) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410214", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address Line 1 must be present",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410214"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410214
    
            #region VR.ATO.GEN.410215
    
            /*  VR.ATO.GEN.410215
            Organisation name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT16 = BLANK)
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
    
            ^OrganisationNameDetails = RP:OrganisationNameDetails
            */
            assertion = (report.OrganisationNameDetailsCollection_MN_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT16) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410215", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must be present",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410215"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410215
    
            #region VR.ATO.GEN.410215
    
            /*  VR.ATO.GEN.410215
            Organisation name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT31 = BLANK)
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
    
            ^OrganisationNameDetails = RP:OrganisationNameDetails
            */
            assertion = (report.OrganisationNameDetailsCollection_MN_P_RPExists != false && string.IsNullOrWhiteSpace(report.FBT31) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410215", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must be present",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410215"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410215
    
            #region VR.ATO.GEN.410215
    
            /*  VR.ATO.GEN.410215
            Organisation name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT10 = BLANK)
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
    
            ^OrganisationNameDetails = RP:ControllingParty:OrganisationNameDetails
            */
            assertion = (report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT10) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410215", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must be present",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410215"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410215
    
            #region VR.ATO.GEN.410215
    
            /*  VR.ATO.GEN.410215
            Organisation name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(organisationname2.xx.xx:OrganisationNameDetails)
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text = NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^OrganisationNameDetails <> NULL) AND (^FBT54 = BLANK)
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
    
            ^OrganisationNameDetails = RP:ControllingParty:OrganisationNameDetails
            */
            assertion = (report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPExists != false && string.IsNullOrWhiteSpace(report.FBT54) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410215", Severity = ProcessMessageSeverity.Error,
                    Description = @"Organisation name must be present",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410215"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410215
    
            #region VR.ATO.GEN.410217
    
            /*  VR.ATO.GEN.410217
            Family Name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails)
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND (^FBT56 = BLANK)
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
    
            ^PersonNameDetails = RP:PersonNameDetails
            */
            assertion = (report.PersonNameDetailsCollection_LGL_Contact_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT56) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410217", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family Name must be present",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410217"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410217
    
            #region VR.ATO.GEN.410217
    
            /*  VR.ATO.GEN.410217
            Family Name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails)
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND (^FBT12 = BLANK)
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^PersonNameDetails = RP:PersonNameDetails
            */
            assertion = (report.PersonNameDetailsCollection_LGL_Identifier_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT12) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410217", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family Name must be present",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410217"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410217
    
            #region VR.ATO.GEN.410217
    
            /*  VR.ATO.GEN.410217
            Family Name must be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails)
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = NULLORBLANK) 
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND (^FBT27 = BLANK)
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
    
            ^PersonNameDetails = RP:PersonNameDetails
            */
            assertion = (report.PersonNameDetailsCollection_LGL_Identifier_P_RPExists != false && string.IsNullOrWhiteSpace(report.FBT27) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410217", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family Name must be present",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410217"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410217
    
            #region VR.ATO.GEN.410218
    
            /*  VR.ATO.GEN.410218
            FirstName must be entered if OtherGivenNames is entered
    
            Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails) 
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text = NULLORBLANK) 
                RETURN VALIDATION MESSAGE 
             ENDIF

            Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND ((^FBT59 <> BLANK) AND (^FBT58 = BLANK))
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
    
            ^PersonNameDetails = RP:PersonNameDetails
            */
            assertion = (report.PersonNameDetailsCollection_LGL_Contact_C_RPExists != false && (string.IsNullOrWhiteSpace(report.FBT59) != true && string.IsNullOrWhiteSpace(report.FBT58) == true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410218", Severity = ProcessMessageSeverity.Error,
                    Description = @"FirstName must be entered if OtherGivenNames is entered",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410218"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410218
    
            #region VR.ATO.GEN.410218
    
            /*  VR.ATO.GEN.410218
            FirstName must be entered if OtherGivenNames is entered
    
            Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails) 
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text = NULLORBLANK) 
                RETURN VALIDATION MESSAGE 
             ENDIF

            Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND ((^FBT15 <> BLANK) AND (^FBT14 = BLANK))
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
    
            ^PersonNameDetails = RP:PersonNameDetails
            */
            assertion = (report.PersonNameDetailsCollection_LGL_Identifier_C_RPExists != false && (string.IsNullOrWhiteSpace(report.FBT15) != true && string.IsNullOrWhiteSpace(report.FBT14) == true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410218", Severity = ProcessMessageSeverity.Error,
                    Description = @"FirstName must be entered if OtherGivenNames is entered",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410218"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410218
    
            #region VR.ATO.GEN.410218
    
            /*  VR.ATO.GEN.410218
            FirstName must be entered if OtherGivenNames is entered
    
            Legacy Rule Format:
            WHERE IN TUPLE(personstructuredname3.xx.xx:PersonNameDetails) 
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonNameDetails.GivenName.Text = NULLORBLANK) 
                RETURN VALIDATION MESSAGE 
             ENDIF

            Technical Business Rule Format:
            (^PersonNameDetails <> NULL) AND ((^FBT30 <> BLANK) AND (^FBT29 = BLANK))
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
    
            ^PersonNameDetails = RP:PersonNameDetails
            */
            assertion = (report.PersonNameDetailsCollection_LGL_Identifier_P_RPExists != false && (string.IsNullOrWhiteSpace(report.FBT30) != true && string.IsNullOrWhiteSpace(report.FBT29) == true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.410218", Severity = ProcessMessageSeverity.Error,
                    Description = @"FirstName must be entered if OtherGivenNames is entered",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.410218"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.410218
    
            #region VR.ATO.GEN.428230
    
            /*  VR.ATO.GEN.428230
            Suburb/Town/City cannot contain state code
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text = FOUND("QLD","NSW","VIC","SA","WA","NT","ACT","TAS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT45, '"QLD","NSW","VIC","SA","WA","NT","ACT","TAS"'))
    
            Data Elements:
    
            ^FBT45 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT45, @"(^(QLD|NSW|VIC|SA|WA|NT|ACT|TAS)$)|(^(.*)( QLD | NSW | VIC | SA | WA | NT | ACT | TAS )(.*)$)|(^(QLD |NSW |VIC |SA |WA |NT |ACT |TAS )(.*)$)|(^(.*)( QLD| NSW| VIC| SA| WA| NT| ACT| TAS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000411", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain state code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428230"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT45", Value = report.FBT45 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428230
    
            #region VR.ATO.GEN.428230
    
            /*  VR.ATO.GEN.428230
            Suburb/Town/City cannot contain state code
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text = FOUND("QLD","NSW","VIC","SA","WA","NT","ACT","TAS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT21, '"QLD","NSW","VIC","SA","WA","NT","ACT","TAS"'))
    
            Data Elements:
    
            ^FBT21 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT21, @"(^(QLD|NSW|VIC|SA|WA|NT|ACT|TAS)$)|(^(.*)( QLD | NSW | VIC | SA | WA | NT | ACT | TAS )(.*)$)|(^(QLD |NSW |VIC |SA |WA |NT |ACT |TAS )(.*)$)|(^(.*)( QLD| NSW| VIC| SA| WA| NT| ACT| TAS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000411", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain state code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428230"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT21", Value = report.FBT21 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428230
    
            #region VR.ATO.GEN.428230
    
            /*  VR.ATO.GEN.428230
            Suburb/Town/City cannot contain state code
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text = FOUND("QLD","NSW","VIC","SA","WA","NT","ACT","TAS"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT36, '"QLD","NSW","VIC","SA","WA","NT","ACT","TAS"'))
    
            Data Elements:
    
            ^FBT36 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT36, @"(^(QLD|NSW|VIC|SA|WA|NT|ACT|TAS)$)|(^(.*)( QLD | NSW | VIC | SA | WA | NT | ACT | TAS )(.*)$)|(^(QLD |NSW |VIC |SA |WA |NT |ACT |TAS )(.*)$)|(^(.*)( QLD| NSW| VIC| SA| WA| NT| ACT| TAS)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000411", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain state code",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428230"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT36", Value = report.FBT36 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428230
    
            #region VR.ATO.GEN.428254
    
            /*  VR.ATO.GEN.428254
            Address line 1 cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text CONTAINS "UNKNOWN")
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT41, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT41 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT41 == null ? false : report.FBT41.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000405", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 1 cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428254"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT41", Value = report.FBT41 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428254
    
            #region VR.ATO.GEN.428254
    
            /*  VR.ATO.GEN.428254
            Address line 1 cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text CONTAINS "UNKNOWN")
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT17, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT17 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT17 == null ? false : report.FBT17.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000405", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 1 cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428254"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT17", Value = report.FBT17 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428254
    
            #region VR.ATO.GEN.428254
    
            /*  VR.ATO.GEN.428254
            Address line 1 cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line1.Text CONTAINS "UNKNOWN")
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT32, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT32 = RP:AddressDetails:AddressDetails.Line1.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (report.FBT32 == null ? false : report.FBT32.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000405", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 1 cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line1.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428254"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT32", Value = report.FBT32 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428254
    
            #region VR.ATO.GEN.428255
    
            /*  VR.ATO.GEN.428255
            Address line 2 cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line2.Text CONTAINS "UNKNOWN")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT42, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT42 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT42 == null ? false : report.FBT42.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000407", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 2 cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line2.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428255"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT42", Value = GetValueOrEmpty(report.FBT42) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428255
    
            #region VR.ATO.GEN.428255
    
            /*  VR.ATO.GEN.428255
            Address line 2 cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line2.Text CONTAINS "UNKNOWN")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT18, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT18 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT18 == null ? false : report.FBT18.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000407", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 2 cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.Line2.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428255"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT18", Value = GetValueOrEmpty(report.FBT18) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428255
    
            #region VR.ATO.GEN.428255
    
            /*  VR.ATO.GEN.428255
            Address line 2 cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.Line2.Text CONTAINS "UNKNOWN")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT33, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT33 = RP:AddressDetails:AddressDetails.Line2.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (report.FBT33 == null ? false : report.FBT33.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000407", Severity = ProcessMessageSeverity.Error,
                    Description = @"Address line 2 cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.Line2.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428255"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT33", Value = GetValueOrEmpty(report.FBT33) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428255
    
            #region VR.ATO.GEN.428256
    
            /*  VR.ATO.GEN.428256
            Suburb/Town/City cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text CONTAINS "UNKNOWN")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT45, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT45 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT45 == null ? false : report.FBT45.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000409", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428256"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT45", Value = report.FBT45 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428256
    
            #region VR.ATO.GEN.428256
    
            /*  VR.ATO.GEN.428256
            Suburb/Town/City cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text CONTAINS "UNKNOWN")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT21, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT21 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT21 == null ? false : report.FBT21.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000409", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428256"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT21", Value = report.FBT21 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428256
    
            #region VR.ATO.GEN.428256
    
            /*  VR.ATO.GEN.428256
            Suburb/Town/City cannot contain "UNKNOWN"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text CONTAINS "UNKNOWN")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT36, 'UNKNOWN')
    
            Data Elements:
    
            ^FBT36 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (report.FBT36 == null ? false : report.FBT36.ToUpperInvariant().Contains(@"UNKNOWN"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000409", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain ""UNKNOWN""",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428256"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT36", Value = report.FBT36 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428256
    
            #region VR.ATO.GEN.428258
    
            /*  VR.ATO.GEN.428258
            Non Individual Name cannot contain space hyphen space combinations
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS  " - " )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT40, ' - ')
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT40 == null ? false : report.FBT40.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000413", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain space hyphen space combinations",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428258"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428258
    
            #region VR.ATO.GEN.428258
    
            /*  VR.ATO.GEN.428258
            Non Individual Name cannot contain space hyphen space combinations
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS  " - " )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT16, ' - ')
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT16 == null ? false : report.FBT16.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000413", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain space hyphen space combinations",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428258"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428258
    
            #region VR.ATO.GEN.428258
    
            /*  VR.ATO.GEN.428258
            Non Individual Name cannot contain space hyphen space combinations
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS  " - " )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT31, ' - ')
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT31 == null ? false : report.FBT31.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000413", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain space hyphen space combinations",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428258"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428258
    
            #region VR.ATO.GEN.428258
    
            /*  VR.ATO.GEN.428258
            Non Individual Name cannot contain space hyphen space combinations
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS  " - " )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT10, ' - ')
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT10 == null ? false : report.FBT10.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000413", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain space hyphen space combinations",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428258"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428258
    
            #region VR.ATO.GEN.428258
    
            /*  VR.ATO.GEN.428258
            Non Individual Name cannot contain space hyphen space combinations
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS  " - " )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT54, ' - ')
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT54 == null ? false : report.FBT54.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000413", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain space hyphen space combinations",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428258"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428258
    
            #region VR.ATO.GEN.428259
    
            /*  VR.ATO.GEN.428259
            Non Individual Name cannot contain "P/L"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS "P/L")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT40, 'P/L')
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT40 == null ? false : report.FBT40.ToUpperInvariant().Contains(@"P/L"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000414", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain ""P/L""",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428259"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428259
    
            #region VR.ATO.GEN.428259
    
            /*  VR.ATO.GEN.428259
            Non Individual Name cannot contain "P/L"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS "P/L")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT16, 'P/L')
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT16 == null ? false : report.FBT16.ToUpperInvariant().Contains(@"P/L"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000414", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain ""P/L""",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428259"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428259
    
            #region VR.ATO.GEN.428259
    
            /*  VR.ATO.GEN.428259
            Non Individual Name cannot contain "P/L"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS "P/L")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT31, 'P/L')
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT31 == null ? false : report.FBT31.ToUpperInvariant().Contains(@"P/L"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000414", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain ""P/L""",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428259"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428259
    
            #region VR.ATO.GEN.428259
    
            /*  VR.ATO.GEN.428259
            Non Individual Name cannot contain "P/L"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS "P/L")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT10, 'P/L')
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT10 == null ? false : report.FBT10.ToUpperInvariant().Contains(@"P/L"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000414", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain ""P/L""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428259"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428259
    
            #region VR.ATO.GEN.428259
    
            /*  VR.ATO.GEN.428259
            Non Individual Name cannot contain "P/L"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS "P/L")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT54, 'P/L')
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT54 == null ? false : report.FBT54.ToUpperInvariant().Contains(@"P/L"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000414", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain ""P/L""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428259"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428259
    
            #region VR.ATO.GEN.428260
    
            /*  VR.ATO.GEN.428260
            Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT40, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT40, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000416", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428260"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428260
    
            #region VR.ATO.GEN.428260
    
            /*  VR.ATO.GEN.428260
            Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT16, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT16, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000416", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428260"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428260
    
            #region VR.ATO.GEN.428260
    
            /*  VR.ATO.GEN.428260
            Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT31, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT31, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000416", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428260"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428260
    
            #region VR.ATO.GEN.428260
    
            /*  VR.ATO.GEN.428260
            Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT10, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT10, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000416", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428260"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428260
    
            #region VR.ATO.GEN.428260
    
            /*  VR.ATO.GEN.428260
            Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT54, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT54, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000416", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428260"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428260
    
            #region VR.ATO.GEN.428261
    
            /*  VR.ATO.GEN.428261
            Non Individual Name cannot end with "T/A", "T/A P'ship", "T/A Pship", "T/A P/Ship" or "T/A Partnership"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (EndsWithSet(^FBT40, '" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"'))
    
            Data Elements:
    
            ^FBT40 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MTR'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT40, @"( T/A| T/A P'ship| T/A Pship| T/A P/Ship| T/A Partnership)$",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000417", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot end with ""T/A"", ""T/A P'ship"", ""T/A Pship"", ""T/A P/Ship"" or ""T/A Partnership""",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MTR_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428261"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT40", Value = report.FBT40 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428261
    
            #region VR.ATO.GEN.428261
    
            /*  VR.ATO.GEN.428261
            Non Individual Name cannot end with "T/A", "T/A P'ship", "T/A Pship", "T/A P/Ship" or "T/A Partnership"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (EndsWithSet(^FBT16, '" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"'))
    
            Data Elements:
    
            ^FBT16 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT16, @"( T/A| T/A P'ship| T/A Pship| T/A P/Ship| T/A Partnership)$",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000417", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot end with ""T/A"", ""T/A P'ship"", ""T/A Pship"", ""T/A P/Ship"" or ""T/A Partnership""",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428261"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT16", Value = report.FBT16 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428261
    
            #region VR.ATO.GEN.428261
    
            /*  VR.ATO.GEN.428261
            Non Individual Name cannot end with "T/A", "T/A P'ship", "T/A Pship", "T/A P/Ship" or "T/A Partnership"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (EndsWithSet(^FBT31, '" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"'))
    
            Data Elements:
    
            ^FBT31 = RP:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT31, @"( T/A| T/A P'ship| T/A Pship| T/A P/Ship| T/A Partnership)$",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000417", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot end with ""T/A"", ""T/A P'ship"", ""T/A Pship"", ""T/A P/Ship"" or ""T/A Partnership""",
                    Location = "/xbrli:xbrl/tns:OrganisationNameDetails" + OccurrenceIndex(report.OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428261"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT31", Value = report.FBT31 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428261
    
            #region VR.ATO.GEN.428261
    
            /*  VR.ATO.GEN.428261
            Non Individual Name cannot end with "T/A", "T/A P'ship", "T/A Pship", "T/A P/Ship" or "T/A Partnership"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (EndsWithSet(^FBT10, '" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"'))
    
            Data Elements:
    
            ^FBT10 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT10, @"( T/A| T/A P'ship| T/A Pship| T/A P/Ship| T/A Partnership)$",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000417", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot end with ""T/A"", ""T/A P'ship"", ""T/A Pship"", ""T/A P/Ship"" or ""T/A Partnership""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_C_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428261"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT10", Value = report.FBT10 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428261
    
            #region VR.ATO.GEN.428261
    
            /*  VR.ATO.GEN.428261
            Non Individual Name cannot end with "T/A", "T/A P'ship", "T/A Pship", "T/A P/Ship" or "T/A Partnership"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:OrganisationNameDetails.OrganisationalName.Text ENDSWITH SET(" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"))
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (EndsWithSet(^FBT54, '" T/A"," T/A P'ship"," T/A Pship"," T/A P/Ship"," T/A Partnership"'))
    
            Data Elements:
    
            ^FBT54 = RP:ControllingParty:OrganisationNameDetails:OrganisationNameDetails.OrganisationalName.Text WHERE [OrganisationNameDetails.OrganisationalNameType.Code='MN'].[OrganisationNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT54, @"( T/A| T/A P'ship| T/A Pship| T/A P/Ship| T/A Partnership)$",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000417", Severity = ProcessMessageSeverity.Error,
                    Description = @"Non Individual Name cannot end with ""T/A"", ""T/A P'ship"", ""T/A Pship"", ""T/A P/Ship"" or ""T/A Partnership""",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:OrganisationNameDetails" + OccurrenceIndex(report.ControllingParty_OrganisationNameDetailsCollection_MN_P_RPOccurrenceIndex) + "/tns:OrganisationNameDetails.OrganisationalName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428261"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT54", Value = report.FBT54 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428261
    
            #region VR.ATO.GEN.428262
    
            /*  VR.ATO.GEN.428262
            Family Name cannot contain "space hyphen space"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text CONTAINS " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT56, ' - ')
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT56 == null ? false : report.FBT56.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000423", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family Name cannot contain ""space hyphen space""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428262"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428262
    
            #region VR.ATO.GEN.428262
    
            /*  VR.ATO.GEN.428262
            Family Name cannot contain "space hyphen space"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text CONTAINS " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT12, ' - ')
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT12 == null ? false : report.FBT12.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000423", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family Name cannot contain ""space hyphen space""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428262"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428262
    
            #region VR.ATO.GEN.428262
    
            /*  VR.ATO.GEN.428262
            Family Name cannot contain "space hyphen space"
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text CONTAINS " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT27, ' - ')
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT27 == null ? false : report.FBT27.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000423", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family Name cannot contain ""space hyphen space""",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428262"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428262
    
            #region VR.ATO.GEN.428263
    
            /*  VR.ATO.GEN.428263
            Family name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT56, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT56, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000427", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428263"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428263
    
            #region VR.ATO.GEN.428263
    
            /*  VR.ATO.GEN.428263
            Family name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT12, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT12, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000427", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428263"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428263
    
            #region VR.ATO.GEN.428263
    
            /*  VR.ATO.GEN.428263
            Family name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT27, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT27, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000427", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428263"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428263
    
            #region VR.ATO.GEN.428264
    
            /*  VR.ATO.GEN.428264
            First name cannot contain space hyphen space
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text CONTAINS  " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT58, ' - ')
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT58 == null ? false : report.FBT58.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000434", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain space hyphen space",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428264"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428264
    
            #region VR.ATO.GEN.428264
    
            /*  VR.ATO.GEN.428264
            First name cannot contain space hyphen space
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text CONTAINS  " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT14, ' - ')
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT14 == null ? false : report.FBT14.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000434", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain space hyphen space",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428264"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428264
    
            #region VR.ATO.GEN.428264
    
            /*  VR.ATO.GEN.428264
            First name cannot contain space hyphen space
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text CONTAINS  " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT29, ' - ')
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT29 == null ? false : report.FBT29.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000434", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain space hyphen space",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428264"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428264
    
            #region VR.ATO.GEN.428265
    
            /*  VR.ATO.GEN.428265
            First name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT58, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT58, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000439", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428265"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428265
    
            #region VR.ATO.GEN.428265
    
            /*  VR.ATO.GEN.428265
            First name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT14, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT14, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000439", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428265"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428265
    
            #region VR.ATO.GEN.428265
    
            /*  VR.ATO.GEN.428265
            First name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT29, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT29, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000439", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428265"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428265
    
            #region VR.ATO.GEN.428266
    
            /*  VR.ATO.GEN.428266
            Other given name cannot contain space hyphen space
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text CONTAINS  " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT59, ' - ')
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT59 == null ? false : report.FBT59.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000446", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain space hyphen space",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428266"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428266
    
            #region VR.ATO.GEN.428266
    
            /*  VR.ATO.GEN.428266
            Other given name cannot contain space hyphen space
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text CONTAINS  " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT15, ' - ')
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = (report.FBT15 == null ? false : report.FBT15.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000446", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain space hyphen space",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428266"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428266
    
            #region VR.ATO.GEN.428266
    
            /*  VR.ATO.GEN.428266
            Other given name cannot contain space hyphen space
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text CONTAINS  " - ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT30, ' - ')
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = (report.FBT30 == null ? false : report.FBT30.ToUpperInvariant().Contains(@" - "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000446", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain space hyphen space",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428266"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428266
    
            #region VR.ATO.GEN.428267
    
            /*  VR.ATO.GEN.428267
            Other given name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT59, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT59, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000451", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428267"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428267
    
            #region VR.ATO.GEN.428267
    
            /*  VR.ATO.GEN.428267
            Other given name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT15, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT15, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000451", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428267"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428267
    
            #region VR.ATO.GEN.428267
    
            /*  VR.ATO.GEN.428267
            Other given name cannot contain repeated hyphen, apostrophe, or space characters
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text CONTAINS SET("--","''","  ") )
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (ContainsSet(^FBT30, '"--","''","  "'))
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT30, @"--|''|  ",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000451", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain repeated hyphen, apostrophe, or space characters",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.428267"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.428267
    
            #region VR.ATO.GEN.430222
    
            /*  VR.ATO.GEN.430222
            Email address must not start or end with an @ symbol
    
            Legacy Rule Format:
            IF (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text STARTSWITH "@") OR (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text ENDSWITH "@")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT62, '@')) OR (EndsWith(^FBT62, '@'))
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (IsMatch(report.FBT62, @"^(@)",RegexOptions.IgnoreCase) || IsMatch(report.FBT62, @"(@)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430222", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not start or end with an @ symbol",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430222"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430222
    
            #region VR.ATO.GEN.430223
    
            /*  VR.ATO.GEN.430223
            Email address must not contain more than one @ symbol
    
            Legacy Rule Format:
            IF pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text CONTAINS MORE THAN ONE "@"
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ContainsMultiple(^FBT62, '@')
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = IsMatch(report.FBT62, @"@(.*)@",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430223", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not contain more than one @ symbol",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430223"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430223
    
            #region VR.ATO.GEN.430224
    
            /*  VR.ATO.GEN.430224
            Email address must not start or end with a dot (.)
    
            Legacy Rule Format:
            IF (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text STARTSWITH ".") OR (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text ENDSWITH ".") 
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (StartsWith(^FBT62, '.')) OR (EndsWith(^FBT62, '.'))
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (IsMatch(report.FBT62, @"^(\.)",RegexOptions.IgnoreCase) || IsMatch(report.FBT62, @"(\.)$",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430224", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not start or end with a dot (.)",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430224"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430224
    
            #region VR.ATO.GEN.430226
    
            /*  VR.ATO.GEN.430226
            Email address must not contain more than one consecutive dots (..)
    
            Legacy Rule Format:
            IF pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text CONTAINS ".."
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT62, '..')
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (report.FBT62 == null ? false : report.FBT62.ToUpperInvariant().Contains(@".."));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430226", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not contain more than one consecutive dots (..)",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430226"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430226
    
            #region VR.ATO.GEN.430227
    
            /*  VR.ATO.GEN.430227
            Email address must not contain a dot followed by a @ symbol (.@)
    
            Legacy Rule Format:
            IF pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text CONTAINS ".@"
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT62, '.@')
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (report.FBT62 == null ? false : report.FBT62.ToUpperInvariant().Contains(@".@"));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430227", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not contain a dot followed by a @ symbol (.@)",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430227"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430227
    
            #region VR.ATO.GEN.430228
    
            /*  VR.ATO.GEN.430228
            Email address must not contain a @ symbol followed by a dot (@.)
    
            Legacy Rule Format:
            IF pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text CONTAINS "@."
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT62, '@.')
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (report.FBT62 == null ? false : report.FBT62.ToUpperInvariant().Contains(@"@."));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430228", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not contain a @ symbol followed by a dot (@.)",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430228"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430228
    
            #region VR.ATO.GEN.430229
    
            /*  VR.ATO.GEN.430229
            Email address must not contain an invalid character
    
            Legacy Rule Format:
            IF pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text CONTAINS SET("(", ")", "<", ">", ",", ";", ":", "\",  """, "]", "[")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ContainsSet(^FBT62, '"(", ")", "<", ">", ",", ";", ":", "\",  """, "]", "["')
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = IsMatch(report.FBT62, @"\(|\)|<|>|,|;|:|\\|""|\]|\[",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430229", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must not contain an invalid character",
                    LongDescription = @"An email address must not contain any of the following invalid characters: ( ) < > , ; : \ "" [ ]",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430229"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430229
    
            #region VR.ATO.GEN.430230
    
            /*  VR.ATO.GEN.430230
            Email address must contain an @ symbol
    
            Legacy Rule Format:
            IF (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text <> NULLORBLANK) AND (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text DOES NOT CONTAIN "@")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^ElectronicContactElectronicMail <> NULL) AND ((^FBT62 <> BLANK) AND (NotContains(^FBT62, '@')))
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
    
            ^ElectronicContactElectronicMail = RP:ElectronicContactElectronicMail
            */
            assertion = (report.ElectronicContactElectronicMailCollection_03_RPExists != false && (string.IsNullOrWhiteSpace(report.FBT62) != true && !(report.FBT62 == null ? true : report.FBT62.ToUpperInvariant().Contains(@"@"))));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430230", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must contain an @ symbol",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430230"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430230
    
            #region VR.ATO.GEN.430231
    
            /*  VR.ATO.GEN.430231
            An email address must not start with a space or include a space within it
    
            Legacy Rule Format:
            IF pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text = FOUND(" ")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Contains(^FBT62, ' ')
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
            */
            assertion = (report.FBT62 == null ? false : report.FBT62.ToUpperInvariant().Contains(@" "));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430231", Severity = ProcessMessageSeverity.Error,
                    Description = @"An email address must not start with a space or include a space within it",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430231"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430231
    
            #region VR.ATO.GEN.430232
    
            /*  VR.ATO.GEN.430232
            Email address must contain a dot (.)
    
            Legacy Rule Format:
            IF (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text <> NULLORBLANK) AND (pyde.xx.xx:ElectronicContact.ElectronicMail.Address.Text DOES NOT CONTAIN ".")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^ElectronicContactElectronicMail <> NULL) AND ((^FBT62 <> BLANK) AND (NotContains(^FBT62, '.')))
    
            Data Elements:
    
            ^FBT62 = RP:ElectronicContactElectronicMail:ElectronicContact.ElectronicMail.Address.Text WHERE [ElectronicContact.ElectronicMail.Usage.Code='03']
    
            ^ElectronicContactElectronicMail = RP:ElectronicContactElectronicMail
            */
            assertion = (report.ElectronicContactElectronicMailCollection_03_RPExists != false && (string.IsNullOrWhiteSpace(report.FBT62) != true && !(report.FBT62 == null ? true : report.FBT62.ToUpperInvariant().Contains(@"."))));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430232", Severity = ProcessMessageSeverity.Error,
                    Description = @"Email address must contain a dot (.)",
                    Location = "/xbrli:xbrl/tns:ElectronicContactElectronicMail" + OccurrenceIndex(report.ElectronicContactElectronicMailCollection_03_RPOccurrenceIndex) + "/tns:ElectronicContact.ElectronicMail.Address.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430232"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT62", Value = report.FBT62 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430232
    
            #region VR.ATO.GEN.430245
    
            /*  VR.ATO.GEN.430245
            Suburb/Town/City must be present in an address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text = NULLORBLANK)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT45 = BLANK)
    
            Data Elements:
    
            ^FBT45 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_BUS_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT45) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430245", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City must be present in an address",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430245"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT45", Value = report.FBT45 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430245
    
            #region VR.ATO.GEN.430245
    
            /*  VR.ATO.GEN.430245
            Suburb/Town/City must be present in an address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text = NULLORBLANK)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT21 = BLANK)
    
            Data Elements:
    
            ^FBT21 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_C_RPExists != false && string.IsNullOrWhiteSpace(report.FBT21) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430245", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City must be present in an address",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430245"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT21", Value = report.FBT21 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430245
    
            #region VR.ATO.GEN.430245
    
            /*  VR.ATO.GEN.430245
            Suburb/Town/City must be present in an address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.LocalityName.Text = NULLORBLANK)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT36 = BLANK)
    
            Data Elements:
    
            ^FBT36 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_P_RPExists != false && string.IsNullOrWhiteSpace(report.FBT36) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430245", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City must be present in an address",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430245"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT36", Value = report.FBT36 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430245
    
            #region VR.ATO.GEN.430246
    
            /*  VR.ATO.GEN.430246
            Suburb/Town/City cannot contain numeric characters
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE) AND (pyde.xx.xx:AddressDetails.LocalityName.Text CONTAINS NUMERICS SET(0-9))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT164 = FALSE) AND (ContainsSet(^FBT45, '0-9'))
    
            Data Elements:
    
            ^FBT45 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT164 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT164 == false && IsMatch(report.FBT45, @"[0-9]",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000410", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain numeric characters",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430246"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT164", Value = GetValueOrEmpty(report.FBT164) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT45", Value = report.FBT45 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430246
    
            #region VR.ATO.GEN.430246
    
            /*  VR.ATO.GEN.430246
            Suburb/Town/City cannot contain numeric characters
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE) AND (pyde.xx.xx:AddressDetails.LocalityName.Text CONTAINS NUMERICS SET(0-9))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT25 = FALSE) AND (ContainsSet(^FBT21, '0-9'))
    
            Data Elements:
    
            ^FBT21 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT25 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
            */
            assertion = (report.FBT25 == false && IsMatch(report.FBT21, @"[0-9]",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000410", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain numeric characters",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430246"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT25", Value = GetValueOrEmpty(report.FBT25) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT21", Value = report.FBT21 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430246
    
            #region VR.ATO.GEN.430246
    
            /*  VR.ATO.GEN.430246
            Suburb/Town/City cannot contain numeric characters
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF (pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE) AND (pyde.xx.xx:AddressDetails.LocalityName.Text CONTAINS NUMERICS SET(0-9))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT159 = FALSE) AND (ContainsSet(^FBT36, '0-9'))
    
            Data Elements:
    
            ^FBT36 = RP:AddressDetails:AddressDetails.LocalityName.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT159 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
            */
            assertion = (report.FBT159 == false && IsMatch(report.FBT36, @"[0-9]",RegexOptions.IgnoreCase));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000410", Severity = ProcessMessageSeverity.Error,
                    Description = @"Suburb/Town/City cannot contain numeric characters",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.LocalityName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430246"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT159", Value = GetValueOrEmpty(report.FBT159) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT36", Value = report.FBT36 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430246
    
            #region VR.ATO.GEN.430252
    
            /*  VR.ATO.GEN.430252
            Unstructured name must not be more than 200 characters
    
            Legacy Rule Format:
            IF LENGTH(pyde.xx.xx:PersonUnstructuredName.FullName.Text) > 200
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT129) > 200
    
            Data Elements:
    
            ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']
            */
            assertion = (Length(report.FBT129) > 200);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430252", Severity = ProcessMessageSeverity.Error,
                    Description = @"Unstructured name must not be more than 200 characters",
                    Location = "/xbrli:xbrl/tns:PersonUnstructuredName" + OccurrenceIndex(report.PersonUnstructuredNameCollection_Contact_INTOccurrenceIndex) + "/tns:PersonUnstructuredName.FullName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430252"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT129", Value = report.FBT129 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430252
    
            #region VR.ATO.GEN.430255
    
            /*  VR.ATO.GEN.430255
            Signature date must not be later than today
    
            Legacy Rule Format:
            IF pyin.xx.xx:Declaration.Signature.Date > DATE(TODAY)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT218 > Today()
    
            Data Elements:
    
            ^FBT218 = INT:Declaration:Declaration.Signature.Date WHERE [Declaration.StatementType.Code='TrueAndCorrect']
            */
            assertion = (report.FBT218.GetValueOrDefault() > DateTime.Now.Date);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430255", Severity = ProcessMessageSeverity.Error,
                    Description = @"Signature date must not be later than today",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_INTOccurrenceIndex) + "/tns:Declaration.Signature.Date",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430255"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT218", Value = GetValueOrEmpty(report.FBT218) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430255
    
            #region VR.ATO.GEN.430255
    
            /*  VR.ATO.GEN.430255
            Signature date must not be later than today
    
            Legacy Rule Format:
            IF pyin.xx.xx:Declaration.Signature.Date > DATE(TODAY)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT214 > Today()
    
            Data Elements:
    
            ^FBT214 = RP:Declaration:Declaration.Signature.Date WHERE [Declaration.StatementType.Code='TrueAndCorrect']
            */
            assertion = (report.FBT214.GetValueOrDefault() > DateTime.Now.Date);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430255", Severity = ProcessMessageSeverity.Error,
                    Description = @"Signature date must not be later than today",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_RPOccurrenceIndex) + "/tns:Declaration.Signature.Date",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430255"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT214", Value = GetValueOrEmpty(report.FBT214) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430255
    
            #region VR.ATO.GEN.430318
    
            /*  VR.ATO.GEN.430318
            ABN in the context definition must pass the ABN algorithm check
    
            Legacy Rule Format:
            IF (entity.identifier.ABN <> NULLORBLANK) AND (ABNALGORITHM(entity.identifier.ABN) = FALSE)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^ABN <> BLANK) AND (FailsABNAlgorithm(^ABN))
    
            Data Elements:
    
            ^ABN = INT
            */
            assertion = (string.IsNullOrWhiteSpace(report.INTIdentifierABN) != true && FailsABNAlgorithm(report.INTIdentifierABN));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430318", Severity = ProcessMessageSeverity.Error,
                    Description = @"ABN in context must be a valid ABN",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430318"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430318
    
            #region VR.ATO.GEN.430318
    
            /*  VR.ATO.GEN.430318
            ABN in the context definition must pass the ABN algorithm check
    
            Legacy Rule Format:
            IF (entity.identifier.ABN <> NULLORBLANK) AND (ABNALGORITHM(entity.identifier.ABN) = FALSE)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^ABN <> BLANK) AND (FailsABNAlgorithm(^ABN))
    
            Data Elements:
    
            ^ABN = RP
            */
            assertion = (string.IsNullOrWhiteSpace(report.RPIdentifierABN) != true && FailsABNAlgorithm(report.RPIdentifierABN));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.430318", Severity = ProcessMessageSeverity.Error,
                    Description = @"ABN in context must be a valid ABN",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.RPOccurrenceIndex) + "/xbrli:entity/xbrli:identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.430318"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.430318
    
            #region VR.ATO.GEN.432032
    
            /*  VR.ATO.GEN.432032
            BSB Number, Account Number and Account Name must all be present
    
            Legacy Rule Format:
            WHERE IN TUPLE(financialinstitutionaccount1.xx.xx:FinancialInstitutionAccount)
            IF pyid.xx.xx:FinancialInstitutionAccount.BankStateBranch.Number = NULLORBLANK OR 
                pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionAccount.Number = NULLORBLANK OR 
                pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text = NULLORBLANK
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FinancialInstitutionAccount <> NULL) AND (^FBT229 = BLANK OR     ^FBT230 = BLANK OR     ^FBT231 = BLANK)
    
            Data Elements:
    
            ^FBT230 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionAccount.Number
    
            ^FBT229 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.BankStateBranch.Number
    
            ^FBT231 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text
    
            ^FinancialInstitutionAccount = RP:FinancialInstitutionAccount
            */
            assertion = (report.FinancialInstitutionAccountCollectionExists != false && (string.IsNullOrWhiteSpace(report.FBT229) == true || string.IsNullOrWhiteSpace(report.FBT230) == true || string.IsNullOrWhiteSpace(report.FBT231) == true));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432032", Severity = ProcessMessageSeverity.Error,
                    Description = @"BSB Number, Account Number and Account Name must all be present",
                    LongDescription = @"If any EFT details are present, then a BSB number, account number and an account name must all be present. If EFT is not required, then all fields must be blank or not present",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount/tns:FinancialInstitutionAccount.FinancialInstitutionAccount.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432032"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT229", Value = report.FBT229 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT230", Value = report.FBT230 });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT231", Value = report.FBT231 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.432032
    
            #region VR.ATO.GEN.432035
    
            /*  VR.ATO.GEN.432035
            BSB Number must be six digits and greater than 012000
    
            Legacy Rule Format:
            IF pyid.xx.xx:FinancialInstitutionAccount.BankStateBranch.Number <> NULLORBLANK AND 
            (pyid.xx.xx:FinancialInstitutionAccount.BankStateBranch.Number <> SET(012001-999999)) OR (LENGTH(pyid.xx.xx:FinancialInstitutionAccount.BankStateBranch.Number) <> 6)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT229 <> BLANK AND (IsNumeric(^FBT229) = 'FALSE' OR AsNumeric(^FBT229) < 12001 OR AsNumeric(^FBT229) > 999999 OR Length(^FBT229) <> 6)
    
            Data Elements:
    
            ^FBT229 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.BankStateBranch.Number
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT229) != true && (IsNumeric(report.FBT229) == false || AsNumeric(report.FBT229) < 12001 || AsNumeric(report.FBT229) > 999999 || Length(report.FBT229) != 6));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432035", Severity = ProcessMessageSeverity.Error,
                    Description = @"BSB Number must be six digits and greater than 012000",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount/tns:FinancialInstitutionAccount.BankStateBranch.Number",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432035"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT229", Value = report.FBT229 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.432035
    
            #region VR.ATO.GEN.432037
    
            /*  VR.ATO.GEN.432037
            Bank account name must not contain invalid characters _ ! @ $ % [ ] ? = : ; " ,
    
            Legacy Rule Format:
            IF pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text CONTAINS SET("_", "!", "@", "$", "%", "]", "[", "?", "=", ":", ";", """, ",")
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ContainsSet(^FBT231, '"_", "!", "@", "$", "%", "]", "[", "?", "=", ":", ";", """, ","')
    
            Data Elements:
    
            ^FBT231 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text
            */
            assertion = IsMatch(report.FBT231, @"_|!|@|\$|%|\]|\[|\?|=|:|;|""|,",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432037", Severity = ProcessMessageSeverity.Error,
                    Description = @"Bank account name must not contain invalid characters _ ! @ $ % [ ] ? = : ; "" ,",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount/tns:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432037"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT231", Value = report.FBT231 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.432037
    
            #region VR.ATO.GEN.432040
    
            /*  VR.ATO.GEN.432040
            Only one EFT bank account may be present
    
            Legacy Rule Format:
            IF COUNT (TUPLE(financialinstitutionaccount1.xx.xx:FinancialInstitutionAccount)) > 1
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Count(^FinancialInstitutionAccount) > 1
    
            Data Elements:
    
            ^FinancialInstitutionAccount = RP:FinancialInstitutionAccount
            */
            assertion = (Count(report.FinancialInstitutionAccountCollectionCount) > 1);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432040", Severity = ProcessMessageSeverity.Error,
                    Description = @"Only one EFT bank account may be present",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount" + OccurrenceIndex(report.FinancialInstitutionAccountCollectionCount) + "/tns:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432040"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.432040
    
            #region VR.ATO.GEN.432041
    
            /*  VR.ATO.GEN.432041
            Financial institution account name cannot be greater than 32 characters
    
            Legacy Rule Format:
            IF LENGTH(pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text) > 32
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            Length(^FBT231) > 32
    
            Data Elements:
    
            ^FBT231 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text
            */
            assertion = (Length(report.FBT231) > 32);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432041", Severity = ProcessMessageSeverity.Error,
                    Description = @"Bank account name must not be longer than 32 characters",
                    LongDescription = @"32 characters is the Banking Standard and set by the Banking Industry",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount/tns:FinancialInstitutionAccount.FinancialInstitutionAccountName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432041"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT231", Value = report.FBT231 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.432041
    
            #region VR.ATO.GEN.432267
    
            /*  VR.ATO.GEN.432267
            Financial institution name and branch name must not be present
    
            Legacy Rule Format:
            IF (pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionBranchName.Text) <> NULLORBLANK OR (pyid.xx.xx:FinancialInstitutionAccount.FinancialInstitutionName.Text <> NULLORBLANK)
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^FBT232 <> BLANK OR (^FBT233 <> BLANK)
    
            Data Elements:
    
            ^FBT233 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionName.Text
    
            ^FBT232 = RP:FinancialInstitutionAccount:FinancialInstitutionAccount.FinancialInstitutionBranchName.Text
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT232) != true || string.IsNullOrWhiteSpace(report.FBT233) != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.432267", Severity = ProcessMessageSeverity.Error,
                    Description = @"Financial institution name and branch name must not be present",
                    Location = "/xbrli:xbrl/tns:FinancialInstitutionAccount/tns:FinancialInstitutionAccount.FinancialInstitutionName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.432267"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT232", Value = GetValueOrEmpty(report.FBT232) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT233", Value = GetValueOrEmpty(report.FBT233) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.432267
    
            #region VR.ATO.GEN.434147
    
            /*  VR.ATO.GEN.434147
            State and post code must be present for an Australian address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE AND (pyde.xx.xx:AddressDetails.StateOrTerritory.Code = NULL OR pyde.xx.xx:AddressDetails.Postcode.Text = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT164 = FALSE AND (^FBT46 = NULL OR ^FBT47 = NULL))
    
            Data Elements:
    
            ^FBT164 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT46 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^FBT47 = RP:AddressDetails:AddressDetails.Postcode.Text WHERE [AddressDetails.Usage.Code='BUS'].[AddressDetails.Currency.Code='C']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_BUS_C_RPExists != false && (report.FBT164 == false && (report.FBT46 == null || report.FBT47 == null)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.434147", Severity = ProcessMessageSeverity.Error,
                    Description = @"State and post code must be present for an Australian address",
                    LongDescription = @"If the overseas indicator is no (false), then an Australian state code and post code must be present",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_BUS_C_RPOccurrenceIndex) + "/tns:AddressDetails.OverseasAddress.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.434147"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT164", Value = GetValueOrEmpty(report.FBT164) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT46", Value = GetValueOrEmpty(report.FBT46) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT47", Value = GetValueOrEmpty(report.FBT47) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.434147
    
            #region VR.ATO.GEN.434147
    
            /*  VR.ATO.GEN.434147
            State and post code must be present for an Australian address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE AND (pyde.xx.xx:AddressDetails.StateOrTerritory.Code = NULL OR pyde.xx.xx:AddressDetails.Postcode.Text = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT25 = FALSE AND (^FBT22 = NULL OR ^FBT23 = NULL))
    
            Data Elements:
    
            ^FBT25 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT22 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^FBT23 = RP:AddressDetails:AddressDetails.Postcode.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='C']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_C_RPExists != false && (report.FBT25 == false && (report.FBT22 == null || report.FBT23 == null)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.434147", Severity = ProcessMessageSeverity.Error,
                    Description = @"State and post code must be present for an Australian address",
                    LongDescription = @"If the overseas indicator is no (false), then an Australian state code and post code must be present",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_C_RPOccurrenceIndex) + "/tns:AddressDetails.OverseasAddress.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.434147"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT25", Value = GetValueOrEmpty(report.FBT25) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT22", Value = GetValueOrEmpty(report.FBT22) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT23", Value = GetValueOrEmpty(report.FBT23) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.434147
    
            #region VR.ATO.GEN.434147
    
            /*  VR.ATO.GEN.434147
            State and post code must be present for an Australian address
    
            Legacy Rule Format:
            WHERE IN TUPLE(addressdetails2.xx.xx:AddressDetails)
            IF pyde.xx.xx:AddressDetails.OverseasAddress.Indicator = FALSE AND (pyde.xx.xx:AddressDetails.StateOrTerritory.Code = NULL OR pyde.xx.xx:AddressDetails.Postcode.Text = NULL)
              RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^AddressDetails <> NULL) AND (^FBT159 = FALSE AND (^FBT37 = NULL OR ^FBT38 = NULL))
    
            Data Elements:
    
            ^FBT159 = RP:AddressDetails:AddressDetails.OverseasAddress.Indicator WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT37 = RP:AddressDetails:AddressDetails.StateOrTerritory.Code WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^FBT38 = RP:AddressDetails:AddressDetails.Postcode.Text WHERE [AddressDetails.Usage.Code='POS'].[AddressDetails.Currency.Code='P']
    
            ^AddressDetails = RP:AddressDetails
            */
            assertion = (report.AddressDetailsCollection_POS_P_RPExists != false && (report.FBT159 == false && (report.FBT37 == null || report.FBT38 == null)));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.434147", Severity = ProcessMessageSeverity.Error,
                    Description = @"State and post code must be present for an Australian address",
                    LongDescription = @"If the overseas indicator is no (false), then an Australian state code and post code must be present",
                    Location = "/xbrli:xbrl/tns:AddressDetails" + OccurrenceIndex(report.AddressDetailsCollection_POS_P_RPOccurrenceIndex) + "/tns:AddressDetails.OverseasAddress.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.434147"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT159", Value = GetValueOrEmpty(report.FBT159) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT37", Value = GetValueOrEmpty(report.FBT37) });
    
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT38", Value = GetValueOrEmpty(report.FBT38) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.434147
    
            #region VR.ATO.GEN.434223
    
            /*  VR.ATO.GEN.434223
            ABN must pass the ABN algorithm
    
            Legacy Rule Format:
            IF (pyid.xx.xx:Identifiers.AustralianBusinessNumber.Identifier <> NULLORBLANK) and (ABNALGORITHM(pyid.xx.xx:Identifiers.AustralianBusinessNumber.Identifier) = FALSE)
            RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (^FBT4 <> BLANK) and (FailsABNAlgorithm(^FBT4))
    
            Data Elements:
    
            ^FBT4 = RP:Identifiers.AustralianBusinessNumber.Identifier
            */
            assertion = (string.IsNullOrWhiteSpace(report.FBT4) != true && FailsABNAlgorithm(report.FBT4));
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.000477", Severity = ProcessMessageSeverity.Error,
                    Description = @"ABN is invalid",
                    Location = "/xbrli:xbrl/tns:Identifiers.AustralianBusinessNumber.Identifier",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.434223"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT4", Value = GetValueOrEmpty(report.FBT4) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.434223
    
            #region VR.ATO.GEN.438030
    
            /*  VR.ATO.GEN.438030
            Entity identifier scheme for Intermediary must be "http://www.ato.gov.au/abn"
    
            Legacy Rule Format:
            IF (RprtPyType.xx.xx:ReportPartyTypeDimension = “RprtPyType.xx.xx:Intermediary”) AND (entity.identifier.scheme <> “http://www.ato.gov.au/abn”)
                RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^Context <> NULL AND ^IdentifierScheme <> 'http://www.ato.gov.au/abn'
    
            Data Elements:
    
            ^IdentifierScheme = INT
    
            ^Context = INT
            */
            assertion = (report.INTExists != false && report.INTIdentifierScheme != @"http://www.ato.gov.au/abn");
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438030", Severity = ProcessMessageSeverity.Error,
                    Description = @"Entity identifier scheme for Intermediary must be ""http://www.ato.gov.au/abn""",
                    Location = "/xbrli:xbrl/xbrli:context" + OccurrenceIndex(report.INTOccurrenceIndex) + "/xbrli:entity/xbrli:identifier/@scheme",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438030"} },
                };
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438030
    
            #region VR.ATO.GEN.438063
    
            /*  VR.ATO.GEN.438063
            If an Intermediary is present, Intermediary declaration statement accepted indicator must be supplied and must be “True”.
    
            Legacy Rule Format:
            IF INT<>NULL AND INT:pyin.xx.xx:Declaration.StatementAccepted.Indicator <> TRUE
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^INT <> NULL AND ^FBT219 <> TRUE
    
            Data Elements:
    
            ^FBT219 = INT:Declaration:Declaration.StatementAccepted.Indicator WHERE [Declaration.StatementType.Code='TrueAndCorrect']
    
            ^INT = INT
            */
            assertion = (report.INTExists != false && report.FBT219 != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438063", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declaration statement accepted indicator is required.",
                    LongDescription = @"If an Intermediary is present, Intermediary declaration statement accepted indicator must be supplied and must be ""True"".",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_INTOccurrenceIndex) + "/tns:Declaration.StatementAccepted.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438063"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT219", Value = GetValueOrEmpty(report.FBT219) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438063
    
            #region VR.ATO.GEN.438064
    
            /*  VR.ATO.GEN.438064
            If an Intermediary is not present, Reporting Party declaration statement accepted indicator must be supplied and must be “True”.
    
            Legacy Rule Format:
            IF INT=NULL AND RP:pyin.xx.xx:Declaration.StatementAccepted.Indicator <> TRUE
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^INT = NULL AND ^FBT215 <> TRUE
    
            Data Elements:
    
            ^FBT215 = RP:Declaration:Declaration.StatementAccepted.Indicator WHERE [Declaration.StatementType.Code='TrueAndCorrect']
    
            ^INT = INT
            */
            assertion = (report.INTExists == false && report.FBT215 != true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438064", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declaration statement accepted indicator is required.",
                    LongDescription = @"If an Intermediary is not present, Reporting Party declaration statement accepted indicator must be supplied and must be ""True"".",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_RPOccurrenceIndex) + "/tns:Declaration.StatementAccepted.Indicator",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438064"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT215", Value = GetValueOrEmpty(report.FBT215) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438064
    
            #region VR.ATO.GEN.438065
    
            /*  VR.ATO.GEN.438065
            If an Intermediary is present, Intermediary declaration signatory identifier must be supplied.
    
            Legacy Rule Format:
            IF INT<>NULL AND INT:pyin.xx.xx:Declaration.SignatoryIdentifier.Text = NULLORBLANK
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^INT <> NULL AND ^FBT217 = BLANK
    
            Data Elements:
    
            ^FBT217 = INT:Declaration:Declaration.SignatoryIdentifier.Text WHERE [Declaration.StatementType.Code='TrueAndCorrect']
    
            ^INT = INT
            */
            assertion = (report.INTExists != false && string.IsNullOrWhiteSpace(report.FBT217) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438065", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declaration signatory identifier is required.",
                    LongDescription = @"If an Intermediary is present, Intermediary declaration signatory identifier must be supplied.",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_INTOccurrenceIndex) + "/tns:Declaration.SignatoryIdentifier.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438065"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT217", Value = report.FBT217 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438065
    
            #region VR.ATO.GEN.438066
    
            /*  VR.ATO.GEN.438066
            If an Intermediary is not present, Reporting Party declaration signatory identifier must be supplied.
    
            Legacy Rule Format:
            IF INT=NULL AND RP:pyin.xx.xx:Declaration.SignatoryIdentifier.Text = NULLORBLANK
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^INT = NULL AND ^FBT213 = BLANK
    
            Data Elements:
    
            ^FBT213 = RP:Declaration:Declaration.SignatoryIdentifier.Text WHERE [Declaration.StatementType.Code='TrueAndCorrect']
    
            ^INT = INT
            */
            assertion = (report.INTExists == false && string.IsNullOrWhiteSpace(report.FBT213) == true);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438066", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declaration signatory identifier is required.",
                    LongDescription = @"If an Intermediary is not present, Reporting Party declaration signatory identifier must be supplied.",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_RPOccurrenceIndex) + "/tns:Declaration.SignatoryIdentifier.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438066"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT213", Value = report.FBT213 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438066
    
            #region VR.ATO.GEN.438067
    
            /*  VR.ATO.GEN.438067
            If an Intermediary is present, Intermediary declaration signature date must be supplied.
    
            Legacy Rule Format:
            IF INT<>NULL AND INT:pyin.xx.xx:Declaration.Signature.Date = NULL
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^INT <> NULL AND ^FBT218 = NULL
    
            Data Elements:
    
            ^FBT218 = INT:Declaration:Declaration.Signature.Date WHERE [Declaration.StatementType.Code='TrueAndCorrect']
    
            ^INT = INT
            */
            assertion = (report.INTExists != false && report.FBT218 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438067", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declaration signature date is required.",
                    LongDescription = @"If an Intermediary is present, Intermediary declaration signature date must be supplied.",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_INTOccurrenceIndex) + "/tns:Declaration.Signature.Date",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438067"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT218", Value = GetValueOrEmpty(report.FBT218) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438067
    
            #region VR.ATO.GEN.438068
    
            /*  VR.ATO.GEN.438068
            If an Intermediary is not present, Reporting Party declaration signature date must be supplied.
    
            Legacy Rule Format:
            IF INT=NULL AND RP:pyin.xx.xx:Declaration.Signature.Date = NULL
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ^INT = NULL AND ^FBT214 = NULL
    
            Data Elements:
    
            ^FBT214 = RP:Declaration:Declaration.Signature.Date WHERE [Declaration.StatementType.Code='TrueAndCorrect']
    
            ^INT = INT
            */
            assertion = (report.INTExists == false && report.FBT214 == null);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.438068", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declaration signature date is required.",
                    LongDescription = @"If an Intermediary is not present, Reporting Party declaration signature date must be supplied.",
                    Location = "/xbrli:xbrl/tns:Declaration" + OccurrenceIndex(report.DeclarationCollection_TrueAndCorrect_RPOccurrenceIndex) + "/tns:Declaration.Signature.Date",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.438068"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT214", Value = GetValueOrEmpty(report.FBT214) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.438068
    
            #region VR.ATO.GEN.500037
    
            /*  VR.ATO.GEN.500037
            A text character must be one of the following: A to Z a to z 0 to 9 @ $ % & * ( ) - = ; : ' " , . ? / or a space character.
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonUnstructuredName.FullName.Text <> NULLORBLANK) AND (pyde.xx.xx:PersonUnstructuredName.FullName.Text CONTAINS SET("{","}","|","_","\","#"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            ContainsSet(^FBT129, '"{","}","|","_","\","#"')
    
            Data Elements:
    
            ^FBT129 = INT:PersonUnstructuredName:PersonUnstructuredName.FullName.Text WHERE [PersonUnstructuredName.Usage.Code='Contact']
            */
            assertion = IsMatch(report.FBT129, @"\{|\}|\||_|\\|#",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.500037", Severity = ProcessMessageSeverity.Error,
                    Description = @"Declarer Contact Name contains invalid text",
                    LongDescription = @"A text character must be one of the following: A to Z a to z 0 to 9 @ $ % & * ( ) - = ; : ' "" , . ? / or a space character.",
                    Location = "/xbrli:xbrl/tns:PersonUnstructuredName" + OccurrenceIndex(report.PersonUnstructuredNameCollection_Contact_INTOccurrenceIndex) + "/tns:PersonUnstructuredName.FullName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500037"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT129", Value = report.FBT129 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500037
    
            #region VR.ATO.GEN.500151
    
            /*  VR.ATO.GEN.500151
            First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT58, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT58 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT58, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010436", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500151"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT58", Value = GetValueOrEmpty(report.FBT58) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500151
    
            #region VR.ATO.GEN.500151
    
            /*  VR.ATO.GEN.500151
            First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT14, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT14 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT14, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010436", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500151"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT14", Value = GetValueOrEmpty(report.FBT14) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500151
    
            #region VR.ATO.GEN.500151
    
            /*  VR.ATO.GEN.500151
            First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT29, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT29 = RP:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT29, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010436", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500151"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT29", Value = GetValueOrEmpty(report.FBT29) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500151
    
            #region VR.ATO.GEN.500151
    
            /*  VR.ATO.GEN.500151
            First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT8, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT8 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT8, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010436", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500151"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT8", Value = GetValueOrEmpty(report.FBT8) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500151
    
            #region VR.ATO.GEN.500151
    
            /*  VR.ATO.GEN.500151
            First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.GivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT52, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT52 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.GivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT52, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010436", Severity = ProcessMessageSeverity.Error,
                    Description = @"First name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.GivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500151"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT52", Value = GetValueOrEmpty(report.FBT52) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500151
    
            #region VR.ATO.GEN.500152
    
            /*  VR.ATO.GEN.500152
            Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT59, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT59 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT59, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010448", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500152"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT59", Value = GetValueOrEmpty(report.FBT59) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500152
    
            #region VR.ATO.GEN.500152
    
            /*  VR.ATO.GEN.500152
            Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT15, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT15 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT15, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010448", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500152"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT15", Value = GetValueOrEmpty(report.FBT15) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500152
    
            #region VR.ATO.GEN.500152
    
            /*  VR.ATO.GEN.500152
            Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT30, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT30 = RP:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT30, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010448", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500152"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT30", Value = GetValueOrEmpty(report.FBT30) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500152
    
            #region VR.ATO.GEN.500152
    
            /*  VR.ATO.GEN.500152
            Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT9, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT9 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT9, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010448", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500152"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT9", Value = GetValueOrEmpty(report.FBT9) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500152
    
            #region VR.ATO.GEN.500152
    
            /*  VR.ATO.GEN.500152
            Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.OtherGivenName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT53, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT53 = RP:ControllingParty:PersonNameDetails:PersonNameDetails.OtherGivenName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT53, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.010448", Severity = ProcessMessageSeverity.Error,
                    Description = @"Other given name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:ControllingParty/tns:PersonNameDetails" + OccurrenceIndex(report.ControllingParty_PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.OtherGivenName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500152"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT53", Value = GetValueOrEmpty(report.FBT53) });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500152
    
            #region VR.ATO.GEN.500153
    
            /*  VR.ATO.GEN.500153
            Family name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT56, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT56 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Contact'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT56, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.500153", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Contact_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500153"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT56", Value = report.FBT56 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500153
    
            #region VR.ATO.GEN.500153
    
            /*  VR.ATO.GEN.500153
            Family name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT12, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT12 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='C']
            */
            assertion = IsMatch(report.FBT12, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.500153", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_C_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500153"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT12", Value = report.FBT12 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500153
    
            #region VR.ATO.GEN.500153
    
            /*  VR.ATO.GEN.500153
            Family name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR
    
            Legacy Rule Format:
            IF (pyde.xx.xx:PersonNameDetails.FamilyName.Text = FOUND("ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"))
               RETURN VALIDATION MESSAGE
            ENDIF

            Technical Business Rule Format:
            (FoundSet(^FBT27, '"ESQ","JNR","JP","MHA","MHR","MLA","MLC","MP","QC","SNR"'))
    
            Data Elements:
    
            ^FBT27 = RP:PersonNameDetails:PersonNameDetails.FamilyName.Text WHERE [PersonNameDetails.PersonNameType.Code='LGL'].[PersonNameDetails.Usage.Code='Identifier'].[PersonNameDetails.Currency.Code='P']
            */
            assertion = IsMatch(report.FBT27, @"(^(ESQ|JNR|JP|MHA|MHR|MLA|MLC|MP|QC|SNR)$)|(^(.*)( ESQ | JNR | JP | MHA | MHR | MLA | MLC | MP | QC | SNR )(.*)$)|(^(ESQ |JNR |JP |MHA |MHR |MLA |MLC |MP |QC |SNR )(.*)$)|(^(.*)( ESQ| JNR| JP| MHA| MHR| MLA| MLC| MP| QC| SNR)$)",RegexOptions.IgnoreCase);
            if (assertion)
            {
                processMessage = new ProcessMessageDocument()
                {
                    Code = "CMN.ATO.GEN.500153", Severity = ProcessMessageSeverity.Error,
                    Description = @"Family name cannot contain suffix ESQ, JNR, JP, MHA, MHR, MLA, MLC, MP, QC or SNR",
                    Location = "/xbrli:xbrl/tns:PersonNameDetails" + OccurrenceIndex(report.PersonNameDetailsCollection_LGL_Identifier_P_RPOccurrenceIndex) + "/tns:PersonNameDetails.FamilyName.Text",
                    Parameters = new ProcessMessageParameters() { new ProcessMessageParameter() {Name = "RuleIdentifier", Value = "VR.ATO.GEN.500153"} },
                };
                processMessage.Parameters.Add(new ProcessMessageParameter
                    { Name = "FBT27", Value = report.FBT27 });
    
                response.Add(processMessage);
            }
            #endregion // VR.ATO.GEN.500153

            foreach (ProcessMessageDocument currentProcessMessage in response)
            {
                if (currentProcessMessage.Parameters != null)
                {
                    foreach (ProcessMessageParameter currentParameter in currentProcessMessage.Parameters)
                    {
                        if (string.IsNullOrEmpty(currentParameter.Name))
                        {
                            currentParameter.Name = _emptyParameterValue;
                        }

                        if (currentParameter.Name.Length > _maxParameterNameLength)
                        {
                            currentParameter.Name = currentParameter.Name.Substring(0, _maxParameterNameLength - 1);
                        }

                        if (string.IsNullOrEmpty(currentParameter.Value))
                        {
                            currentParameter.Value = _emptyParameterValue;
                        }

                        if (currentParameter.Value.Length > _maxParameterValueLength)
                        {
                            currentParameter.Value = currentParameter.Value.Substring(0, _maxParameterValueLength - 1);
                        }
                    }
                }
            }

            return response;
        }


    }
} 
